<?php

class Interico_Customizer {

	/**
	 * Holds the instance of this class.
	 *
	 * @since  1.0.0
	 * @access private
	 * @var    object
	 */
	private static $instance;

	/**
	 * Initialization.
	 */
	public function __construct() {

		// Enable Live preview via JavaScript
		add_action( 'customize_preview_init', array( $this, 'interico_customizer_live_preview' ) );

		// Add Customizer generated CSS into the <head>.
		add_action( 'wp_head', array( $this, 'interico_wp_head_callback' ) );

		// Add a '.custom-colors' <body> class.
		add_filter( 'body_class', array( $this, 'body_class' ) );

		// Add customizer options: panel, sections, settings and controls
		add_action( 'customize_register', array( $this, 'interico_register_theme_customizer' ) );

		// Delete the cached data for this feature.
		add_action( 'update_option_theme_mods_' . get_stylesheet(), array( $this, 'interico_cache_delete' ) );

		// Flush rewrite rules after saving
		add_action( 'customize_save_after', 'flush_rewrite_rules' );

	}

	/**
	 * Adds the 'custom-colors' class to the <body> element.
	 *
	 * @access public
	 * @param  array  $classes
	 * @return array
	 */
	public function body_class( $classes ) {
		$classes[] = 'custom-colors';
		return $classes;
	}

	/**
	 * Callback for 'wp_head' that outputs the CSS for this feature.
	 * @access public
	 */
	public function interico_wp_head_callback() {
		$stylesheet = get_stylesheet();

		// Get the cached style.
		$interico_customizer_style = wp_cache_get( "{$stylesheet}_custom_colors" );

		// If the style is available, output it and return.
		if ( ! empty( $interico_customizer_style ) ) {
			echo $interico_customizer_style; // already sanitized
			return;
		}
		$interico_customizer_style = $this->interico_customizer_styles();

		// Put the final style output together.
		$interico_customizer_style = "\n" . '<style type="text/css" id="custom-colors-css">' . trim( $interico_customizer_style ) . '</style>' . "\n";

		// Cache the style, so we don't have to process this on each page load.
		wp_cache_set( "{$stylesheet}_custom_colors", $interico_customizer_style );

		// Custom CSS set in Customizer
		$custom_css = get_theme_mod( 'tc_custom_css' );

		// Output the custom style.
		echo $interico_customizer_style; // already sanitized

		// Add <style> tags for the Custom CSS
		if ( strlen( $custom_css ) ) {
			echo '<style id="custom-css" type="text/css">' . PHP_EOL;
			echo $custom_css . PHP_EOL; // already sanitized
			echo '</style>' . PHP_EOL;
		}

		// Add inline style
		wp_add_inline_style( 'custom-css', 'interico_customizer_css', 30 );
	}

	/**
	 * Formats the primary styles for output.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string
	 */
	public function interico_customizer_styles() {

		/*-----------------------------------------------------------*
		 * Get the Styles
		 *-----------------------------------------------------------*/

		// Logo
		$tc_logo_top_mrg = get_theme_mod( 'tc_logo_top_mrg', 45 );
		$tc_logo_top_mrg_mobile = get_theme_mod( 'tc_logo_top_mrg_mobile', 35 );
		$tc_logo_width = get_theme_mod( 'tc_logo_width', 320 );
		$tc_logo_width_mobile = get_theme_mod( 'tc_logo_width_mobile', 320 );
		$tc_toggle_top_mobile = get_theme_mod( 'tc_toggle_top_mobile', 20 );

		// Top Contacts Subnav
		$tc_subnav_text = get_theme_mod( 'tc_subnav_text' );
		$tc_subnav_bg = get_theme_mod( 'tc_subnav_bg' );
		$tc_social_icon_bg = interico_adjust_brightness( $tc_subnav_bg, -15 );
		$tc_subnav_icon_color = get_theme_mod( 'tc_subnav_icon_color' );
		$tc_subnav_secondary_nav_alignment = get_theme_mod( 'tc_subnav_secondary_nav_alignment', 'right' );
		$tc_subnav_secondary_nav_width = get_theme_mod( 'tc_subnav_secondary_nav_width' );

		// Navigation
		$tc_header_height = get_theme_mod( 'tc_header_height' );
		$tc_header_height_mobile = get_theme_mod( 'tc_header_height_mobile' );
		$tc_header_link_color = get_theme_mod( 'tc_header_link_color' );
		$tc_header_link_color_hover = get_theme_mod( 'tc_header_link_color_hover' );
		$tc_header_underline_hover = get_theme_mod( 'tc_header_underline_hover' );
		$tc_header_bg = get_theme_mod( 'tc_header_bg' );

		// Navigation 2nd level
		$tc_nav_submenu_bg = get_theme_mod( 'tc_nav_submenu_bg', '#69593e' );
		$tc_nav_submenu_bg_hover = interico_adjust_brightness( $tc_nav_submenu_bg, -15 );
		$tc_header_link_bg_mobile_hover = interico_adjust_brightness( $tc_nav_submenu_bg_hover, -15 );
		$tc_nav_submenu_border = interico_adjust_brightness( $tc_nav_submenu_bg, -15 );
		$tc_nav_submenu_text = get_theme_mod( 'tc_nav_submenu_text', '#ffffff' );
		$tc_nav_submenu_text_hover = interico_adjust_brightness( $tc_nav_submenu_text, 15 );
		
		// Navigation 3rd level
		$tc_nav_sub_submenu_bg = get_theme_mod( 'tc_nav_sub_submenu_bg', '#333333' );
		$tc_nav_sub_submenu_bg_hover = interico_adjust_brightness( $tc_nav_sub_submenu_bg, -15 );
		$tc_nav_sub_submenu_border = interico_adjust_brightness( $tc_nav_sub_submenu_bg, -15 );
		$tc_nav_sub_submenu_text = get_theme_mod( 'tc_nav_sub_submenu_text', '#cccccc' );
		$tc_nav_sub_submenu_text_hover = interico_adjust_brightness( $tc_nav_sub_submenu_text, 15 );

		// Page Top Content Area
		$tc_interico_tca_text = get_theme_mod( 'tc_interico_tca_text', '#ffffff' );
		$tc_interico_subtitle_color = get_theme_mod( 'tc_interico_subtitle_color' );
		$tc_interico_text_color = get_theme_mod( 'tc_interico_text_color' );
		$tc_interico_overlay_color = get_theme_mod( 'tc_interico_overlay_color', '#444444' );
		$tc_interico_overlay_opacity = get_theme_mod( 'tc_interico_overlay_opacity', 30 );
		$tc_interico_overlay_opacity = $tc_interico_overlay_opacity/100;
		$tc_show_grid_lines = get_theme_mod( 'tc_show_grid_lines', 'yes' );

		// General Styling
		$tc_accent_color = get_theme_mod( 'tc_accent_color', '#7d6741' );
		$tc_accent_color_dark = interico_adjust_brightness( $tc_accent_color, -10 );
		$tc_headings_color = get_theme_mod( 'tc_headings_color' );
		$tc_body_text_color = get_theme_mod( 'tc_body_text_color' );
		$tc_slider_span_color = get_theme_mod( 'tc_slider_span_color' );

		$interico_headings_font_css = get_theme_mod( 'interico_headings_font_css' );
		$interico_body_font_css = get_theme_mod( 'interico_body_font_css' );

		// General Styling: Buttons
		$tc_btn_border_radius = get_theme_mod( 'tc_btn_border_radius', 3 );
		$tc_primary_btn_text = get_theme_mod ( 'tc_primary_btn_text', '#ffffff' );
		$tc_primary_btn_text_hover = get_theme_mod ( 'tc_primary_btn_text_hover', '#ffffff' );
		if (!$tc_primary_btn_text_hover) {
			$tc_primary_btn_text_hover = $tc_primary_btn_text;
		}
		$tc_primary_btn_bg = get_theme_mod( 'tc_primary_btn_bg', '#7d6741' );
		$tc_primary_btn_bg_hover = get_theme_mod( 'tc_primary_btn_bg_hover' );
		if (!$tc_primary_btn_bg_hover) {
			$tc_primary_btn_bg_hover = interico_adjust_brightness( $tc_primary_btn_bg, -25 );
		}
		
		$tc_btn_border_width = get_theme_mod( 'tc_btn_border_width', 2 );
		$tc_btn_padding = get_theme_mod( 'tc_btn_padding', 15 );
		$tc_btn_padding_sides = $tc_btn_padding+5;
		$tc_social_icon_bg_color_footer = get_theme_mod( 'tc_social_icon_bg_color_footer', '#aaaaaa' );
		$tc_social_icon_hover_color = get_theme_mod ( 'tc_social_icon_hover_color', '#ffffff' );
		$tc_social_icon_bg_hover_color = get_theme_mod ( 'tc_social_icon_bg_hover_color', '#7d6741' );
		$tc_regular_btn_color = get_theme_mod( 'tc_regular_btn_color' );
		$tc_regular_btn_text = get_theme_mod( 'tc_regular_btn_text', '#999' );
		$tc_regular_btn_text_hover = get_theme_mod( 'tc_regular_btn_text_hover', '#777' );

		// General Styling: Tabs & Accordion
		$tc_tab_heading_color = get_theme_mod( 'tc_tab_heading_color' );
		$tc_tab_content_color = get_theme_mod( 'tc_tab_content_color' );
		$tc_accordion_heading_color = get_theme_mod( 'tc_accordion_heading_color' );
		$tc_accordion_panel_color = get_theme_mod( 'tc_accordion_panel_color' );

		// General Styling: Preloader
		$tc_show_preloader = get_theme_mod( 'tc_show_preloader', 'yes' );
		$tc_preloader_bg = get_theme_mod( 'tc_preloader_bg', '#444' );
		$tc_preloader_circle = get_theme_mod( 'tc_preloader_circle', '#666' );
		$tc_preloader_spinner = get_theme_mod( 'tc_preloader_spinner', '#eee' );

		// Footer CTA
		$tc_footer_cta_text_color_static = get_theme_mod( 'tc_footer_cta_text_color_static', '#333333' );
		$tc_footer_cta_text_color = get_theme_mod( 'tc_footer_cta_text_color', '#ffffff' );
		$tc_footer_cta_bg_static = get_theme_mod( 'tc_footer_cta_bg_static', '#f9f9f9' );
		$tc_footer_cta_bg = get_theme_mod( 'tc_footer_cta_bg', '#7d6741' );
		$tc_footer_cta_border_static = interico_adjust_brightness( $tc_footer_cta_bg_static, -20 );

		// Footer
		$tc_footer_title_color = get_theme_mod( 'tc_footer_title_color', '#999999' );
		$tc_footer_text_color = get_theme_mod( 'tc_footer_text_color', '#aaaaaa' );
		$tc_footer_link_color = get_theme_mod( 'tc_footer_link_color', '#aaaaaa' );
		$tc_footer_text_hover_color = get_theme_mod ( 'tc_footer_text_hover_color', '#ffffff' );
		$tc_footer_bg = get_theme_mod( 'tc_footer_bg' );
		$tc_footer_border = get_theme_mod( 'tc_footer_border', '#000000' );
		$tc_footer_bot_bg = get_theme_mod( 'tc_footer_bot_bg', '#111111' );
		$tc_footer_bot_text = get_theme_mod( 'tc_footer_bot_text', '#666666' );
		$tc_social_icon_footer_bg = interico_adjust_brightness( $tc_footer_bot_bg, -15 );

		// Widget: Image box
		$tc_image_box_hover_bg = get_theme_mod ( 'tc_image_box_hover_bg', '#7d6741' );
		$tc_image_box_headline_hover =  get_theme_mod ( 'tc_image_box_headline_hover', '#7d6741' );

		// Widget: Team member
		$tc_team_headline_hover =  get_theme_mod ( 'tc_team_headline_hover', '#7d6741' );

		// Widget: Blog
		$tc_blog_headline_hover_color =  get_theme_mod ( 'tc_blog_headline_hover_color', '#7d6741' );

		// Widget: Projects Gallery
		$tc_gallery_active_bg = get_theme_mod( 'tc_gallery_active_bg', '#dddddd' ); 
		$tc_gallery_slider_hover_bg = get_theme_mod ( 'tc_gallery_slider_hover_bg', '#7d6741' );
		$tc_slider_arrow_hover_bg = get_theme_mod ( 'tc_slider_arrow_hover_bg', '#7d6741' );
		$tc_gallery_active_text = get_theme_mod( 'tc_gallery_active_text', '#000000' );
		$tc_gallery_bg = get_theme_mod( 'tc_gallery_bg', '#333333' );
		$tc_gallery_regular_text = get_theme_mod( 'tc_gallery_regular_text' );
		$tc_gallery_regular_bg = get_theme_mod( 'tc_gallery_regular_bg' );
		$tc_gallery_regular_bg_hover = interico_adjust_brightness( $tc_gallery_regular_bg, -15 );
		$tc_gallery_button_text = get_theme_mod( 'tc_gallery_button_text' );
		$tc_gallery_button_bg = get_theme_mod( 'tc_gallery_button_bg' );
		$tc_gallery_button_bg_hover = interico_adjust_brightness( $tc_gallery_button_bg, -15 );
		$tc_gallery_item_category_text = get_theme_mod( 'tc_gallery_item_category_text', '#cccccc' );

		// Widget: Feature Box
		$tc_featured_box_icon_color = get_theme_mod( 'tc_featured_box_icon_color', '#7d6741' );
		$tc_featured_box_icon_hover = get_theme_mod( 'tc_featured_box_icon_hover', '#7d6741' );
		$tc_featured_box_headline_color = get_theme_mod( 'tc_featured_box_headline_color' );
		$tc_featured_box_headline_hover_color = get_theme_mod( 'tc_featured_box_headline_hover_color', '#7d6741' );

		// Widget: Number Box
		$tc_number_box_headline_color = get_theme_mod( 'tc_number_box_headline_color' );
		$tc_number_box_headline_hover_color = get_theme_mod( 'tc_number_box_headline_hover_color', '#7d6741' );
		$tc_number_box_number_bg = get_theme_mod( 'tc_number_box_number_bg', '#7d6741' );
		$tc_number_box_number_bg_hover = get_theme_mod( 'tc_number_box_number_bg_hover', '#333333' );

		// Widget: Testimonials
		$tc_testimonial_box_bg = get_theme_mod( 'tc_testimonial_box_bg' );

		// Shop
		$tc_shop_products_columns = get_theme_mod( 'tc_shop_products_columns', 4 );
		if ( $tc_shop_products_columns == 2 ) {
			$shop_column_width = 48;
		} elseif ( $tc_shop_products_columns == 3 ) {
			$shop_column_width = 30.75;
		} elseif ( $tc_shop_products_columns == 4 ) {
			$shop_column_width = 22.05;
		} elseif ( $tc_shop_products_columns == 5 ) {
			$shop_column_width = 16.9;
		} elseif ( $tc_shop_products_columns == 6 ) {
			$shop_column_width = 13.5;
		}

		/*-----------------------------------------------------------*
		 * Apply Customizer Values
		 *-----------------------------------------------------------*/

		// Build the styles
		$interico_style = '';

		// Logo
		$interico_customizer_style = "header #logo { margin-top: {$tc_logo_top_mrg}px; }";
		$interico_customizer_style .= "header #logo img { max-width:{$tc_logo_width}px; }";
		$interico_customizer_style .= "@media screen and (max-width: 990px) { header #logo { margin-top: {$tc_logo_top_mrg_mobile}px; } }";
		$interico_customizer_style .= "@media screen and (max-width: 990px) { header #logo img { max-width:{$tc_logo_width_mobile}px; } }";
		$interico_customizer_style .= "@media screen and (max-width: 990px) { .navbar-toggle { top:{$tc_toggle_top_mobile}px; } }";

		// Top Contacts Subnav
		if ( $tc_subnav_bg ) {
			$interico_customizer_style .= ".header-style-2.subnav-dark .header-wrapper, .header-style-2.subnav-light .header-wrapper { background-color: {$tc_subnav_bg}!important; }";
			$interico_customizer_style .= ".subnav-dark .subnav, .subnav-light .subnav { background-color: {$tc_subnav_bg}; }";
			$interico_customizer_style .= ".subnav-light.subnav-angular .subnav::before, .subnav-dark.subnav-angular .subnav::before { border-right-color: {$tc_subnav_bg}!important; }";
			$interico_customizer_style .= ".subnav-light.subnav-angular .subnav::after, .subnav-dark.subnav-angular .subnav::after { border-top-color: {$tc_subnav_bg}!important; }";
			$interico_customizer_style .= ".subnav .social i, .subnav-light .subnav .social i, .subnav-light .social i { background-color: {$tc_social_icon_bg}; }";
		}
		if ( $tc_subnav_text ) {
			$interico_customizer_style .= ".subnav-item p, .subnav-item a, .subnav-item i, .subnav-item p span { color: {$tc_subnav_text}; }";
			$interico_customizer_style .= ".subnav-light .subnav-item p, .subnav-light .subnav-item a, .subnav-light .subnav-item i, .subnav-light .subnav-item p span { color: {$tc_subnav_text}; }";
		}

		if ( $tc_subnav_icon_color ) {
			$interico_customizer_style .= ".subnav .subnav-item .fa { color: {$tc_subnav_icon_color}; }";
		}

		if ( $tc_subnav_secondary_nav_alignment ) {
			$interico_customizer_style .= ".nav-secondary .sub-menu li a { text-align: {$tc_subnav_secondary_nav_alignment}; }";
		}

		if ( $tc_subnav_secondary_nav_width ) {
			$interico_customizer_style .= ".nav-secondary .sub-menu li a { min-width: {$tc_subnav_secondary_nav_width}px; }";
		}

		// Header
		if ( $tc_header_height ) {
			$interico_customizer_style .= ".header-style-1 #header #mainmenu > li > a, .header-style-2 #header #mainmenu > li > a, .header-style-2 #header, .header-style-3 #header #mainmenu > li > a, .header-style-5 #header #mainmenu > li > a { line-height: {$tc_header_height}px; } .header-style-1 #header, .header-style-2 #header, .header-style-3 #header, .header-style-5 #header { min-height: {$tc_header_height}px; } .header-style-3 #mainmenu > li > a { padding-top: 0; padding-bottom: 0; }";
		}

		if ( $tc_header_height_mobile ) {
			$interico_customizer_style .= "@media screen and (max-width: 990px) { .header-style-1 #header #mainmenu > li > a, .header-style-2 #header #mainmenu > li > a, .header-style-2 #header, .header-style-3 #header #mainmenu > li > a, .header-style-5 #header #mainmenu > li > a { line-height: {$tc_header_height_mobile}px; } .header-style-1 #header, .header-style-2 #header, .header-style-3 #header, .header-style-5 #header { min-height: {$tc_header_height_mobile}px; } .header-style-3 #mainmenu > li > a { padding-top: 0; padding-bottom: 0; } }";
		}

		if ( $tc_header_link_color ) {
			$interico_customizer_style .= "#mainmenu > li > a, #mainmenu > li.menu-item-has-children:after { color: {$tc_header_link_color}!important; }";
		}
		if ( $tc_header_link_color_hover ) {
			$interico_customizer_style .= "#mainmenu > li > a:hover, #mainmenu > li.menu-item-has-children:hover:after, #mainmenu > li:hover > a, #header.header-light #mainmenu > li:hover > a, #header.header-light #mainmenu > li.menu-item-has-children:hover:after { color: {$tc_header_link_color_hover}!important; }";
		}

		if ( $tc_header_underline_hover ) {
			$interico_customizer_style .= "@media screen and (min-width: 991px) { #mainmenu > li:before { background-color: {$tc_header_underline_hover}; } }";
		}
		
		if ( $tc_header_bg ) {
			$interico_customizer_style .= "#header, #header.header-light { background-color: {$tc_header_bg}; }";
			$interico_customizer_style .= ".header-style-3 #header, .header-style-3 #header.header-light { background: linear-gradient(to bottom, {$tc_header_bg} 0%, transparent 100%)!important; }";
		}

		// Navigation 2nd level
		if ( $tc_nav_submenu_text ) {
			$interico_customizer_style .= "#mainmenu li ul li a { color: {$tc_nav_submenu_text}!important; }";
			$interico_customizer_style .= "#mainmenu li ul li a:hover { color: {$tc_nav_submenu_text_hover}!important; }";
			// Mobile Navigation
			$interico_customizer_style .= "@media screen and (max-width: 990px) { #mainmenu > li > a { color: {$tc_nav_submenu_text}!important; } }";
			$interico_customizer_style .= "@media screen and (max-width: 990px) { #mainmenu > li.menu-item-has-children:after, #header.header-light #mainmenu > li.menu-item-has-children::after { color: {$tc_nav_submenu_text}!important; } }";

		}
		if ( $tc_nav_submenu_bg ) {
			$interico_customizer_style .= "#mainmenu li ul li a { background-color: {$tc_nav_submenu_bg}!important; }";
			$interico_customizer_style .= "#mainmenu li ul li a:hover { background-color: {$tc_nav_submenu_bg_hover}!important; }";
			$interico_customizer_style .= "#mainmenu li ul li, #mainmenu ul { border-color: {$tc_nav_submenu_border}!important; }";
			// Mobile Navigation
			$interico_customizer_style .= "@media screen and (max-width: 990px) { #mainmenu > li > a, .header-style-3 #header #mainmenu > li > a { background: {$tc_nav_submenu_border}; border-color: {$tc_header_link_bg_mobile_hover}!important; } }";
			$interico_customizer_style .= "@media screen and (max-width: 990px) { #mainmenu > li.menu-item-has-children:after, #header.header-light #mainmenu > li.menu-item-has-children::after { background-color: {$tc_header_link_bg_mobile_hover}!important; } }";
		}

		// Navigation 3rd level
		if ( $tc_nav_sub_submenu_text ){
			$interico_customizer_style .= "#mainmenu li ul li ul li a { color: {$tc_nav_sub_submenu_text}!important; }";
			$interico_customizer_style .= "#mainmenu li ul li ul li a:hover { color: {$tc_nav_sub_submenu_text_hover}!important; }";
			// Mobile navigation
			$interico_customizer_style .= "@media screen and (max-width: 990px) { #mainmenu > li > a:hover { color: {$tc_nav_sub_submenu_text}!important; } }";
			$interico_customizer_style .= "@media screen and (max-width: 990px) { #mainmenu > li.menu-item-has-children:hover:after, #header.header-light #mainmenu > li.menu-item-has-children:hover:after { color: {$tc_nav_sub_submenu_text}!important; } }";

		}
		if ( $tc_nav_sub_submenu_bg ) {
			$interico_customizer_style .= "#mainmenu li ul li ul li a { background-color: {$tc_nav_sub_submenu_bg}!important; }";
			$interico_customizer_style .= "#mainmenu li ul li ul li a:hover { background-color: {$tc_nav_sub_submenu_bg_hover}!important; }";
			$interico_customizer_style .= "#mainmenu li ul li ul li, #mainmenu ul li ul { border-color: {$tc_nav_sub_submenu_border}!important; }";
			// Mobile navigation
			$interico_customizer_style .= "@media screen and (max-width: 990px) { #mainmenu > li > a:hover { background-color: {$tc_header_link_bg_mobile_hover}!important; border-color: {$tc_header_link_bg_mobile_hover}!important; } }";
			$interico_customizer_style .= "@media screen and (max-width: 990px) { #mainmenu { border-bottom-color: {$tc_header_link_bg_mobile_hover}!important; } }";
		}

		// Page Top Content Area
		if ( $tc_interico_tca_text ) {
			$interico_customizer_style .= "#top-content-area .title-content h1 { color: {$tc_interico_tca_text}; }";
		}
		if ( $tc_interico_subtitle_color ) {
			$interico_customizer_style .= "#top-content-area .page-subtitle { color: {$tc_interico_subtitle_color}; }";
		}
		if ( $tc_interico_text_color ) {
			$interico_customizer_style .= "#top-content-area .title-content-text { color: {$tc_interico_text_color}; }";
			$interico_customizer_style .= "#top-content-area .title-content-text:before { background-color: {$tc_interico_text_color}; }";
		}
		if ( $tc_interico_overlay_color && $tc_interico_overlay_opacity ) {
			$interico_customizer_style .= "#top-content-area .overlay { background-color: {$tc_interico_overlay_color}; opacity: {$tc_interico_overlay_opacity}; }";
		}

		if ( $interico_body_font_css ) {
			$interico_customizer_style .= "body { font-family: {$interico_body_font_css}; }";			
		}

		if ( $interico_headings_font_css ) {
			$interico_customizer_style .= "h1, h2, h3, h4, h5, h6 { font-family: {$interico_headings_font_css}; }";			
		}

		if ( $tc_show_grid_lines === 'no' ) {
			$interico_customizer_style .= "#top-content-area .lines-overlay { display: none; }";
		}

		// General Styling: Button padding, border width and radius
		$interico_customizer_style .= ".btn, .btn-primary, .btn-regular, input[type='submit'], .woocommerce button[type='submit'], .woocommerce #respond input#submit, .woocommerce a.button, .woocommerce button.button, .woocommerce input.button, .woocommerce button.button.alt, .woocommerce #respond input#submit.alt, .woocommerce a.button.alt, .woocommerce button.button.alt, .woocommerce input.button.alt, .woocommerce button[type='submit'] { border-width: {$tc_btn_border_width}px!important; padding: {$tc_btn_padding}px {$tc_btn_padding_sides}px; border-radius: {$tc_btn_border_radius}px; }";

		// General Styling: Border radius for special buttons
		if ($tc_btn_border_radius) {
			$interico_customizer_style .= ".woocommerce button[type='submit'] { border-bottom-right-radius: {$tc_btn_border_radius}px; border-top-right-radius: {$tc_btn_border_radius}px; }";
		}

		// General Styling: Primary Button (Colors)
		if ( $tc_primary_btn_bg ) {
			$interico_customizer_style .= ".btn-primary, input[type=submit], input[type='submit'], .woocommerce button[type='submit'], .woocommerce #respond input#submit, .woocommerce a.button, .woocommerce button.button, .woocommerce input.button, .woocommerce button.button.alt, .woocommerce #respond input#submit.alt, .woocommerce a.button.alt, .woocommerce button.button.alt, .woocommerce input.button.alt, .woocommerce button[type='submit'] { color: {$tc_primary_btn_text}!important; background-color: {$tc_primary_btn_bg}!important; border-color: {$tc_primary_btn_bg}!important; }";
		}

		if ( $tc_primary_btn_bg ) {
			$interico_customizer_style .= "
				.btn-primary:active:hover,
				.btn-primary:active:focus,
				.btn-primary:hover,
				.btn-primary:focus,
				.btn-primary:active,
				input[type=submit]:hover,
				input[type=submit]:focus,
				input[type='submit']:hover,
				input[type='submit']:focus,
				.woocommerce button[type='submit']:hover,
				.woocommerce button[type='submit']:focus,
				.woocommerce #respond input#submit.alt:hover,
				.woocommerce a.button.alt:hover,
				.woocommerce button.button:hover,
				.woocommerce button.button.alt:hover,
				.woocommerce input.button:hover
				.woocommerce input.button.alt:hover,
				.woocommerce #respond input#submit:hover,
				.btn-primary:before, a.btn-primary:before,
				.woocommerce a.button:hover { color: {$tc_primary_btn_text_hover}!important; background-color: {$tc_primary_btn_bg_hover}!important; border-color: {$tc_primary_btn_bg_hover}!important; }";
		}

		// General styling: Regular button
		if ( $tc_regular_btn_color ) {
			$interico_customizer_style .= ".btn-regular { color: {$tc_regular_btn_text}; border-color: {$tc_regular_btn_color}!important; }";
			$interico_customizer_style .= ".btn-regular:hover, .btn-regular:focus, .btn-regular:active { background-color: {$tc_regular_btn_color}; border-color: {$tc_regular_btn_color}!important; }";
		}
		if ( $tc_regular_btn_text_hover ) {
			$interico_customizer_style .= ".btn-regular:hover, .btn-regular:focus, .btn-regular:active { color: {$tc_regular_btn_text_hover}; }";
		}

		// General Styling: Accent Color
		if ( $tc_accent_color ) {
			$interico_customizer_style .= "
			main ul li::before,
			.content ul li::before,
			.panel-body ul li::before,
			.page-content ul li:before,
			.tab-content ul li:before,
			.divider-light::before,
			.divider-dark::before,
			.read-more-dark::before,
			.read-more::before,
			.subtitle.style-dark::before,
			.dash.style-dark,
			.toggled,
			::selection,
			::-moz-selection,
			.tooltip-inner,
			.reply:hover:before { background-color: {$tc_accent_color}; }";

			$interico_customizer_style .= "blockquote { border-color: {$tc_accent_color}; }";
			$interico_customizer_style .= "a:hover, .post-info a:hover, .body-dark .post-info a:hover, .subtitle, .number-box:hover .btn-read-more, .number-box:hover .btn-read-more::after, .feature-box:hover .btn-read-more, .feature-box:hover .btn-read-more::after, .content-box.service-item:hover .btn-read-more, .content-box.service-item:hover .btn-read-more::after, .btn-read-more:hover, .body-dark .btn-read-more:hover, .blog-post-box:hover .btn-read-more, .blog-post-box:hover .btn-read-more::after, .btn-read-more:hover::after, .comments .testimonial.image-left .content-box-info .testimonial-content span.name, .reply:hover a.comment-reply-link, .sidebar-nav ul li a:hover, .sidebar-heading, .body-dark .sidebar-heading, .projects-navigation a:hover, .body-dark .projects-navigation a:hover, .projects-navigation .icon-icon-gallery:hover:before, .title-link-box.dark .btn-read-more:hover, .title-link-box.dark .btn-read-more:hover::after, .body-dark .title-link-box .btn-read-more:hover, .body-dark .title-link-box .btn-read-more:hover::after { color: {$tc_accent_color}; }";
			$interico_customizer_style .= ".nav-tabs.style-accent > li.active > a,.nav-tabs.style-accent > li.active > a:hover,.nav-tabs.style-accent > li.active > a:focus, .panel-group .accordion-toggle[aria-expanded='true'], .panel-group .accordion-toggle[aria-expanded='true']:hover { background-color: {$tc_accent_color}!important; }";
			$interico_customizer_style .= ".panel-body, .tab-content.style-accent { background-color: {$tc_accent_color_dark}; }";
			$interico_customizer_style .= ".subtitle::before, .dash { opacity: 0.75; }";
			$interico_customizer_style .= ".tooltip.top .tooltip-arrow { border-top-color: {$tc_accent_color}; }";
		}

		if ( $tc_tab_heading_color ) {
			$interico_customizer_style .= ".nav-tabs.style-accent > li.active > a, .nav-tabs.style-accent > li.active > a:hover, .nav-tabs.style-accent > li.active > a:focus, .body-dark .shadow-box .nav-tabs > li.active > a, .body-dark .nav-tabs > li.active > a { background-color: {$tc_tab_heading_color}!important; }";
		}

		if ( $tc_accordion_heading_color ) {
			$interico_customizer_style .= ".panel-group a.accordion-toggle[aria-expanded='true'], .panel-group a.accordion-toggle[aria-expanded='true']:hover, .panel-group a.accordion-toggle[aria-expanded='true']:focus, .panel-group.dark a.accordion-toggle[aria-expanded='true'], .panel-group.dark a.accordion-toggle[aria-expanded='true']:hover, .panel-group.dark a.accordion-toggle[aria-expanded='true']:focus { background-color: {$tc_accordion_heading_color}!important; }";
		}

		if ( $tc_tab_content_color ) {
			$interico_customizer_style .= ".tab-content.style-accent { background-color: {$tc_tab_content_color}!important; }";
		}

		if ( $tc_accordion_panel_color ) {
			$interico_customizer_style .= ".panel-body { background-color: {$tc_accordion_panel_color}!important; }";
		}

		// General Styling: Social Media icons
		$interico_customizer_style .= ".social i:hover, #footer-bot .social i:hover { color: {$tc_social_icon_hover_color}; background-color: {$tc_social_icon_bg_hover_color}; }";

		// General Styling: Fonts
		if ($tc_headings_color) {
			$interico_customizer_style .= "h1, h2, blockquote, .entry-title a, .entry-title, .body-dark h1, .body-dark h2, .body-dark blockquote, .body-dark .entry-title a, .body-dark .entry-title, .shadow-box.light h1, .shadow-box.light h2, .shadow-box.dark h1, .shadow-box.dark h2 { color: {$tc_headings_color}; }";
		}
		
		if ( $tc_body_text_color ) {
			$interico_customizer_style .= "body, .feature-box p.feature-text, .content-box-info p, .woocommerce div.product .summary p, body.body-dark, .body-dark .feature-box p.feature-text, .body-dark .content-box-info p, .body-dark .body-dark.woocommerce div.product .summary p { color: {$tc_body_text_color}; }";
		}

		if ( $tc_slider_span_color ) {
			$interico_customizer_style .= ".slide-title h1 span, .slide-title h2 span { font-weight: inherit; font-style: unset; color: {$tc_slider_span_color}; }";
		}

		// General Styling: Preloader
		if ( $tc_show_preloader === 'no' ) {
			$interico_customizer_style .= ".preloader-wrapper { display: none; }";
		}

		if ( $tc_preloader_bg ) {
			$interico_customizer_style .= ".preloader-wrapper.dark { background: {$tc_preloader_bg}; }";
		}

		if ( $tc_preloader_circle ) {
			$interico_customizer_style .= ".preloader-wrapper.dark .preloader { border-color: {$tc_preloader_circle}; }";
		}

		if ( $tc_preloader_spinner ) {
			$interico_customizer_style .= ".preloader-wrapper.dark .preloader { border-top-color: {$tc_preloader_spinner}; }";
		}

		// Footer CTA
		$interico_customizer_style .= "a.cta-footer { background-color: {$tc_footer_cta_bg_static}; border-top-color: {$tc_footer_cta_border_static}; }";
		$interico_customizer_style .= "a.cta-footer:hover {  background-color: {$tc_footer_cta_bg}; border-top-color: {$tc_footer_cta_bg}; }";
		$interico_customizer_style .= "a.cta-footer h2, a.cta-footer h2::after { color: {$tc_footer_cta_text_color_static}!important; }";
		$interico_customizer_style .= "a.cta-footer:hover h2, a.cta-footer:hover h2::after { color: {$tc_footer_cta_text_color}!important; }";

		// Footer
		if ( $tc_footer_title_color ) {
			$interico_customizer_style .= "#footer h4.footer-header { color: {$tc_footer_title_color}; }";
			$interico_customizer_style .= "#footer.footer-dark h4.footer-header { color: {$tc_footer_title_color}; }";
		}

		if ( $tc_footer_text_color ) {
			$interico_customizer_style .= "#footer, #footer ul li { color: {$tc_footer_text_color}; }";
			$interico_customizer_style .= "#footer.footer-dark, #footer.footer-dark ul li { color: {$tc_footer_text_color}; }";
		}

		if ( $tc_footer_link_color ) {
			$interico_customizer_style .= "#footer a, #footer ul li a, ul.content-list a, #footer ul li:before { color: {$tc_footer_link_color}; }";
			$interico_customizer_style .= "#footer.footer-dark a, #footer.footer-dark ul li a, #footer.footer-dark ul.content-list a, #footer.footer-dark ul li:before { color: {$tc_footer_link_color}; }";
		}

		if ( $tc_footer_text_hover_color ) {
			$interico_customizer_style .= "#footer a:hover, #footer ul li a:hover, ul.content-list a:hover, ul.content-list li:hover, #footer ul li:hover:before { color: {$tc_footer_text_hover_color}; }";
			$interico_customizer_style .= "#footer.footer-dark a:hover, #footer.footer-dark ul li a:hover, footer.footer-dark ul.content-list a:hover, footer.footer-dark ul.content-list li:hover, #footer.footer-dark ul li:hover:before { color: {$tc_footer_text_hover_color}; }";	
		}

		if ( $tc_footer_bg ) {
			$interico_customizer_style .= "#footer, #footer.footer-dark, #footer.footer-light { background-color: {$tc_footer_bg}; }";
		}
		
		$interico_customizer_style .= "#footer-bot { background-color: {$tc_footer_bot_bg}; color: {$tc_footer_bot_text}; }";
		$interico_customizer_style .= "#footer-bot .social i { color:{$tc_social_icon_bg_color_footer}; background-color: {$tc_social_icon_footer_bg}; }";

		// Widget: Image Box
		if ( $tc_image_box_hover_bg ) {
			$interico_customizer_style .= ".content-box.service-item.service-box-dark .content-box-info:after { background-color: {$tc_image_box_hover_bg}; }";
		}

		if ( $tc_image_box_headline_hover ) {
			$interico_customizer_style .= ".content-box.service-item.service-box-default:hover .box-heading, .content-box.service-item.service-box-white:hover .box-heading, .body-dark .content-box.service-item.service-box-default:hover .box-heading, .body-dark .content-box.service-item.service-box-white:hover .box-heading, .content-box.service-item.service-box-gray:hover h4.box-heading, .body-dark .content-box.service-item.service-box-gray:hover h4.box-heading { color: {$tc_image_box_headline_hover}; }";
		}

		// Widget: Team member
		if ( $tc_team_headline_hover ) {
			$interico_customizer_style .= ".team-member:hover h4 { color: {$tc_team_headline_hover}; }";
		}

		// Widget: Blog
		if ( $tc_blog_headline_hover_color ) {
			$interico_customizer_style .= ".blog-post-box:hover .content-box-info .box-heading, .entry-title a:hover { color: {$tc_blog_headline_hover_color}; }";
		}
				
		// Widget: Projects Gallery
		if ( $tc_gallery_active_text ) {
			$interico_customizer_style .= ".gallery-categories ul li a.selected, .section-gallery.gallery-light .gallery-categories ul li a.selected, .section-gallery.gallery-light .gallery-categories ul li a.selected:hover, .gallery-categories ul li a.selected:hover  { color: {$tc_gallery_active_text}; }";
		}

		if ( $tc_gallery_slider_hover_bg ) {
			$interico_customizer_style .= ".captions-bottom .portfolio-box-caption-content::after { background-color: {$tc_gallery_slider_hover_bg}; }";
		}

		if ( $tc_slider_arrow_hover_bg ) {
			$interico_customizer_style .= ".carousel-control:after, #gallery-slider .slick-prev:after, #gallery-slider .slick-next:after { background-color: {$tc_slider_arrow_hover_bg}; }";
		}

		if ( $tc_gallery_active_bg ) {
			$interico_customizer_style .= ".gallery-categories ul li a.selected, .section-gallery.gallery-light .gallery-categories ul li a.selected, .section-gallery.gallery-light .gallery-categories ul li a.selected:hover, .gallery-categories ul li a.selected:hover  { background-color: {$tc_gallery_active_bg}; }";
		}
		
		if ( $tc_gallery_regular_bg ) {
			$interico_customizer_style .= ".gallery-categories ul li a, .section-gallery.gallery-light .gallery-categories ul li a { background-color: {$tc_gallery_regular_bg}; }";
			$interico_customizer_style .= ".gallery-categories ul li a:hover, .section-gallery.gallery-light .gallery-categories ul li a:hover  { background-color: {$tc_gallery_regular_bg_hover}; }";
		}
		if ( $tc_gallery_regular_text ) {
			$interico_customizer_style .= ".gallery-categories ul li a, .section-gallery.gallery-light .gallery-categories ul li a, .gallery-categories ul li a:hover { color: {$tc_gallery_regular_text}; }";
		}
		
		if ( $tc_gallery_button_text ) {
			$interico_customizer_style .= "a.btn-all-projects, .btn-all-projects::after, .btn-all-projects:hover, .btn-all-projects:hover:after, .section-gallery.gallery-light a.btn-all-projects, .section-gallery.gallery-light a.btn-all-projects:hover, .section-gallery.gallery-light a.btn-all-projects:hover:after, .section-gallery.gallery-light a.btn-all-projects:after { color: {$tc_gallery_button_text}; }";
		}
		if ( $tc_gallery_button_bg ) {
			$interico_customizer_style .= "a.btn-all-projects, .section-gallery.gallery-light a.btn-all-projects  { background-color: {$tc_gallery_button_bg}; }";
			$interico_customizer_style .= "a.btn-all-projects:hover, .section-gallery.gallery-light a.btn-all-projects:hover { background-color: {$tc_gallery_button_bg_hover}; }";
		}
		if ( $tc_gallery_bg ) {
			$interico_customizer_style .= ".section-gallery, .section-gallery.gallery-light .section-gallery { background-color: {$tc_gallery_bg}; }";
		}
		if ( $tc_gallery_item_category_text ) {
			$interico_customizer_style .= ".project-category { color: {$tc_gallery_item_category_text}; }";
		}

		// Widget: Feature Box
		if ( $tc_featured_box_icon_color ) {
			$interico_customizer_style .= ".feature-box > i, .feature-box > .lnr { color: {$tc_featured_box_icon_color}; }";
		}
		if ( $tc_featured_box_icon_hover ) {
			$interico_customizer_style .= ".feature-box:hover > i, .feature-box:hover > .lnr { color: {$tc_featured_box_icon_hover}; }";
		}
		if ( $tc_featured_box_headline_color ) {
			$interico_customizer_style .= ".feature-box .feature-title, .feature-box.dark .feature-title, .body-dark .feature-box.dark .feature-title, .feature-box.dark .feature-title, .body-dark .feature-title, .feature-box .feature-title { color: {$tc_featured_box_headline_color}; }";
		}
		if ( $tc_featured_box_headline_hover_color ) {
			$interico_customizer_style .= ".feature-box:hover .feature-title, .feature-box.dark:hover .feature-title { color: {$tc_featured_box_headline_hover_color}; }";
		}

		// Widget: Number Box
		if ( $tc_number_box_headline_color ) {
			$interico_customizer_style .= ".number-box h3, .number-box.style-dark h3 { color: {$tc_number_box_headline_color}; }";
		}
		if ( $tc_number_box_headline_hover_color ) {
			$interico_customizer_style .= ".number-box:hover h3, .number-box.style-dark:hover h3 { color: {$tc_number_box_headline_hover_color}; }";
		}
		if ( $tc_number_box_number_bg ) {
			$interico_customizer_style .= ".number-box-number { background-color: {$tc_number_box_number_bg}; }";
		}

		if ( $tc_number_box_number_bg_hover ) {
			$interico_customizer_style .= ".number-box.style-default .number-box-number:after { background: {$tc_number_box_number_bg_hover}; }";
			$interico_customizer_style .= ".number-box.style-dark .number-box-number { color: {$tc_number_box_number_bg_hover}; }";
		}

		// Widget: Testimonials
		if ( $tc_testimonial_box_bg ) {
			$interico_customizer_style .= ".testimonial.testimonial-dark .content-box { background: {$tc_testimonial_box_bg}; }";
		}
		
			

		// Shop
		$interico_customizer_style .= "@media screen and (min-width: 768px) { .woocommerce ul.products > li.product, .woocommerce-page ul.products > li.product { width: {$shop_column_width}%; } }";

		return str_replace( array( "\r", "\n", "\t" ), '', $interico_customizer_style );
	}


	/**
	 * Registers options with the Theme Customizer
	 *
	 * @access public
	 */
	public function interico_register_theme_customizer( $wp_customize ) {
		
		/*-----------------------------------------------------------*
		 * Defining 'interico Options' panel
		 *-----------------------------------------------------------*/

		$wp_customize->add_panel( 'tc_interico_options',
			array(
				'title'    => esc_html__( 'Interico Options', 'interico' ),
				'priority' => 10
			)
		);

		/*-----------------------------------------------------------*
		 * Sections for the 'Interico Options' panel
		 * 1. Logo
		 *-----------------------------------------------------------*/

		$wp_customize->add_section( 'tc_interico_logo_section',
			array(
				'title'       	=> esc_html__( 'Logo', 'interico' ),
				'description' 	=> esc_html__( 'Logo settings.', 'interico' ),
				'priority'    	=> 10,
				'panel'       	=> 'tc_interico_options',
			)
		);

			$wp_customize->add_setting( 'tc_logo_img' ,
				array( 
					'default' 			=> get_template_directory_uri() . '/img/logo-white.png',
					'transport'			=> 'refresh',
					'type'				=> 'theme_mod',
					'capability'		=> 'edit_theme_options',
					'sanitize_callback' => 'esc_url_raw',
				)
			);
			$wp_customize->add_control( new WP_Customize_Image_Control( 
				$wp_customize, 'tc_logo_img',
					array(
			            'label' 	 	=> esc_html__( 'Logo Image', 'interico' ),
			            'description' 	=> esc_html__( 'Recommended height: 90 pixels', 'interico' ),
			            'section' 	 	=> 'tc_interico_logo_section',
			            'settings' 	 	=> 'tc_logo_img',
						'priority'   	=> 5,
					)
				)
			);

			$wp_customize->add_setting( 'tc_logo_img_2x', 
				array( 
					'default' 			=> get_template_directory_uri() . '/img/logo-white2x.png',
					'transport'			=> 'refresh',
					'type'				=> 'theme_mod',
					'capability'		=> 'edit_theme_options',
					'sanitize_callback' => 'esc_url_raw',
				)
			);
			$wp_customize->add_control( new WP_Customize_Image_Control(
				$wp_customize, 'tc_logo_img_2x',
					array(
		            	'label' 	 	=> esc_html__( 'High Res logo (2x)', 'interico' ),
			            'description' 	=> esc_html__( '2x size of original logo for high DPI screens', 'interico' ),
			            'section' 	 	=> 'tc_interico_logo_section',
			            'settings' 	 	=> 'tc_logo_img_2x',
						'priority'   	=> 10,
					) 
				)
			);

			$wp_customize->add_setting( 'tc_logo_top_mrg', 
					array(
						'default'			=> 35,
				    	'transport'			=> 'refresh',
				    	'type'				=> 'theme_mod',
				    	'capability'		=> 'edit_theme_options',
				    	'sanitize_callback' => 'interico_sanitize_text',
					)
				);
			$wp_customize->add_control( 'tc_logo_top_mrg', 
				array(
				    'label' 			=> esc_html__( 'Top Margin Logo', 'interico'),
				    'description' 		=> esc_html__( 'Adjust logo vertical position by pixels.', 'interico' ),
			    	'type'		        => 'number',
				    'section' 			=> 'tc_interico_logo_section',
				    'settings' 			=> 'tc_logo_top_mrg',
				    'priority' 			=> 15,
				    'input_attrs' 		=> array(
						'min' 		=> 0,
						'max'  		=> 100,
						'step' 		=> 1,
					),
				)
			);

			$wp_customize->add_setting( 'tc_logo_top_mrg_mobile', 
					array(
						'default'			=> 35,
				    	'transport'			=> 'refresh',
				    	'type'				=> 'theme_mod',
				    	'capability'		=> 'edit_theme_options',
				    	'sanitize_callback' => 'interico_sanitize_text',
					)
				);
			$wp_customize->add_control( 'tc_logo_top_mrg_mobile', 
				array(
				    'label' 			=> esc_html__( 'Top Margin Logo Mobile', 'interico'),
				    'description' 		=> esc_html__( 'Adjust logo vertical position by pixels.', 'interico' ),
			    	'type'		        => 'number',
				    'section' 			=> 'tc_interico_logo_section',
				    'settings' 			=> 'tc_logo_top_mrg_mobile',
				    'priority' 			=> 15,
				    'input_attrs' 		=> array(
						'min' 		=> 0,
						'max'  		=> 100,
						'step' 		=> 1,
					),
				)
			);

			$wp_customize->add_setting( 'tc_logo_width', 
					array(
						'default'			=> 320,
				    	'transport'			=> 'refresh',
				    	'type'				=> 'theme_mod',
				    	'capability'		=> 'edit_theme_options',
				    	'sanitize_callback' => 'interico_sanitize_text',
					)
				);
			$wp_customize->add_control( 'tc_logo_width', 
				array(
				    'label' 			=> esc_html__( 'Logo Width', 'interico'),
				    'description' 		=> esc_html__( 'Adjust logo maximum width for mobile devices.', 'interico' ),
			    	'type'		        => 'number',
				    'section' 			=> 'tc_interico_logo_section',
				    'settings' 			=> 'tc_logo_width',
				    'priority' 			=> 15,
				    'input_attrs' 		=> array(
						'min' 		=> 0,
						'max'  		=> 320,
						'step' 		=> 1,
					),
				)
			);

			$wp_customize->add_setting( 'tc_logo_width_mobile', 
					array(
						'default'			=> 320,
				    	'transport'			=> 'refresh',
				    	'type'				=> 'theme_mod',
				    	'capability'		=> 'edit_theme_options',
				    	'sanitize_callback' => 'interico_sanitize_text',
					)
				);
			$wp_customize->add_control( 'tc_logo_width_mobile', 
				array(
				    'label' 			=> esc_html__( 'Logo Width Mobile', 'interico'),
				    'description' 		=> esc_html__( 'Adjust logo maximum width for mobile devices.', 'interico' ),
			    	'type'		        => 'number',
				    'section' 			=> 'tc_interico_logo_section',
				    'settings' 			=> 'tc_logo_width_mobile',
				    'priority' 			=> 15,
				    'input_attrs' 		=> array(
						'min' 		=> 0,
						'max'  		=> 320,
						'step' 		=> 1,
					),
				)
			);

			$wp_customize->add_setting( 'tc_toggle_top_mobile', 
					array(
						'default'			=> 20,
				    	'transport'			=> 'refresh',
				    	'type'				=> 'theme_mod',
				    	'capability'		=> 'edit_theme_options',
				    	'sanitize_callback' => 'interico_sanitize_text',
					)
				);
			$wp_customize->add_control( 'tc_toggle_top_mobile', 
				array(
				    'label' 			=> esc_html__( 'Mobile Toggle Top Position', 'interico'),
				    'description' 		=> esc_html__( 'Adjust toggle top position for mobile devices.', 'interico' ),
			    	'type'		        => 'number',
				    'section' 			=> 'tc_interico_logo_section',
				    'settings' 			=> 'tc_toggle_top_mobile',
				    'priority' 			=> 15,
				    'input_attrs' 		=> array(
						'min' 		=> 0,
						'max'  		=> 100,
						'step' 		=> 1,
					),
				)
			);

		/*-----------------------------------------------------------*
		 * 2. Top Contacts Subnav
		 *-----------------------------------------------------------*/

		$wp_customize->add_section( 'tc_interico_subnav_section',
			array(
				'title'       	=> esc_html__( 'Top Subnav', 'interico' ),
				'description' 	=> esc_html__( 'Manage content, visibility and color settings. To find icons, visit http://fontawesome.io', 'interico' ),
				'priority'    	=> 10,
				'panel'       	=> 'tc_interico_options',
			)
		);

			// Top Contacts Bar Settings
			$wp_customize->add_setting( 'tc_subnav',
				array(
		        	'default'  			=> 'no',
		        	'transport'			=> 'refresh',
		        	'type'				=> 'theme_mod',
		        	'capability'		=> 'edit_theme_options',
		        	'sanitize_callback' => 'interico_sanitize_select',
		    	)
			);
			$wp_customize->add_control( 'tc_subnav',
				array(
					'label'				=> esc_html__( 'Show Top Contacts Subnav', 'interico' ),
					'section'			=> 'tc_interico_subnav_section',
					'settings'			=> 'tc_subnav',
					'type'				=> 'select',
					'choices'			=> array(
						'yes'			=> esc_html__( 'Yes', 'interico' ),
						'no'			=> esc_html__( 'No', 'interico' ),
					),
					'priority' 			=> 5,
				)
			);

			// Top Contacts Bar Settings
			$wp_customize->add_setting( 'tc_subnav_hide_mobile',
				array(
		        	'default'  			=> 'yes',
		        	'transport'			=> 'refresh',
		        	'type'				=> 'theme_mod',
		        	'capability'		=> 'edit_theme_options',
		        	'sanitize_callback' => 'interico_sanitize_select',
		    	)
			);
			$wp_customize->add_control( 'tc_subnav_hide_mobile',
				array(
					'label'				=> esc_html__( 'Hide Subnav on Mobile', 'interico' ),
					'section'			=> 'tc_interico_subnav_section',
					'settings'			=> 'tc_subnav_hide_mobile',
					'type'				=> 'select',
					'choices'			=> array(
						'yes'			=> esc_html__( 'Yes', 'interico' ),
						'no'			=> esc_html__( 'No', 'interico' ),
					),
					'priority' 			=> 10,
				)
			);

			$wp_customize->add_setting( 'tc_subnav_color_scheme',
				array(
		        	'default'  			=> 'subnav-dark',
		        	'transport'			=> 'refresh',
		        	'type'				=> 'theme_mod',
		        	'capability'		=> 'edit_theme_options',
		        	'sanitize_callback' => 'interico_sanitize_select',
		    	)
			);
			$wp_customize->add_control( 'tc_subnav_color_scheme', 
				array(
					'label'				=> esc_html__( 'Dark or Light Subnav Color Scheme', 'interico' ),
					'section'			=> 'tc_interico_subnav_section',
					'settings'			=> 'tc_subnav_color_scheme',
					'type'				=> 'select',
					'choices'			=> array(
						'subnav-light'	=> esc_html__( 'Light', 'interico' ),
						'subnav-dark'	=> esc_html__( 'Dark', 'interico' ),
					),
					'priority'			=> 15,
				)
			);

			$wp_customize->add_setting( 'tc_subnav_layout',
				array(
		        	'default'  			=> 'subnav-fullwidth',
		        	'transport'			=> 'refresh',
		        	'type'				=> 'theme_mod',
		        	'capability'		=> 'edit_theme_options',
		        	'sanitize_callback' => 'interico_sanitize_select',
		    	)
			);
			$wp_customize->add_control( 'tc_subnav_layout', 
				array(
					'label'					=> esc_html__( 'Subnav Layout', 'interico' ),
					'section'				=> 'tc_interico_subnav_section',
					'settings'				=> 'tc_subnav_layout',
					'type'					=> 'select',
					'choices'				=> array(
						'subnav-fullwidth'	=> esc_html__( 'Fullwidth', 'interico' ),
						'subnav-angular'	=> esc_html__( 'Boxed Angular', 'interico' ),
					),
					'priority'			=> 15,
				)
			);

			$wp_customize->add_setting( 'tc_subnav_content_alignment',
				array(
		        	'default'  			=> 'subnav-content-right',
		        	'transport'			=> 'refresh',
		        	'type'				=> 'theme_mod',
		        	'capability'		=> 'edit_theme_options',
		        	'sanitize_callback' => 'interico_sanitize_select',
		    	)
			);
			$wp_customize->add_control( 'tc_subnav_content_alignment', 
				array(
					'label'				 => esc_html__( 'Subnav Content Alignment', 'interico' ),
					'section'			 => 'tc_interico_subnav_section',
					'settings'			 => 'tc_subnav_content_alignment',
					'type'				 => 'select',
					'choices'			 => array(
						'subnav-content-right'	 	=> esc_html__( 'Right', 'interico' ),
						'subnav-content-centered' 	=> esc_html__( 'Centered', 'interico' ),
						'subnav-content-left'		=> esc_html__( 'Left', 'interico' ),
					),
					'priority'			 => 15,
				)
			);

			$wp_customize->add_setting( 'tc_subnav_bg',
				array( 
					'default' 			=> '#2f2e2e', 
					'transport'			=> 'refresh',
					'type'				=> 'theme_mod',
					'capability'		=> 'edit_theme_options',
					'sanitize_callback' => 'sanitize_hex_color',
				)
			);
			$wp_customize->add_control( new WP_Customize_Color_Control( 
				$wp_customize, 'tc_subnav_bg',
					array(
						'label'       	=> esc_html__( 'Subnav Background Color', 'interico' ),
						'section'     	=> 'tc_interico_subnav_section',
						'settings'    	=> 'tc_subnav_bg',
						'priority'    	=> 20,
					)
				)
			);

			$wp_customize->add_setting( 'tc_subnav_text',
				array(
					'default'			=> '#ffffff',
					'transport'			=> 'refresh',
					'type'				=> 'theme_mod',
					'capability'		=> 'edit_theme_options',
					'sanitize_callback' => 'sanitize_hex_color'
				)
			);
			$wp_customize->add_control( new WP_Customize_Color_Control( 
				$wp_customize, 'tc_subnav_text', 
					array(
						'label'       	=> esc_html__( 'Subnav Text Color', 'interico' ),
						'section'     	=> 'tc_interico_subnav_section',
						'settings'    	=> 'tc_subnav_text',
						'priority'    	=> 25,
					)
				)
			);

			$wp_customize->add_setting( 'tc_subnav_icon_color',
				array( 
					'default' 			=> '#7d6741', 
					'transport'			=> 'refresh',
					'type'				=> 'theme_mod',
					'capability'		=> 'edit_theme_options',
					'sanitize_callback' => 'sanitize_hex_color',
				)
			);
			$wp_customize->add_control( new WP_Customize_Color_Control( 
				$wp_customize, 'tc_subnav_icon_color',
					array(
						'label'       	=> esc_html__( 'Subnav Icon Color', 'interico' ),
						'section'     	=> 'tc_interico_subnav_section',
						'settings'    	=> 'tc_subnav_icon_color',
						'priority'    	=> 20,
					)
				)
			);

			$wp_customize->add_setting( 'tc_subnav_icon_1',
				array(
					'default'            => 'fa-clock-o',
					'sanitize_callback'  => 'interico_sanitize_input',
					'capability'		 => 'edit_theme_options',
					'type'				 => 'theme_mod',
					'transport'          => 'refresh'
				)
			);
			$wp_customize->add_control( 'tc_subnav_icon_1',
				array(
					'section'  			 => 'tc_interico_subnav_section',
					'label'   			 => esc_html__( 'Field 1: Icon (example: fa-clock-o)', 'interico' ),
					'type'     			 => 'text',
					'settings' 			 => 'tc_subnav_icon_1',
					'priority' 			 => 30,
				)
			);

			$wp_customize->add_setting( 'tc_subnav_text_1',
				array(
					'default'            => 'Opening time: Mon-Fri 08:00 - 18:00',
					'sanitize_callback'  => 'interico_sanitize_text',
					'capability'		 => 'edit_theme_options',
					'type'				 => 'theme_mod',
					'transport'          => 'refresh'
				)
			);
			$wp_customize->add_control( 'tc_subnav_text_1',
				array(
					'section'  			 => 'tc_interico_subnav_section',
					'label'    			 => esc_html__( 'Field 1: Text', 'interico' ),
					'type'     			 => 'text',
					'settings' 			 => 'tc_subnav_text_1',
					'priority' 			 => 35,
				)
			);

			$wp_customize->add_setting( 'tc_subnav_icon_2',
				array(
					'default'            => 'fa-envelope-o',
					'sanitize_callback'  => 'interico_sanitize_input',
					'capability'		 => 'edit_theme_options',
					'type'				 => 'theme_mod',
					'transport'          => 'refresh'
				)
			);
			$wp_customize->add_control( 'tc_subnav_icon_2',
				array(
					'section' 			 => 'tc_interico_subnav_section',
					'label'   			 => esc_html__( 'Field 2: Icon', 'interico' ),
					'type'     			 => 'text',
					'settings'			 => 'tc_subnav_icon_2',
					'priority'			 => 40,
				)
			);

			$wp_customize->add_setting( 'tc_subnav_text_2',
				array(
					'default'            => 'Email: info@interico.com',
					'sanitize_callback'  => 'interico_sanitize_text',
					'capability'		 => 'edit_theme_options',
					'type'				 => 'theme_mod',
					'transport'          => 'refresh'
				)
			);
			$wp_customize->add_control( 'tc_subnav_text_2',
				array(
					'section'  			 => 'tc_interico_subnav_section',
					'label'    			 => esc_html__( 'Field 2: Text', 'interico' ),
					'type'     			 => 'text',
					'settings'			 => 'tc_subnav_text_2',
					'priority'			 => 45,
				)
			);

			$wp_customize->add_setting( 'tc_subnav_icon_3',
				array(
					'default'            => 'fa-phone',
					'sanitize_callback'  => 'interico_sanitize_text',
					'capability'		 => 'edit_theme_options',
					'type'				 => 'theme_mod',
					'transport'          => 'refresh'
				)
			);
			$wp_customize->add_control( 'tc_subnav_icon_3',
				array(
					'section' 			 => 'tc_interico_subnav_section',
					'label'   			 => esc_html__( 'Field 3: Icon', 'interico' ),
					'type'    			 => 'text',
					'settings'			 => 'tc_subnav_icon_3',
					'priority'			 => 50,
				)
			);

			$wp_customize->add_setting( 'tc_subnav_text_3',
				array(
					'default'            => 'Phone: +1 (378) 400-1234',
					'sanitize_callback'  => 'interico_sanitize_text',
					'capability'		 => 'edit_theme_options',
					'type'				 => 'theme_mod',
					'transport'          => 'refresh'
				)
			);
			$wp_customize->add_control( 'tc_subnav_text_3',
				array(
					'section'  			 => 'tc_interico_subnav_section',
					'label'    			 => esc_html__( 'Field 3: Text', 'interico' ),
					'type'     			 => 'text',
					'settings' 			 => 'tc_subnav_text_3',
					'priority' 			 => 55,
				)
			);

			$wp_customize->add_setting( 'tc_subnav_secondary_nav_alignment',
				array(
			    	'default'  			=> 'subnav-content-right',
			    	'transport'			=> 'refresh',
			    	'type'				=> 'theme_mod',
			    	'capability'		=> 'edit_theme_options',
			    	'sanitize_callback' => 'interico_sanitize_select',
				)
			);
			$wp_customize->add_control( 'tc_subnav_secondary_nav_alignment', 
				array(
					'label'				 => esc_html__( 'Secondary Nav Submenu Alignment', 'interico' ),
					'section'			 => 'tc_interico_subnav_section',
					'settings'			 => 'tc_subnav_secondary_nav_alignment',
					'type'				 => 'select',
					'choices'			 => array(
						'right'	 => esc_html__( 'Right', 'interico' ),
						'center' 	 => esc_html__( 'Centered', 'interico' ),
						'left'		 => esc_html__( 'Left', 'interico' ),
					),
					'priority'			 => 15,
				)
			);

			$wp_customize->add_setting( 'tc_subnav_secondary_nav_width', 
					array(
				    	'transport'			=> 'refresh',
				    	'type'				=> 'theme_mod',
				    	'capability'		=> 'edit_theme_options',
				    	'sanitize_callback' => 'interico_sanitize_text',
					)
				);
			$wp_customize->add_control( 'tc_subnav_secondary_nav_width', 
				array(
				    'label' 			=> esc_html__( 'Secondary Nav Sumenu Width', 'interico'),
			    	'type'		        => 'number',
				    'section' 			=> 'tc_interico_subnav_section',
				    'settings' 			=> 'tc_subnav_secondary_nav_width',
				    'priority' 			=> 15,
				    'input_attrs' 		=> array(
						'min' 		=> 0,
						'max'  		=> 320,
						'step' 		=> 1,
					),
				)
			);

		/*-----------------------------------------------------------*
		 * 3. Header Menu settings
		 *-----------------------------------------------------------*/

		$wp_customize->add_section( 'tc_interico_header_section',
			array(
				'title'       			 => esc_html__( 'Header', 'interico' ),
				'description' 			 => esc_html__( 'Customize header layout and color settings.', 'interico' ),
				'priority'    			 => 10,
				'panel'       			 => 'tc_interico_options',
			)
		);

			$wp_customize->add_setting( 'tc_header_layout_style',
				array(
		        	'default'  			=> 'header-style-1',
		        	'transport'			=> 'refresh',
		        	'type'				=> 'theme_mod',
		        	'capability'		=> 'edit_theme_options',
		        	'sanitize_callback' => 'interico_sanitize_select',
		    	)
			);
			$wp_customize->add_control( 'tc_header_layout_style', 
				array(
					'label'				 => esc_html__( 'Header Layout Style', 'interico' ),
					'section'			 => 'tc_interico_header_section',
					'settings'			 => 'tc_header_layout_style',
					'type'				 => 'select',
					'choices'			 => array(
						'header-style-1' => esc_html__( 'Style 1: Wide', 'interico' ),
						'header-style-2' => esc_html__( 'Style 2: Overlapped', 'interico' ),
						'header-style-3' => esc_html__( 'Style 3: Transparent', 'interico' ),
						'header-style-4' => esc_html__( 'Style 4: Sided', 'interico' ),
						'header-style-5' => esc_html__( 'Style 5: Centered', 'interico' ),
					),
					'priority'			=> 5,
				)
			);

			$wp_customize->add_setting( 'tc_header_container',
				array(
		        	'default'  			=> 'container-default',
		        	'transport'			=> 'refresh',
		        	'type'				=> 'theme_mod',
		        	'capability'		=> 'edit_theme_options',
		        	'sanitize_callback' => 'interico_sanitize_select',
		    	)
			);
			$wp_customize->add_control( 'tc_header_container', 
				array(
					'label'				 => esc_html__( 'Header Container', 'interico' ),
					'section'			 => 'tc_interico_header_section',
					'settings'			 => 'tc_header_container',
					'type'				 => 'select',
					'choices'			 => array(
						'container-default' => esc_html__( 'Style 1: Default', 'interico' ),
						'container-wide' => esc_html__( 'Style 2: Wide', 'interico' ),
					),
					'priority'			=> 5,
				)
			);
			

			$wp_customize->add_setting( 'tc_header_typography_style',
				array(
			    	'default'  			=> 'header-typography-style-3',
			    	'transport'			=> 'refresh',
			    	'type'				=> 'theme_mod',
			    	'capability'		=> 'edit_theme_options',
			    	'sanitize_callback' => 'interico_sanitize_select',
				)
			);
			$wp_customize->add_control( 'tc_header_typography_style', 
				array(
					'label'				 => esc_html__( 'Header Typography', 'interico' ),
					'section'			 => 'tc_interico_header_section',
					'settings'			 => 'tc_header_typography_style',
					'type'				 => 'select',
					'choices'			 => array(
						'header-typography-style-1' => esc_html__( 'Style 1: Small', 'interico' ),
						'header-typography-style-2' => esc_html__( 'Style 2: Medium', 'interico' ),
						'header-typography-style-3' => esc_html__( 'Style 3: Uppercase', 'interico' ),
					),
					'priority'			=> 5,
				)
			);

			$wp_customize->add_setting( 'tc_header_color_scheme',
				array(
		        	'default'  			=> 'dark',
		        	'transport'			=> 'refresh',
		        	'type'				=> 'theme_mod',
		        	'capability'		=> 'edit_theme_options',
		        	'sanitize_callback' => 'interico_sanitize_select',
		    	)
			);
			$wp_customize->add_control( 'tc_header_color_scheme', 
				array(
					'label'				=> esc_html__( 'Dark or Light Header Color Scheme', 'interico' ),
					'section'			=> 'tc_interico_header_section',
					'settings'			=> 'tc_header_color_scheme',
					'type'				=> 'select',
					'choices'			=> array(
						'light'			=> esc_html__( 'Light', 'interico' ),
						'dark'			=> esc_html__( 'Dark', 'interico' ),
					),
					'priority'			=> 5,
				)
			);

			$wp_customize->add_setting( 'tc_submenu_color_scheme',
				array(
		        	'default'  			=> 'submenu-dark',
		        	'transport'			=> 'refresh',
		        	'type'				=> 'theme_mod',
		        	'capability'		=> 'edit_theme_options',
		        	'sanitize_callback' => 'interico_sanitize_select',
		    	)
			);
			$wp_customize->add_control( 'tc_submenu_color_scheme', 
				array(
					'label'				=> esc_html__( 'Dark or Light Dropdown Menu Color Scheme', 'interico' ),
					'section'			=> 'tc_interico_header_section',
					'settings'			=> 'tc_submenu_color_scheme',
					'type'				=> 'select',
					'choices'			=> array(
						'submenu-light'	=> esc_html__( 'Light', 'interico' ),
						'submenu-dark'	=> esc_html__( 'Dark', 'interico' ),
					),
					'priority'			=> 5,
				)
			);

			$wp_customize->add_setting( 'tc_sticky_nav',
				array(
		        	'default'  			=> 'sticky',
		        	'transport'			=> 'refresh',
		        	'type'				=> 'theme_mod',
		        	'capability'		=> 'edit_theme_options',
		        	'sanitize_callback' => 'interico_sanitize_select',
		    	)
			);
			$wp_customize->add_control( 'tc_sticky_nav', 
				array(
					'label'				=> esc_html__( 'Sticky Navigation', 'interico' ),
					'section'			=> 'tc_interico_header_section',
					'settings'			=> 'tc_sticky_nav',
					'type'				=> 'select',
					'choices'			=> array(
						'sticky'		=> esc_html__( 'Yes', 'interico' ),
						'static'		=> esc_html__( 'No', 'interico' ),
					),
					'priority'			=> 10,
				)
			);

			$wp_customize->add_setting( 'tc_sticky_nav_mobile',
				array(
		        	'default'  			=> 'sticky',
		        	'transport'			=> 'refresh',
		        	'type'				=> 'theme_mod',
		        	'capability'		=> 'edit_theme_options',
		        	'sanitize_callback' => 'interico_sanitize_select',
		    	)
			);
			$wp_customize->add_control( 'tc_sticky_nav_mobile', 
				array(
					'label'				=> esc_html__( 'Sticky Navigation Mobile', 'interico' ),
					'section'			=> 'tc_interico_header_section',
					'settings'			=> 'tc_sticky_nav_mobile',
					'type'				=> 'select',
					'choices'			=> array(
						'sticky'		=> esc_html__( 'Yes', 'interico' ),
						'static'		=> esc_html__( 'No', 'interico' ),
					),
					'priority'			=> 10,
				)
			);

			$wp_customize->add_setting( 'tc_hide_submenu_mobile',
				array(
		        	'default'  			=> 'yes',
		        	'transport'			=> 'refresh',
		        	'type'				=> 'theme_mod',
		        	'capability'		=> 'edit_theme_options',
		        	'sanitize_callback' => 'interico_sanitize_select',
		    	)
			);
			$wp_customize->add_control( 'tc_hide_submenu_mobile', 
				array(
					'label'				=> esc_html__( 'Mobile Submenu Style', 'interico' ),
					'section'			=> 'tc_interico_header_section',
					'settings'			=> 'tc_hide_submenu_mobile',
					'type'				=> 'select',
					'choices'			=> array(
						'no'		=> esc_html__( 'Style 1: With dropdown', 'interico' ),
						'yes'		=> esc_html__( 'Style 2: Large centered', 'interico' ),
						'style-3'		=> esc_html__( 'Style 3: Large centered + dropdown', 'interico' ),
					),
					'priority'			=> 10,
				)
			);

			$wp_customize->add_setting( 'tc_header_shadow',
				array(
					'default'			=> 'soft',
					'transport'			=> 'refresh
					',
					'type'				=> 'theme_mod',
					'capability'		=> 'edit_theme_options',
					'sanitize_callback' => 'interico_sanitize_select',
				)
			);
			$wp_customize->add_control( 'tc_header_shadow',
				array(
					'label'				=> esc_html__( 'Header Shadow', 'interico' ),
					'section'			=> 'tc_interico_header_section',
					'settings'			=> 'tc_header_shadow',
					'type'				=> 'select',
					'choices'			=> array(
						'soft'			=> esc_html__( 'Soft', 'interico' ),
						'bold'			=> esc_html__( 'Bold', 'interico' ),
						'none'			=> esc_html__( 'No Shadow', 'interico' )
					),
					'priority' 			=> 15,
				)
			);

			$wp_customize->add_setting( 'tc_header_height', 
					array(
				    	'transport'			=> 'refresh',
				    	'type'				=> 'theme_mod',
				    	'capability'		=> 'edit_theme_options',
				    	'sanitize_callback' => 'interico_sanitize_text',
					)
				);
			$wp_customize->add_control( 'tc_header_height', 
				array(
				    'label' 			=> esc_html__( 'Header Height', 'interico'),
				    'description' 		=> esc_html__( 'Adjust header height by pixels.', 'interico' ),
			    	'type'		        => 'number',
				    'section' 			=> 'tc_interico_header_section',
				    'settings' 			=> 'tc_header_height',
				    'priority' 			=> 15,
				    'input_attrs' 		=> array(
						'min' 		=> 0,
						'max'  		=> 200,
						'step' 		=> 1,
					),
				)
			);

			$wp_customize->add_setting( 'tc_header_height_mobile', 
					array(
				    	'transport'			=> 'refresh',
				    	'type'				=> 'theme_mod',
				    	'capability'		=> 'edit_theme_options',
				    	'sanitize_callback' => 'interico_sanitize_text',
					)
				);
			$wp_customize->add_control( 'tc_header_height_mobile', 
				array(
				    'label' 			=> esc_html__( 'Header Height Mobile', 'interico'),
				    'description' 		=> esc_html__( 'Adjust header height by pixels.', 'interico' ),
			    	'type'		        => 'number',
				    'section' 			=> 'tc_interico_header_section',
				    'settings' 			=> 'tc_header_height_mobile',
				    'priority' 			=> 15,
				    'input_attrs' 		=> array(
						'min' 		=> 0,
						'max'  		=> 200,
						'step' 		=> 1,
					),
				)
			);


			$wp_customize->add_setting( 'tc_header_bg',
				array(
					'transport'			=> 'refresh',
					'type'				=> 'theme_mod',
					'capability'		=> 'edit_theme_options',
				    'sanitize_callback' => 'sanitize_hex_color',
				)
			);
			$wp_customize->add_control( new WP_Customize_Color_Control( 
				$wp_customize, 'tc_header_bg', 
					array(
						'label'         => esc_html__( 'Header Background Color', 'interico' ),
						'section'     	=> 'tc_interico_header_section',
						'settings'    	=> 'tc_header_bg',
						'priority'    	=> 20,
					)
				)
			);

			$wp_customize->add_setting( 'tc_header_link_color',
				array(
				    'transport'			=> 'refresh',
				    'type'				=> 'theme_mod',
				    'capability'		=> 'edit_theme_options',
				    'sanitize_callback' => 'sanitize_hex_color',
				)
			);
			$wp_customize->add_control( new WP_Customize_Color_Control( 
				$wp_customize, 'tc_header_link_color',
					array(
						'label'      	=> esc_html__( 'Navigation Link Color', 'interico' ),
						'section'     	=> 'tc_interico_header_section',
						'settings'    	=> 'tc_header_link_color',
						'priority'    	=> 25,
					)
				)
			);

			$wp_customize->add_setting( 'tc_header_link_color_hover',
				array(
				    'default'    		=> '#aa9168',
				    'transport'			=> 'refresh',
				    'type'				=> 'theme_mod',
				    'capability'		=> 'edit_theme_options',
				    'sanitize_callback' => 'sanitize_hex_color',
				)
			);
			$wp_customize->add_control( new WP_Customize_Color_Control( 
				$wp_customize, 'tc_header_link_color_hover',
					array(
						'label'      	=> esc_html__( 'Navigation Link Hover Color', 'interico' ),
						'section'     	=> 'tc_interico_header_section',
						'settings'    	=> 'tc_header_link_color_hover',
						'priority'    	=> 30,
					)
				)
			);

			$wp_customize->add_setting( 'tc_header_underline_hover',
				array(
				    'default'    		=> '#7d6741',
				    'transport'			=> 'refresh',
				    'type'				=> 'theme_mod',
				    'capability'		=> 'edit_theme_options',
				    'sanitize_callback' => 'sanitize_hex_color',
				)
			);
			$wp_customize->add_control( new WP_Customize_Color_Control( 
				$wp_customize, 'tc_header_underline_hover',
					array(
						'label'      	=> esc_html__( 'Navigation Link Underline', 'interico' ),
						'section'     	=> 'tc_interico_header_section',
						'settings'    	=> 'tc_header_underline_hover',
						'priority'    	=> 30,
					)
				)
			);

			$wp_customize->add_setting( 'tc_nav_submenu_bg', 
				array(
					'default' 			=> '#69593e',
					'transport'			=> 'refresh',
					'type'				=> 'theme_mod',
					'capability'		=> 'edit_theme_options',
			    	'sanitize_callback' => 'sanitize_hex_color',
				)
			);
			$wp_customize->add_control( new WP_Customize_Color_Control( 
				$wp_customize, 'tc_nav_submenu_bg', 
					array(
						'label'       	=> esc_html__( '2nd Level Menu Background Color', 'interico' ),
						'section'     	=> 'tc_interico_header_section',
						'settings'    	=> 'tc_nav_submenu_bg',
						'priority'    	=> 35,
					)
				)
			);

			$wp_customize->add_setting( 'tc_nav_submenu_text',
				array(
			    	'default'     		=> '#cccccc',
			    	'transport'			=> 'refresh',
			    	'type'				=> 'theme_mod',
			    	'capability'		=> 'edit_theme_options',
			    	'sanitize_callback' => 'sanitize_hex_color',
				)
			);
			$wp_customize->add_control( new WP_Customize_Color_Control( 
				$wp_customize, 'tc_nav_submenu_text',
					array(
						'label'       	=> esc_html__( '2nd Level Menu Text Color', 'interico' ),
						'section'     	=> 'tc_interico_header_section',
						'settings'    	=> 'tc_nav_submenu_text',
						'priority'    	=> 40,
					)
				)
			);

			$wp_customize->add_setting( 'tc_nav_sub_submenu_bg', 
				array(
					'default' 			=> '#333333',
					'transport'			=> 'refresh',
					'type'				=> 'theme_mod',
					'capability'		=> 'edit_theme_options',
			    	'sanitize_callback' => 'sanitize_hex_color',
				)
			);
			$wp_customize->add_control( new WP_Customize_Color_Control( 
				$wp_customize, 'tc_nav_sub_submenu_bg', 
					array(
						'label'       	=> esc_html__( '3rd Level Menu Background Color', 'interico' ),
						'section'     	=> 'tc_interico_header_section',
						'settings'    	=> 'tc_nav_sub_submenu_bg',
						'priority'    	=> 45,
					)
				)
			);

			$wp_customize->add_setting( 'tc_nav_sub_submenu_text',
				array(
			    	'default'     		=> '#cccccc',
			    	'transport'			=> 'refresh',
			    	'type'				=> 'theme_mod',
			    	'capability'		=> 'edit_theme_options',
			    	'sanitize_callback' => 'sanitize_hex_color',
				)
			);
			$wp_customize->add_control( new WP_Customize_Color_Control( 
				$wp_customize, 'tc_nav_sub_submenu_text',
					array(
						'label'       	=> esc_html__( '3rd Level Menu Text Color', 'interico' ),
						'section'     	=> 'tc_interico_header_section',
						'settings'    	=> 'tc_nav_sub_submenu_text',
						'priority'    	=> 50,
					)
				)
			);

	
		/*-----------------------------------------------------------*
		 * 4. Page Top Content Area
		 *-----------------------------------------------------------*/

		$wp_customize->add_section( 'tc_interico_tca_section',
			array(
				'title'       			=> esc_html__( 'Page Title Area & Content', 'interico' ),
				'description' 			=> esc_html__( 'Control title, content & layout settings for inner pages.', 'interico' ),
				'priority'    			=> 10,
				'panel'       			=> 'tc_interico_options',
			)
		);

			$wp_customize->add_setting( 'tc_interico_tca_text',
				array(
			    	'default'     		=> '#ffffff',
			    	'transport'			=> 'refresh',
			    	'type'				=> 'theme_mod',
			    	'capability'		=> 'edit_theme_options',
			    	'sanitize_callback' => 'sanitize_hex_color',
				)
			);
			$wp_customize->add_control( new WP_Customize_Color_Control( 
				$wp_customize, 'tc_interico_tca_text',
					array(
						'label'       	=> esc_html__( 'Title Text Color', 'interico' ),
						'section'     	=> 'tc_interico_tca_section',
						'settings'    	=> 'tc_interico_tca_text',
						'priority'    	=> 5,
					)
				)
			);

			$wp_customize->add_setting( 'tc_interico_subtitle_color',
				array(
			    	'transport'			=> 'refresh',
			    	'type'				=> 'theme_mod',
			    	'capability'		=> 'edit_theme_options',
			    	'sanitize_callback' => 'sanitize_hex_color',
				)
			);
			$wp_customize->add_control( new WP_Customize_Color_Control( 
				$wp_customize, 'tc_interico_subtitle_color',
					array(
						'label'       	=> esc_html__( 'Subtitle Text Color', 'interico' ),
						'section'     	=> 'tc_interico_tca_section',
						'settings'    	=> 'tc_interico_subtitle_color',
						'priority'    	=> 5,
					)
				)
			);

			$wp_customize->add_setting( 'tc_interico_text_color',
				array(
			    	'transport'			=> 'refresh',
			    	'type'				=> 'theme_mod',
			    	'capability'		=> 'edit_theme_options',
			    	'sanitize_callback' => 'sanitize_hex_color',
				)
			);
			$wp_customize->add_control( new WP_Customize_Color_Control( 
				$wp_customize, 'tc_interico_text_color',
					array(
						'label'       	=> esc_html__( 'Content Color', 'interico' ),
						'section'     	=> 'tc_interico_tca_section',
						'settings'    	=> 'tc_interico_text_color',
						'priority'    	=> 5,
					)
				)
			);

			$wp_customize->add_setting( 'tc_interico_overlay_color',
				array(
			    	'default'     		=> '#444444',
			    	'transport'			=> 'refresh',
			    	'type'				=> 'theme_mod',
			    	'capability'		=> 'edit_theme_options',
			    	'sanitize_callback' => 'sanitize_hex_color',
				)
			);
			$wp_customize->add_control( new WP_Customize_Color_Control( 
				$wp_customize, 'tc_interico_overlay_color',
					array(
						'label'       	=> esc_html__( 'Background Overlay Color', 'interico' ),
						'section'     	=> 'tc_interico_tca_section',
						'settings'    	=> 'tc_interico_overlay_color',
						'priority'    	=> 10,
					)
				)
			);

			$wp_customize->add_setting( 'tc_interico_overlay_opacity', 
					array(
						'default'			=> 30,
				    	'transport'			=> 'refresh',
				    	'type'				=> 'theme_mod',
				    	'capability'		=> 'edit_theme_options',
				    	'sanitize_callback' => 'interico_sanitize_text',
					)
				);
			$wp_customize->add_control( 'tc_interico_overlay_opacity', 
				array(
				    'label' 			=> esc_html__( 'Background Overlay Opacity', 'interico'),
				    'description' 		=> esc_html__( 'Enter value from 0 to 100.', 'interico' ),
			    	'type'		        => 'number',
				    'section' 			=> 'tc_interico_tca_section',
				    'settings' 			=> 'tc_interico_overlay_opacity',
				    'priority' 			=> 15,
				    'input_attrs' 		=> array(
						'min' 		=> 0,
						'max'  		=> 100,
						'step' 		=> 1,
					),
				)
			);

			$wp_customize->add_setting( 'tc_interico_tca_img',
				array( 
					'transport'			=> 'refresh',
					'type'				=> 'theme_mod',
					'capability'		=> 'edit_theme_options',
					'sanitize_callback' => 'esc_url_raw',
				)
			);
			$wp_customize->add_control( new WP_Customize_Image_Control( 
				$wp_customize, 'tc_interico_tca_img',
					array(
			            'label' 	 	=> esc_html__( 'Background Image', 'interico' ),
			            'description' 	=> esc_html__( 'Recommended size: 1920 x 880 pixels', 'interico' ),
			            'section' 	 	=> 'tc_interico_tca_section',
			            'settings' 	 	=> 'tc_interico_tca_img',
						'priority'   	=> 15,
					)
				)
			);

			$wp_customize->add_setting( 'tc_show_grid_lines', 
				array(
		        	'default'  			=> 'yes',
		        	'transport'			=> 'refresh',
		        	'type'				=> 'theme_mod',
		        	'capability'		=> 'edit_theme_options',
		        	'sanitize_callback' => 'interico_sanitize_select',
		    	)
			);
			$wp_customize->add_control( 'tc_show_grid_lines', 
				array(
					'label'    			=> esc_html__( 'Display Grid Lines on Title Area', 'interico' ),
					'section'  			=> 'tc_interico_tca_section',
					'settings' 			=> 'tc_show_grid_lines',
					'type'    			=> 'select',
					'choices'  			=> array(
						'yes'  			=> esc_html__( 'Yes', 'interico' ),
						'no' 			=> esc_html__( 'No', 'interico' ),
					),
					'priority' 			=> 35,
				)
			);

			$wp_customize->add_setting( 'tc_default_tca_visibility', 
				array(
			    	'default'  			=> 'yes',
			    	'transport'			=> 'refresh',
			    	'type'				=> 'theme_mod',
			    	'capability'		=> 'edit_theme_options',
			    	'sanitize_callback' => 'interico_sanitize_select',
				)
			);
			$wp_customize->add_control( 'tc_default_tca_visibility', 
				array(
					'label'    			=> esc_html__( 'Default Title Area Visibility (Pages)', 'interico' ),
					'section'  			=> 'tc_interico_tca_section',
					'settings' 			=> 'tc_default_tca_visibility',
					'type'    			=> 'select',
					'choices'  			=> array(
						'yes'  			=> esc_html__( 'Show', 'interico' ),
						'no' 			=> esc_html__( 'Hide', 'interico' ),
					),
					'priority' 			=> 35,
				)
			);

			$wp_customize->add_setting( 'tc_default_tca_size', 
				array(
		        	'default'  			=> 'medium',
		        	'transport'			=> 'refresh',
		        	'type'				=> 'theme_mod',
		        	'capability'		=> 'edit_theme_options',
		        	'sanitize_callback' => 'interico_sanitize_select',
		    	)
			);
			$wp_customize->add_control( 'tc_default_tca_size', 
				array(
					'label'    			=> esc_html__( 'Default Title Area Size', 'interico' ),
					'section'  			=> 'tc_interico_tca_section',
					'settings' 			=> 'tc_default_tca_size',
					'type'    			=> 'select',
					'choices'  			=> array(
						'small' 			=> esc_html__( 'Small', 'interico' ),
						'medium' 			=> esc_html__( 'Medium', 'interico' ),
						'large'  			=> esc_html__( 'Large', 'interico' ),
					),
					'priority' 			=> 35,
				)
			);

			$wp_customize->add_setting( 'tc_default_tca_text_alignment', 
				array(
		        	'default'  			=> 'center',
		        	'transport'			=> 'refresh',
		        	'type'				=> 'theme_mod',
		        	'capability'		=> 'edit_theme_options',
		        	'sanitize_callback' => 'interico_sanitize_select',
		    	)
			);
			$wp_customize->add_control( 'tc_default_tca_text_alignment', 
				array(
					'label'    			=> esc_html__( 'Default Title Area Alignment', 'interico' ),
					'section'  			=> 'tc_interico_tca_section',
					'settings' 			=> 'tc_default_tca_text_alignment',
					'type'    			=> 'select',
					'choices'  			=> array(
						'center' 			=> esc_html__( 'Center', 'interico' ),
						'left'  			=> esc_html__( 'Left', 'interico' ),
						'right' 			=> esc_html__( 'Right', 'interico' ),
					),
					'priority' 			=> 35,
				)
			);

			$wp_customize->add_setting( 'tc_default_post_layout', 
				array(
		        	'default'  			=> 'standard',
		        	'transport'			=> 'refresh',
		        	'type'				=> 'theme_mod',
		        	'capability'		=> 'edit_theme_options',
		        	'sanitize_callback' => 'interico_sanitize_select',
		    	)
			);
			$wp_customize->add_control( 'tc_default_post_layout', 
				array(
					'label'    			=> esc_html__( 'Default Post Layout', 'interico' ),
					'section'  			=> 'tc_interico_tca_section',
					'settings' 			=> 'tc_default_post_layout',
					'type'    			=> 'select',
					'choices'  			=> array(
						'standard'  		=> esc_html__( 'Standard', 'interico' ),
						'overlapped' 		=> esc_html__( 'Overlapped', 'interico' ),
						'overlapped-2' 		=> esc_html__( 'Overlapped Large', 'interico' ),
					),
					'priority' 			=> 35,
				)
			);

			$wp_customize->add_setting( 'tc_default_tca_post_visibility', 
				array(
			    	'default'  			=> 'yes',
			    	'transport'			=> 'refresh',
			    	'type'				=> 'theme_mod',
			    	'capability'		=> 'edit_theme_options',
			    	'sanitize_callback' => 'interico_sanitize_select',
				)
			);
			$wp_customize->add_control( 'tc_default_tca_post_visibility', 
				array(
					'label'    			=> esc_html__( 'Default Title Area Visibility (Posts)', 'interico' ),
					'section'  			=> 'tc_interico_tca_section',
					'settings' 			=> 'tc_default_tca_post_visibility',
					'type'    			=> 'select',
					'choices'  			=> array(
						'yes'  			=> esc_html__( 'Show', 'interico' ),
						'no' 			=> esc_html__( 'Hide', 'interico' ),
					),
					'priority' 			=> 35,
				)
			);

			$wp_customize->add_setting( 'tc_blog_sidebar_position', 
				array(
			    	'default'  			=> 'left',
			    	'transport'			=> 'refresh',
			    	'type'				=> 'theme_mod',
			    	'capability'		=> 'edit_theme_options',
			    	'sanitize_callback' => 'interico_sanitize_select',
				)
			);
			$wp_customize->add_control( 'tc_blog_sidebar_position', 
				array(
					'label'    			=> esc_html__( 'Default Blog Sidebar', 'interico' ),
					'section'  			=> 'tc_interico_tca_section',
					'settings' 			=> 'tc_blog_sidebar_position',
					'type'    			=> 'select',
					'choices'  			=> array(
						'left' 			=> esc_html__( 'Left', 'interico' ),
						'right' 		=> esc_html__( 'Right', 'interico' ),
						'disabled'  	=> esc_html__( 'Disabled', 'interico' ),
					),
					'priority' 			=> 35,
				)
			);

			$wp_customize->add_setting( 'tc_page_sidebar_position', 
				array(
			    	'default'  			=> 'disabled',
			    	'transport'			=> 'refresh',
			    	'type'				=> 'theme_mod',
			    	'capability'		=> 'edit_theme_options',
			    	'sanitize_callback' => 'interico_sanitize_select',
				)
			);
			$wp_customize->add_control( 'tc_page_sidebar_position', 
				array(
					'label'    			=> esc_html__( 'Default Page Sidebar', 'interico' ),
					'section'  			=> 'tc_interico_tca_section',
					'settings' 			=> 'tc_page_sidebar_position',
					'type'    			=> 'select',
					'choices'  			=> array(
						'disabled'  	=> esc_html__( 'Disabled', 'interico' ),
						'left' 			=> esc_html__( 'Left', 'interico' ),
						'right' 		=> esc_html__( 'Right', 'interico' ),
					),
					'priority' 			=> 35,
				)
			);

			$wp_customize->add_setting( 'tc_default_page_padding_top', 
				array(
			    	'default'  			=> '80',
			    	'transport'			=> 'refresh',
			    	'type'				=> 'theme_mod',
			    	'capability'		=> 'edit_theme_options',
			    	'sanitize_callback' => 'interico_sanitize_select',
				)
			);
			$wp_customize->add_control( 'tc_default_page_padding_top', 
				array(
					'label'    			=> esc_html__( 'Default Page Top Padding', 'interico' ),
					'section'  			=> 'tc_interico_tca_section',
					'settings' 			=> 'tc_default_page_padding_top',
					'type'    			=> 'select',
					'choices'  			=> array(
						'80' 			=> esc_html__( '80', 'interico' ),
						'120' 			=> esc_html__( '120', 'interico' ),
						'0' 			=> esc_html__( '0', 'interico' ),
					),
					'priority' 			=> 35,
				)
			);

			$wp_customize->add_setting( 'tc_default_page_padding_bottom', 
				array(
			    	'default'  			=> '80',
			    	'transport'			=> 'refresh',
			    	'type'				=> 'theme_mod',
			    	'capability'		=> 'edit_theme_options',
			    	'sanitize_callback' => 'interico_sanitize_select',
				)
			);
			$wp_customize->add_control( 'tc_default_page_padding_bottom', 
				array(
					'label'    			=> esc_html__( 'Default Page Bottom Padding', 'interico' ),
					'section'  			=> 'tc_interico_tca_section',
					'settings' 			=> 'tc_default_page_padding_bottom',
					'type'    			=> 'select',
					'choices'  			=> array(
						'120' 			=> esc_html__( '120', 'interico' ),
						'80' 			=> esc_html__( '80', 'interico' ),
						'0' 			=> esc_html__( '0', 'interico' ),
					),
					'priority' 			=> 35,
				)
			);

			$wp_customize->add_setting( 'tc_default_project_padding_top', 
				array(
			    	'default'  			=> '120',
			    	'transport'			=> 'refresh',
			    	'type'				=> 'theme_mod',
			    	'capability'		=> 'edit_theme_options',
			    	'sanitize_callback' => 'interico_sanitize_select',
				)
			);
			$wp_customize->add_control( 'tc_default_project_padding_top', 
				array(
					'label'    			=> esc_html__( 'Default Project Padding Top', 'interico' ),
					'section'  			=> 'tc_interico_tca_section',
					'settings' 			=> 'tc_default_project_padding_top',
					'type'    			=> 'select',
					'choices'  			=> array(
						'120' 			=> esc_html__( '120', 'interico' ),
						'80' 			=> esc_html__( '80', 'interico' ),
						'0' 			=> esc_html__( '0', 'interico' ),
					),
					'priority' 			=> 35,
				)
			);

			$wp_customize->add_setting( 'tc_default_project_padding_bottom', 
				array(
			    	'default'  			=> '120',
			    	'transport'			=> 'refresh',
			    	'type'				=> 'theme_mod',
			    	'capability'		=> 'edit_theme_options',
			    	'sanitize_callback' => 'interico_sanitize_select',
				)
			);
			$wp_customize->add_control( 'tc_default_project_padding_bottom', 
				array(
					'label'    			=> esc_html__( 'Default Project Padding Bottom', 'interico' ),
					'section'  			=> 'tc_interico_tca_section',
					'settings' 			=> 'tc_default_project_padding_bottom',
					'type'    			=> 'select',
					'choices'  			=> array(
						'80' 			=> esc_html__( '80', 'interico' ),
						'120' 			=> esc_html__( '120', 'interico' ),
						'0' 			=> esc_html__( '0', 'interico' ),
					),
					'priority' 			=> 35,
				)
			);


		/*-----------------------------------------------------------*
		 * 5. General Styling
		 *-----------------------------------------------------------*/

		$wp_customize->add_section( 'tc_interico_styling_section',
			array(
				'title'       	=> esc_html__( 'General Styling', 'interico' ),
				'description' 	=> esc_html__( 'Change accent colors, layout and more.', 'interico' ),
				'priority'    	=> 1,
				'panel'       	=> 'tc_interico_options',
			)
		);


			$wp_customize->add_setting( 'tc_headings_color',
				array(
			        'transport'			=> 'refresh',
			        'type'				=> 'theme_mod',
			        'capability'		=> 'edit_theme_options',
				    'sanitize_callback' => 'sanitize_hex_color'
				)
			);
			$wp_customize->add_control( new WP_Customize_Color_Control( 
				$wp_customize, 'tc_headings_color', 
					array(
						'label'       	=> esc_html__( 'Main Headings Color (H1, H2)', 'interico' ),
						'section'     	=> 'tc_interico_styling_section',
						'settings'    	=> 'tc_headings_color',
						'priority'    	=> 10,
					)
				)
			);

			$wp_customize->add_setting(	'interico_headings_font',
				array(
					'sanitize_callback'  => 'interico_sanitize_text',
					'transport'          => 'refresh'
				)
			);
			$wp_customize->add_control(	'interico_headings_font',
				array(
					'section'  			=> 'tc_interico_styling_section',
					'label'    			=> esc_html__( 'Headings Font', 'interico' ),
					'description' 		=> esc_html__( 'Font generated on fonts.google.com, Example: Open+Sans:300,300i,400,400i,700,700i', 'interico' ),
					'type'     			=> 'text',
					'priority' 			=> 10,
				)
			);

			$wp_customize->add_setting(	'interico_headings_font_css',
				array(
					'sanitize_callback'  => 'interico_sanitize_text',
					'transport'          => 'refresh'
				)
			);
			$wp_customize->add_control(	'interico_headings_font_css',
				array(
					'section'  			=> 'tc_interico_styling_section',
					'label'    			=> esc_html__( 'Headings Font CSS', 'interico' ),
					'description' 		=> esc_html__( "CSS generated on fonts.google.com, Example: 'Open Sans', sans-serif", 'interico' ),
					'type'     			=> 'text',
					'priority' 			=> 10,
				)
			);

			$wp_customize->add_setting(	'interico_body_font',
				array(
					'sanitize_callback'  => 'interico_sanitize_text',
					'transport'          => 'refresh'
				)
			);
			$wp_customize->add_control(	'interico_body_font',
				array(
					'section'  			=> 'tc_interico_styling_section',
					'label'    			=> esc_html__( 'Body Font', 'interico' ),
					'description' 		=> esc_html__( 'Font generated on fonts.google.com, Example: Open+Sans:300,300i,400,400i,700,700i', 'interico' ),
					'type'     			=> 'text',
					'priority' 			=> 10,
				)
			);

			$wp_customize->add_setting(	'interico_body_font_css',
				array(
					'sanitize_callback'  => 'interico_sanitize_text',
					'transport'          => 'refresh'
				)
			);
			$wp_customize->add_control(	'interico_body_font_css',
				array(
					'section'  			=> 'tc_interico_styling_section',
					'label'    			=> esc_html__( 'Body Font CSS', 'interico' ),
					'description' 		=> esc_html__( "CSS generated on fonts.google.com, Example: 'Open Sans', sans-serif", 'interico' ),
					'type'     			=> 'text',
					'priority' 			=> 10,
				)
			);

			$wp_customize->add_setting( 'tc_body_color_scheme',
				array(
					'default'  			=> 'body-light',
					'transport'			=> 'refresh',
					'type'				=> 'theme_mod',
					'capability'		=> 'edit_theme_options',
					'sanitize_callback' => 'interico_sanitize_select',
				)
			);
			$wp_customize->add_control( 'tc_body_color_scheme', 
				array(
					'label'				=> esc_html__( 'Body Dark or Light Color Scheme', 'interico' ),
					'section'			=> 'tc_interico_styling_section',
					'settings'			=> 'tc_body_color_scheme',
					'type'				=> 'select',
					'choices'			=> array(
						'body-light'		=> esc_html__( 'Light', 'interico' ),
						'body-dark'			=> esc_html__( 'Dark', 'interico' ),

					),
					'priority'			=> 10,
				)
			);
			

			$wp_customize->add_setting( 'tc_body_text_color',
				array(
				    'default'     		=> '#777777',
			        'transport'			=> 'refresh',
			        'type'				=> 'theme_mod',
			        'capability'		=> 'edit_theme_options',
				    'sanitize_callback' => 'sanitize_hex_color'
				)
			);
			$wp_customize->add_control( new WP_Customize_Color_Control( 
				$wp_customize, 'tc_body_text_color', 
					array(
						'label'       	=> esc_html__( 'Body Text Color', 'interico' ),
						'section'     	=> 'tc_interico_styling_section',
						'settings'    	=> 'tc_body_text_color',
						'priority'    	=> 15,
					)
				)
			);

			$wp_customize->add_setting( 'tc_accent_color',
				array(
				    'default'     		=> '#7d6741',
					'transport'			=> 'refresh',
					'type'				=> 'theme_mod',
					'capability'		=> 'edit_theme_options',
				    'sanitize_callback' => 'sanitize_hex_color',
				)
			);
			$wp_customize->add_control( new WP_Customize_Color_Control( 
				$wp_customize, 'tc_accent_color', 
					array(
						'label'       	=> esc_html__( 'Accent Color', 'interico' ),
						'section'     	=> 'tc_interico_styling_section',
						'settings'    	=> 'tc_accent_color',
						'priority'    	=> 20,
					)
				)
			);

			$wp_customize->add_setting( 'tc_btn_border_radius', 
					array(
						'default'			=> 3,
				    	'transport'			=> 'refresh',
				    	'type'				=> 'theme_mod',
				    	'capability'		=> 'edit_theme_options',
				    	'sanitize_callback' => 'interico_sanitize_text',
					)
				);
			$wp_customize->add_control( 'tc_btn_border_radius', 
				array(
				    'label' 			=> esc_html__( 'Border Radius for Buttons', 'interico'),
				    'description' 		=> esc_html__( 'Adjust radius for all of the buttons by pixels.', 'interico' ),
			    	'type'		        => 'number',
				    'section' 			=> 'tc_interico_styling_section',
				    'settings' 			=> 'tc_btn_border_radius',
				    'priority' 			=> 25,
				    'input_attrs' 		=> array(
						'min' 		=> 0,
						'max'  		=> 50,
						'step' 		=> 1,
					),
				)
			);

			$wp_customize->add_setting( 'tc_btn_border_width', 
					array(
						'default'			=> 2,
				    	'transport'			=> 'refresh',
				    	'type'				=> 'theme_mod',
				    	'capability'		=> 'edit_theme_options',
				    	'sanitize_callback' => 'interico_sanitize_text',
					)
				);
			$wp_customize->add_control( 'tc_btn_border_width', 
				array(
				    'label' 			=> esc_html__( 'Border Width for Buttons', 'interico'),
				    'description' 		=> esc_html__( 'Adjust border thickness for all of the buttons by pixels.', 'interico' ),
			    	'type'		        => 'number',
				    'section' 			=> 'tc_interico_styling_section',
				    'settings' 			=> 'tc_btn_border_width',
				    'priority' 			=> 25,
				    'input_attrs' 		=> array(
						'min' 		=> 0,
						'max'  		=> 10,
						'step' 		=> 1,
					),
				)
			);

			$wp_customize->add_setting( 'tc_btn_padding', 
					array(
						'default'			=> 15,
				    	'transport'			=> 'refresh',
				    	'type'				=> 'theme_mod',
				    	'capability'		=> 'edit_theme_options',
				    	'sanitize_callback' => 'interico_sanitize_text',
					)
				);
			$wp_customize->add_control( 'tc_btn_padding', 
				array(
				    'label' 			=> esc_html__( 'Padding for Buttons', 'interico'),
				    'description' 		=> esc_html__( 'Adjust padding for all of the buttons by pixels.', 'interico' ),
			    	'type'		        => 'number',
				    'section' 			=> 'tc_interico_styling_section',
				    'settings' 			=> 'tc_btn_padding',
				    'priority' 			=> 25,
				    'input_attrs' 		=> array(
						'min' 		=> 0,
						'max'  		=> 50,
						'step' 		=> 1,
					),
				)
			);

			$wp_customize->add_setting( 'tc_primary_btn_bg',
				array(
				    'default'     		=> '#7d6741',
			        'transport'			=> 'refresh',
			        'type'				=> 'theme_mod',
			        'capability'		=> 'edit_theme_options',
				    'sanitize_callback' => 'sanitize_hex_color'
				)
			);
			$wp_customize->add_control( new WP_Customize_Color_Control( 
				$wp_customize, 'tc_primary_btn_bg', 
					array(
						'label'       	=> esc_html__( 'Primary Button Background Color', 'interico' ),
						'section'     	=> 'tc_interico_styling_section',
						'settings'    	=> 'tc_primary_btn_bg',
						'priority'    	=> 25,
					)
				)
			);

			$wp_customize->add_setting( 'tc_primary_btn_bg_hover',
				array(
			        'transport'			=> 'refresh',
			        'type'				=> 'theme_mod',
			        'capability'		=> 'edit_theme_options',
				    'sanitize_callback' => 'sanitize_hex_color'
				)
			);
			$wp_customize->add_control( new WP_Customize_Color_Control( 
				$wp_customize, 'tc_primary_btn_bg_hover', 
					array(
						'label'       	=> esc_html__( 'Primary Button Background Hover Color', 'interico' ),
						'description' 	=> esc_html__( 'If not used, sets a darker shade of the existing color.', 'interico' ),
						'section'     	=> 'tc_interico_styling_section',
						'settings'    	=> 'tc_primary_btn_bg_hover',
						'priority'    	=> 25,
					)
				)
			);

			$wp_customize->add_setting( 'tc_primary_btn_text',
				array(
				    'default'     		=> '#ffffff',
			        'transport'			=> 'refresh',
			        'type'				=> 'theme_mod',
			        'capability'		=> 'edit_theme_options',
				    'sanitize_callback' => 'sanitize_hex_color'
				)
			);
			$wp_customize->add_control( new WP_Customize_Color_Control( 
				$wp_customize, 'tc_primary_btn_text', 
					array(
						'label'       	=> esc_html__( 'Primary Button Text Color', 'interico' ),
						'section'     	=> 'tc_interico_styling_section',
						'settings'    	=> 'tc_primary_btn_text',
						'priority'    	=> 30,
					)
				)
			);

			$wp_customize->add_setting( 'tc_primary_btn_text_hover',
				array(
					'default'     		=> '#ffffff',
			        'transport'			=> 'refresh',
			        'type'				=> 'theme_mod',
			        'capability'		=> 'edit_theme_options',
				    'sanitize_callback' => 'sanitize_hex_color'
				)
			);
			$wp_customize->add_control( new WP_Customize_Color_Control( 
				$wp_customize, 'tc_primary_btn_text_hover', 
					array(
						'label'       	=> esc_html__( 'Primary Button Text Hover Color', 'interico' ),
						'section'     	=> 'tc_interico_styling_section',
						'settings'    	=> 'tc_primary_btn_text_hover',
						'priority'    	=> 30,
					)
				)
			);

			$wp_customize->add_setting( 'tc_regular_btn_color',
				array(
				    'default'     		=> '#ddd',
			        'transport'			=> 'refresh',
			        'type'				=> 'theme_mod',
			        'capability'		=> 'edit_theme_options',
				    'sanitize_callback' => 'sanitize_hex_color'
				)
			);
			$wp_customize->add_control( new WP_Customize_Color_Control( 
				$wp_customize, 'tc_regular_btn_color', 
					array(
						'label'       	=> esc_html__( 'Regular Button Outline Color', 'interico' ),
						'section'     	=> 'tc_interico_styling_section',
						'settings'    	=> 'tc_regular_btn_color',
						'priority'    	=> 30,
					)
				)
			);

			$wp_customize->add_setting( 'tc_regular_btn_text',
				array(
				    'default'     		=> '#999',
			        'transport'			=> 'refresh',
			        'type'				=> 'theme_mod',
			        'capability'		=> 'edit_theme_options',
				    'sanitize_callback' => 'sanitize_hex_color'
				)
			);
			$wp_customize->add_control( new WP_Customize_Color_Control( 
				$wp_customize, 'tc_regular_btn_text', 
					array(
						'label'       	=> esc_html__( 'Regular Button Text Color', 'interico' ),
						'section'     	=> 'tc_interico_styling_section',
						'settings'    	=> 'tc_regular_btn_text',
						'priority'    	=> 30,
					)
				)
			);

			$wp_customize->add_setting( 'tc_regular_btn_text_hover',
				array(
				    'default'     		=> '#777',
			        'transport'			=> 'refresh',
			        'type'				=> 'theme_mod',
			        'capability'		=> 'edit_theme_options',
				    'sanitize_callback' => 'sanitize_hex_color'
				)
			);
			$wp_customize->add_control( new WP_Customize_Color_Control( 
				$wp_customize, 'tc_regular_btn_text_hover', 
					array(
						'label'       	=> esc_html__( 'Regular Button Text Hover Color', 'interico' ),
						'section'     	=> 'tc_interico_styling_section',
						'settings'    	=> 'tc_regular_btn_text_hover',
						'priority'    	=> 30,
					)
				)
			);

			$wp_customize->add_setting( 'tc_tab_heading_color',
				array(
			        'transport'			=> 'refresh',
			        'type'				=> 'theme_mod',
			        'capability'		=> 'edit_theme_options',
				    'sanitize_callback' => 'sanitize_hex_color'
				)
			);
			$wp_customize->add_control( new WP_Customize_Color_Control( 
				$wp_customize, 'tc_tab_heading_color', 
					array(
						'label'       	=> esc_html__( 'Tab Heading Background Color', 'interico' ),
						'section'     	=> 'tc_interico_styling_section',
						'settings'    	=> 'tc_tab_heading_color',
						'priority'    	=> 30,
					)
				)
			);

			$wp_customize->add_setting( 'tc_tab_content_color',
				array(
			        'transport'			=> 'refresh',
			        'type'				=> 'theme_mod',
			        'capability'		=> 'edit_theme_options',
				    'sanitize_callback' => 'sanitize_hex_color'
				)
			);
			$wp_customize->add_control( new WP_Customize_Color_Control( 
				$wp_customize, 'tc_tab_content_color', 
					array(
						'label'       	=> esc_html__( 'Tab Content Background Color', 'interico' ),
						'section'     	=> 'tc_interico_styling_section',
						'settings'    	=> 'tc_tab_content_color',
						'priority'    	=> 30,
					)
				)
			);

			$wp_customize->add_setting( 'tc_accordion_heading_color',
				array(
			        'transport'			=> 'refresh',
			        'type'				=> 'theme_mod',
			        'capability'		=> 'edit_theme_options',
				    'sanitize_callback' => 'sanitize_hex_color'
				)
			);
			$wp_customize->add_control( new WP_Customize_Color_Control( 
				$wp_customize, 'tc_accordion_heading_color', 
					array(
						'label'       	=> esc_html__( 'Accordion Heading Background Color', 'interico' ),
						'section'     	=> 'tc_interico_styling_section',
						'settings'    	=> 'tc_accordion_heading_color',
						'priority'    	=> 30,
					)
				)
			);

			$wp_customize->add_setting( 'tc_accordion_panel_color',
				array(
			        'transport'			=> 'refresh',
			        'type'				=> 'theme_mod',
			        'capability'		=> 'edit_theme_options',
				    'sanitize_callback' => 'sanitize_hex_color'
				)
			);
			$wp_customize->add_control( new WP_Customize_Color_Control( 
				$wp_customize, 'tc_accordion_panel_color', 
					array(
						'label'       	=> esc_html__( 'Accordion Content Background Color', 'interico' ),
						'section'     	=> 'tc_interico_styling_section',
						'settings'    	=> 'tc_accordion_panel_color',
						'priority'    	=> 30,
					)
				)
			);

			$wp_customize->add_setting( 'tc_slider_span_color',
				array(
			        'transport'			=> 'refresh',
			        'type'				=> 'theme_mod',
			        'capability'		=> 'edit_theme_options',
				    'sanitize_callback' => 'sanitize_hex_color'
				)
			);
			$wp_customize->add_control( new WP_Customize_Color_Control( 
				$wp_customize, 'tc_slider_span_color', 
					array(
						'label'       	=> esc_html__( 'Slider Heading Span Color', 'interico' ),
						'section'     	=> 'tc_interico_styling_section',
						'settings'    	=> 'tc_slider_span_color',
						'priority'    	=> 30,
					)
				)
			);


			$wp_customize->add_setting( 'tc_show_preloader', 
				array(
		        	'default'  			=> 'yes',
		        	'transport'			=> 'refresh',
		        	'type'				=> 'theme_mod',
		        	'capability'		=> 'edit_theme_options',
		        	'sanitize_callback' => 'interico_sanitize_select',
		    	)
			);
			$wp_customize->add_control( 'tc_show_preloader', 
				array(
					'label'    			=> esc_html__( 'Display Preloader', 'interico' ),
					'section'  			=> 'tc_interico_styling_section',
					'settings' 			=> 'tc_show_preloader',
					'type'    			=> 'select',
					'choices'  			=> array(
						'yes'  			=> esc_html__( 'Yes', 'interico' ),
						'no' 			=> esc_html__( 'No', 'interico' ),
					),
					'priority' 			=> 35,
				)
			);

			$wp_customize->add_setting( 'tc_preloader_bg',
				array(
				    'default'     		=> '#444',
			        'transport'			=> 'refresh',
			        'type'				=> 'theme_mod',
			        'capability'		=> 'edit_theme_options',
				    'sanitize_callback' => 'sanitize_hex_color'
				)
			);
			$wp_customize->add_control( new WP_Customize_Color_Control( 
				$wp_customize, 'tc_preloader_bg', 
					array(
						'label'       	=> esc_html__( 'Preloader Background Color', 'interico' ),
						'section'     	=> 'tc_interico_styling_section',
						'settings'    	=> 'tc_preloader_bg',
						'priority'    	=> 35,
					)
				)
			);

			$wp_customize->add_setting( 'tc_preloader_circle',
				array(
				    'default'     		=> '#666',
			        'transport'			=> 'refresh',
			        'type'				=> 'theme_mod',
			        'capability'		=> 'edit_theme_options',
				    'sanitize_callback' => 'sanitize_hex_color'
				)
			);
			$wp_customize->add_control( new WP_Customize_Color_Control( 
				$wp_customize, 'tc_preloader_circle', 
					array(
						'label'       	=> esc_html__( 'Preloader Circle Color', 'interico' ),
						'section'     	=> 'tc_interico_styling_section',
						'settings'    	=> 'tc_preloader_circle',
						'priority'    	=> 35,
					)
				)
			);

			$wp_customize->add_setting( 'tc_preloader_spinner',
				array(
				    'default'     		=> '#eee',
			        'transport'			=> 'refresh',
			        'type'				=> 'theme_mod',
			        'capability'		=> 'edit_theme_options',
				    'sanitize_callback' => 'sanitize_hex_color'
				)
			);
			$wp_customize->add_control( new WP_Customize_Color_Control( 
				$wp_customize, 'tc_preloader_spinner', 
					array(
						'label'       	=> esc_html__( 'Preloader Spinner Color', 'interico' ),
						'section'     	=> 'tc_interico_styling_section',
						'settings'    	=> 'tc_preloader_spinner',
						'priority'    	=> 35,
					)
				)
			);

			$wp_customize->add_setting( 'tc_show_breadcrumbs', 
				array(
		        	'default'  			=> 'yes',
		        	'transport'			=> 'refresh',
		        	'type'				=> 'theme_mod',
		        	'capability'		=> 'edit_theme_options',
		        	'sanitize_callback' => 'interico_sanitize_select',
		    	)
			);
			$wp_customize->add_control( 'tc_show_breadcrumbs', 
				array(
					'label'    			=> esc_html__( 'Display Breadcrumbs', 'interico' ),
					'section'  			=> 'tc_interico_styling_section',
					'settings' 			=> 'tc_show_breadcrumbs',
					'type'    			=> 'select',
					'choices'  			=> array(
						'yes'  			=> esc_html__( 'Yes', 'interico' ),
						'no' 			=> esc_html__( 'No', 'interico' ),
					),
					'priority' 			=> 35,
				)
			);	

			$wp_customize->add_setting( 'tc_custom_css', 
				array(
			    	'transport'			=> 'refresh',
			    	'type'				=> 'theme_mod',
			    	'capability'		=> 'edit_theme_options',
			    	'sanitize_callback' => 'interico_sanitize_textarea',
				)
			);
			$wp_customize->add_control( 'tc_custom_css', 
				array(
			    	'label' 			=> esc_html__( 'Custom CSS', 'interico' ),
			    	'section' 			=> 'tc_interico_styling_section',
			    	'settings' 			=> 'tc_custom_css',
			    	'type' 				=> 'textarea',
			    	'priority' 			=> 40,
				)
			);

		/*-----------------------------------------------------------*
		 * 6. Social Media
		 *-----------------------------------------------------------*/

		$wp_customize->add_section( 'tc_interico_social_section',
			array(
				'title'       			=> esc_html__( 'Social Media', 'interico' ),
				'description' 			=> esc_html__( 'Social media icons appean on Top Subnav and on the bottom footer. All URLS must begin with http://', 'interico' ),
				'priority'    			=> 10,
				'panel'       			=> 'tc_interico_options',
			)
		);

			$wp_customize->add_setting( 'tc_social_icon_hover_color',
				array(
				    'default'     		=> '#ffffff',
			        'transport'			=> 'refresh',
			        'type'				=> 'theme_mod',
			        'capability'		=> 'edit_theme_options',
				    'sanitize_callback' => 'sanitize_hex_color'
				)
			);
			$wp_customize->add_control( new WP_Customize_Color_Control( 
				$wp_customize, 'tc_social_icon_hover_color', 
					array(
						'label'       	=> esc_html__( 'Social Icon Hover Color', 'interico' ),
						'section'     	=> 'tc_interico_social_section',
						'settings'    	=> 'tc_social_icon_hover_color',
						'priority'    	=> 10,
					)
				)
			);

			$wp_customize->add_setting( 'tc_social_icon_bg_hover_color',
				array(
				    'default'     		=> '#7d6741',
			        'transport'			=> 'refresh',
			        'type'				=> 'theme_mod',
			        'capability'		=> 'edit_theme_options',
				    'sanitize_callback' => 'sanitize_hex_color',
				)
			);
			$wp_customize->add_control( new WP_Customize_Color_Control( 
				$wp_customize, 'tc_social_icon_bg_hover_color', 
					array(
						'label'       	=> esc_html__( 'Social Icon Background Hover Color', 'interico' ),
						'section'     	=> 'tc_interico_social_section',
						'settings'    	=> 'tc_social_icon_bg_hover_color',
						'priority'    	=> 15,
					)
				)
			);

			$wp_customize->add_setting( 'tc_social_icon_bg_color_footer',
				array(
				    'default'     		=> '#aaaaaa',
			        'transport'			=> 'refresh',
			        'type'				=> 'theme_mod',
			        'capability'		=> 'edit_theme_options',
				    'sanitize_callback' => 'sanitize_hex_color',
				)
			);
			$wp_customize->add_control( new WP_Customize_Color_Control( 
				$wp_customize, 'tc_social_icon_bg_color_footer', 
					array(
						'label'       	=> esc_html__( 'Footer Social Icon Background Hover Color', 'interico' ),
						'section'     	=> 'tc_interico_social_section',
						'settings'    	=> 'tc_social_icon_bg_color_footer',
						'priority'    	=> 15,
					)
				)
			);

			$wp_customize->add_setting( 'tc_social_facebook', 
				array(
			    	'transport'			=> 'refresh',
			    	'type'				=> 'theme_mod',
			    	'capability'		=> 'edit_theme_options',
			    	'sanitize_callback' => 'interico_sanitize_text',
			    	'default'			=> 'http://',
				)
			);
			$wp_customize->add_control( 'tc_social_facebook', 
				array(
				    'label' 			=> esc_html__( 'Facebook Profile Link', 'interico' ),
				    'section' 			=> 'tc_interico_social_section',
				    'settings' 			=> 'tc_social_facebook',
				    'type' 				=> 'text',
				    'priority' 			=> 20,
				)
			);

			$wp_customize->add_setting( 'tc_social_linkedin', 
				array(
			    	'transport'			=> 'refresh',
			    	'type'				=> 'theme_mod',
			    	'capability'		=> 'edit_theme_options',
			    	'sanitize_callback' => 'interico_sanitize_text',
				)
			);
			$wp_customize->add_control( 'tc_social_linkedin', 
				array(
				    'label' 			=> esc_html__( 'LinkedIn Profile Link', 'interico' ),
				    'section' 			=> 'tc_interico_social_section',
				    'settings' 			=> 'tc_social_linkedin',
				    'type' 				=> 'text',
				    'priority' 			=> 25,
				)
			);

			$wp_customize->add_setting( 'tc_social_twitter', 
				array(
			    	'transport'			=> 'refresh',
			    	'type'				=> 'theme_mod',
			    	'capability'		=> 'edit_theme_options',
			    	'sanitize_callback' => 'interico_sanitize_text',
				)
			);
			$wp_customize->add_control( 'tc_social_twitter', 
				array(
				    'label' 			=> esc_html__( 'Twitter Profile Link', 'interico' ),
				    'section' 			=> 'tc_interico_social_section',
				    'settings' 			=> 'tc_social_twitter',
				    'type' 				=> 'text',
				    'priority' 			=> 30,
				)
			);

			$wp_customize->add_setting( 'tc_social_google', 
				array(
			    	'transport'			=> 'refresh',
			    	'type'				=> 'theme_mod',
			    	'capability'		=> 'edit_theme_options',
			    	'sanitize_callback' => 'interico_sanitize_text',
				)
			);
			$wp_customize->add_control( 'tc_social_google', 
				array(
				    'label' 			=> esc_html__( 'Google+ Profile Link', 'interico' ),
				    'section' 			=> 'tc_interico_social_section',
				    'settings' 			=> 'tc_social_google',
				    'type' 				=> 'text',
				    'priority' 			=> 35,
				)
			);

			$wp_customize->add_setting( 'tc_social_pinterest', 
				array(
			    	'transport'			=> 'refresh',
			    	'type'				=> 'theme_mod',
			    	'capability'		=> 'edit_theme_options',
			    	'sanitize_callback' => 'interico_sanitize_text',
				)
			);
			$wp_customize->add_control( 'tc_social_pinterest', 
				array(
				    'label' 			=> esc_html__( 'Pinterest Profile Link', 'interico' ),
				    'section' 			=> 'tc_interico_social_section',
				    'settings' 			=> 'tc_social_pinterest',
				    'type' 				=> 'text',
				    'priority' 			=> 40,
				)
			);

			$wp_customize->add_setting( 'tc_social_youtube', 
				array(
			    	'transport'			=> 'refresh',
			    	'type'				=> 'theme_mod',
			    	'capability'		=> 'edit_theme_options',
			    	'sanitize_callback' => 'interico_sanitize_text',
				)
			);
			$wp_customize->add_control( 'tc_social_youtube', 
				array(
				    'label' 			=> esc_html__( 'Youtube Profile Link', 'interico' ),
				    'section' 			=> 'tc_interico_social_section',
				    'settings' 			=> 'tc_social_youtube',
				    'type' 				=> 'text',
				    'priority' 			=> 45,
				)
			);

			$wp_customize->add_setting( 'tc_social_instagram', 
				array(
			    	'transport'			=> 'refresh',
			    	'type'				=> 'theme_mod',
			    	'capability'		=> 'edit_theme_options',
			    	'sanitize_callback' => 'interico_sanitize_text',
				)
			);
			$wp_customize->add_control( 'tc_social_instagram', 
				array(
				    'label' 			=> esc_html__( 'Instagram Profile Link', 'interico' ),
				    'section' 			=> 'tc_interico_social_section',
				    'settings' 			=> 'tc_social_instagram',
				    'type' 				=> 'text',
				    'priority' 			=> 50,
				)
			);


		/*-----------------------------------------------------------*
		 * 7. Widgets Styling
		 *-----------------------------------------------------------*/

		$wp_customize->add_section( 'tc_interico_widget_styling_section',
			array(
				'title'       			=> esc_html__( 'Widgets Styling', 'interico' ),
				'description' 			=> esc_html__( 'Control colors for variety of widgets, such as Gallery, Feature box, etc.', 'interico' ),
				'priority'    			=> 10,
				'panel'       			=> 'tc_interico_options',
			)
		);

			// Widget: Feature Box
			$wp_customize->add_setting( 'tc_featured_box_icon_color',
				array(
				    'default'     		=> '#7d6741',
			        'transport'			=> 'refresh',
			        'type'				=> 'theme_mod',
			        'capability'		=> 'edit_theme_options',
				    'sanitize_callback' => 'sanitize_hex_color',
				)
			);
			$wp_customize->add_control( new WP_Customize_Color_Control( 
				$wp_customize, 'tc_featured_box_icon_color', 
					array(
						'label'       	=> esc_html__( 'Feature Icon Color', 'interico' ),
						'description' 	=> esc_html__( 'Widget: Feature Box', 'interico' ),
						'section'     	=> 'tc_interico_widget_styling_section',
						'settings'    	=> 'tc_featured_box_icon_color',
						'priority'    	=> 10,
					)
				)
			);

			$wp_customize->add_setting( 'tc_featured_box_icon_hover',
				array(
				    'default'     		=> '#7d6741',
			        'transport'			=> 'refresh',
			        'type'				=> 'theme_mod',
			        'capability'		=> 'edit_theme_options',
				    'sanitize_callback' => 'sanitize_hex_color',
				)
			);
			$wp_customize->add_control( new WP_Customize_Color_Control( 
				$wp_customize, 'tc_featured_box_icon_hover', 
					array(
						'label'       	=> esc_html__( 'Feature Icon Hover Color', 'interico' ),
						'description' 	=> esc_html__( 'Widget: Feature Box', 'interico' ),
						'section'     	=> 'tc_interico_widget_styling_section',
						'settings'    	=> 'tc_featured_box_icon_hover',
						'priority'    	=> 10,
					)
				)
			);

			$wp_customize->add_setting( 'tc_featured_box_headline_color',
				array(
				    'default'     		=> '#222222',
			        'transport'			=> 'refresh',
			        'type'				=> 'theme_mod',
			        'capability'		=> 'edit_theme_options',
				    'sanitize_callback' => 'sanitize_hex_color',
				)
			);
			$wp_customize->add_control( new WP_Customize_Color_Control( 
				$wp_customize, 'tc_featured_box_headline_color', 
					array(
						'label'       	=> esc_html__( 'Feature Headline Color', 'interico' ),
						'description' 	=> esc_html__( 'Widget: Feature Box', 'interico' ),
						'section'     	=> 'tc_interico_widget_styling_section',
						'settings'    	=> 'tc_featured_box_headline_color',
						'priority'    	=> 10,
					)
				)
			);

			$wp_customize->add_setting( 'tc_featured_box_headline_hover_color',
				array(
				    'default'     		=> '#7d6741',
			        'transport'			=> 'refresh',
			        'type'				=> 'theme_mod',
			        'capability'		=> 'edit_theme_options',
				    'sanitize_callback' => 'sanitize_hex_color',
				)
			);
			$wp_customize->add_control( new WP_Customize_Color_Control( 
				$wp_customize, 'tc_featured_box_headline_hover_color', 
					array(
						'label'       	=> esc_html__( 'Feature Headline Hover Color', 'interico' ),
						'description' 	=> esc_html__( 'Widget: Feature Box', 'interico' ),
						'section'     	=> 'tc_interico_widget_styling_section',
						'settings'    	=> 'tc_featured_box_headline_hover_color',
						'priority'    	=> 10,
					)
				)
			);

			// Widget: Number Box
			$wp_customize->add_setting( 'tc_number_box_headline_color',
				array(
			        'transport'			=> 'refresh',
			        'type'				=> 'theme_mod',
			        'capability'		=> 'edit_theme_options',
				    'sanitize_callback' => 'sanitize_hex_color',
				)
			);
			$wp_customize->add_control( new WP_Customize_Color_Control( 
				$wp_customize, 'tc_number_box_headline_color', 
					array(
						'label'       	=> esc_html__( 'Headline Color', 'interico' ),
						'description' 	=> esc_html__( 'Widget: Number Box', 'interico' ),
						'section'     	=> 'tc_interico_widget_styling_section',
						'settings'    	=> 'tc_number_box_headline_color',
						'priority'    	=> 10,
					)
				)
			);

			$wp_customize->add_setting( 'tc_number_box_headline_hover_color',
				array(
				    'default'     		=> '#7d6741',
			        'type'				=> 'theme_mod',
			        'capability'		=> 'edit_theme_options',
				     'transport'			=> 'refresh',
			       'sanitize_callback' => 'sanitize_hex_color',
				)
			);
			$wp_customize->add_control( new WP_Customize_Color_Control( 
				$wp_customize, 'tc_number_box_headline_hover_color', 
					array(
						'label'       	=> esc_html__( 'Headline Hover Color', 'interico' ),
						'description' 	=> esc_html__( 'Widget: Number Box', 'interico' ),
						'section'     	=> 'tc_interico_widget_styling_section',
						'settings'    	=> 'tc_number_box_headline_hover_color',
						'priority'    	=> 10,
					)
				)
			);

			$wp_customize->add_setting( 'tc_number_box_number_bg',
				array(
				    'default'     		=> '#7d6741',
			        'transport'			=> 'refresh',
			        'type'				=> 'theme_mod',
			        'capability'		=> 'edit_theme_options',
				    'sanitize_callback' => 'sanitize_hex_color',
				)
			);
			$wp_customize->add_control( new WP_Customize_Color_Control( 
				$wp_customize, 'tc_number_box_number_bg', 
					array(
						'label'       	=> esc_html__( 'Number Background Color (Style 1)', 'interico' ),
						'description' 	=> esc_html__( 'Widget: Number Box', 'interico' ),
						'section'     	=> 'tc_interico_widget_styling_section',
						'settings'    	=> 'tc_number_box_number_bg',
						'priority'    	=> 10,
					)
				)
			);

			$wp_customize->add_setting( 'tc_number_box_number_bg_hover',
				array(
					'default'     		=> '#333333',
			        'type'				=> 'theme_mod',
			        'capability'		=> 'edit_theme_options',
				     'transport'			=> 'refresh',
			       'sanitize_callback' => 'sanitize_hex_color',
				)
			);
			$wp_customize->add_control( new WP_Customize_Color_Control( 
				$wp_customize, 'tc_number_box_number_bg_hover', 
					array(
						'label'       	=> esc_html__( 'Number Background Hover Color (Style 1)', 'interico' ),
						'description' 	=> esc_html__( 'Widget: Number Box', 'interico' ),
						'section'     	=> 'tc_interico_widget_styling_section',
						'settings'    	=> 'tc_number_box_number_bg_hover',
						'priority'    	=> 10,
					)
				)
			);

			$wp_customize->add_setting( 'tc_image_box_hover_bg',
				array(
					'default'     		=> '#7d6741',
			        'transport'			=> 'refresh',
			        'type'				=> 'theme_mod',
			        'capability'		=> 'edit_theme_options',
				    'sanitize_callback' => 'sanitize_hex_color',
				)
			);
			$wp_customize->add_control( new WP_Customize_Color_Control( 
				$wp_customize, 'tc_image_box_hover_bg', 
					array(
						'label'       	=> esc_html__( 'Image Box Background Hover', 'interico' ),
						'description' 	=> esc_html__( 'Widget: Image Box', 'interico' ),
						'section'     	=> 'tc_interico_widget_styling_section',
						'settings'    	=> 'tc_image_box_hover_bg',
						'priority'    	=> 25,
					)
				)
			);

			$wp_customize->add_setting( 'tc_image_box_headline_hover',
				array(
					'default'     		=> '#7d6741',
			        'transport'			=> 'refresh',
			        'type'				=> 'theme_mod',
			        'capability'		=> 'edit_theme_options',
				    'sanitize_callback' => 'sanitize_hex_color',
				)
			);
			$wp_customize->add_control( new WP_Customize_Color_Control( 
				$wp_customize, 'tc_image_box_headline_hover', 
					array(
						'label'       	=> esc_html__( 'Image Box Headline Hover (Style Light)', 'interico' ),
						'description' 	=> esc_html__( 'Widget: Image Box', 'interico' ),
						'section'     	=> 'tc_interico_widget_styling_section',
						'settings'    	=> 'tc_image_box_headline_hover',
						'priority'    	=> 25,
					)
				)
			);

			$wp_customize->add_setting( 'tc_team_headline_hover',
				array(
					'default'     		=> '#7d6741',
			        'transport'			=> 'refresh',
			        'type'				=> 'theme_mod',
			        'capability'		=> 'edit_theme_options',
				    'sanitize_callback' => 'sanitize_hex_color',
				)
			);
			$wp_customize->add_control( new WP_Customize_Color_Control( 
				$wp_customize, 'tc_team_headline_hover', 
					array(
						'label'       	=> esc_html__( 'Team Headline Hover', 'interico' ),
						'description' 	=> esc_html__( 'Widget: Team Member', 'interico' ),
						'section'     	=> 'tc_interico_widget_styling_section',
						'settings'    	=> 'tc_team_headline_hover',
						'priority'    	=> 25,
					)
				)
			);

			// Widget: Projects Gallery
			$wp_customize->add_setting( 'tc_gallery_color_scheme',
				array(
					'default'  			=> 'dark',
					'transport'			=> 'refresh',
					'type'				=> 'theme_mod',
					'capability'		=> 'edit_theme_options',
					'sanitize_callback' => 'interico_sanitize_select',
				)
			);
			$wp_customize->add_control( 'tc_gallery_color_scheme', 
				array(
					'label'				=> esc_html__( 'Gallery Dark or Light Color Scheme', 'interico' ),
					'description' 		=> esc_html__( 'Widget: Projects Gallery', 'interico' ),
					'section'			=> 'tc_interico_widget_styling_section',
					'settings'			=> 'tc_gallery_color_scheme',
					'type'				=> 'select',
					'choices'			=> array(
						'dark'			=> esc_html__( 'Dark', 'interico' ),
						'light'			=> esc_html__( 'Light', 'interico' ),
					),
					'priority'			=> 10,
				)
			);

			$wp_customize->add_setting( 'tc_gallery_slider_hover_bg',
				array(
					'default'     		=> '#7d6741',
			        'transport'			=> 'refresh',
			        'type'				=> 'theme_mod',
			        'capability'		=> 'edit_theme_options',
				    'sanitize_callback' => 'sanitize_hex_color',
				)
			);
			$wp_customize->add_control( new WP_Customize_Color_Control( 
				$wp_customize, 'tc_gallery_slider_hover_bg', 
					array(
						'label'       	=> esc_html__( 'Slider Item Background Hover', 'interico' ),
						'description' 	=> esc_html__( 'Widget: Projects Gallery', 'interico' ),
						'section'     	=> 'tc_interico_widget_styling_section',
						'settings'    	=> 'tc_gallery_slider_hover_bg',
						'priority'    	=> 25,
					)
				)
			);

			$wp_customize->add_setting( 'tc_slider_arrow_hover_bg',
				array(
					'default'     		=> '#7d6741',
			        'transport'			=> 'refresh',
			        'type'				=> 'theme_mod',
			        'capability'		=> 'edit_theme_options',
				    'sanitize_callback' => 'sanitize_hex_color',
				)
			);
			$wp_customize->add_control( new WP_Customize_Color_Control( 
				$wp_customize, 'tc_slider_arrow_hover_bg', 
					array(
						'label'       	=> esc_html__( 'Slider Arrow Background Hover', 'interico' ),
						'description' 	=> esc_html__( 'Widget: Projects Gallery', 'interico' ),
						'section'     	=> 'tc_interico_widget_styling_section',
						'settings'    	=> 'tc_slider_arrow_hover_bg',
						'priority'    	=> 25,
					)
				)
			);
	

			$wp_customize->add_setting( 'tc_gallery_active_bg',
				array(
				    'default'     		=> '#dddddd',
			        'transport'			=> 'refresh',
			        'type'				=> 'theme_mod',
			        'capability'		=> 'edit_theme_options',
				    'sanitize_callback' => 'sanitize_hex_color',
				)
			);
			$wp_customize->add_control( new WP_Customize_Color_Control( 
				$wp_customize, 'tc_gallery_active_bg', 
					array(
						'label'       	=> esc_html__( 'Gallery Active Category Background', 'interico' ),
						'description' 	=> esc_html__( 'Widget: Projects Gallery', 'interico' ),
						'section'     	=> 'tc_interico_widget_styling_section',
						'settings'    	=> 'tc_gallery_active_bg',
						'priority'    	=> 15,
					)
				)
			);

			$wp_customize->add_setting( 'tc_gallery_active_text',
				array(
					'default'     		=> '#000',
			        'transport'			=> 'refresh',
			        'type'				=> 'theme_mod',
			        'capability'		=> 'edit_theme_options',
				    'sanitize_callback' => 'sanitize_hex_color',
				)
			);
			$wp_customize->add_control( new WP_Customize_Color_Control( 
				$wp_customize, 'tc_gallery_active_text', 
					array(
						'label'       	=> esc_html__( 'Gallery Active Category Text', 'interico' ),
						'description' 	=> esc_html__( 'Widget: Projects Gallery', 'interico' ),
						'section'     	=> 'tc_interico_widget_styling_section',
						'settings'    	=> 'tc_gallery_active_text',
						'priority'    	=> 20,
					)
				)
			);

			$wp_customize->add_setting( 'tc_gallery_regular_bg',
				array(
			        'transport'			=> 'refresh',
			        'type'				=> 'theme_mod',
			        'capability'		=> 'edit_theme_options',
				    'sanitize_callback' => 'sanitize_hex_color',
				)
			);
			$wp_customize->add_control( new WP_Customize_Color_Control( 
				$wp_customize, 'tc_gallery_regular_bg', 
					array(
						'label'       	=> esc_html__( 'Gallery Category Background', 'interico' ),
						'description' 	=> esc_html__( 'Widget: Projects Gallery', 'interico' ),
						'section'     	=> 'tc_interico_widget_styling_section',
						'settings'    	=> 'tc_gallery_regular_bg',
						'priority'    	=> 20,
					)
				)
			);

			$wp_customize->add_setting( 'tc_gallery_regular_text',
				array(
			        'transport'			=> 'refresh',
			        'type'				=> 'theme_mod',
			        'capability'		=> 'edit_theme_options',
				    'sanitize_callback' => 'sanitize_hex_color',
				)
			);
			$wp_customize->add_control( new WP_Customize_Color_Control( 
				$wp_customize, 'tc_gallery_regular_text', 
					array(
						'label'       	=> esc_html__( 'Gallery Category Text', 'interico' ),
						'description' 	=> esc_html__( 'Widget: Projects Gallery', 'interico' ),
						'section'     	=> 'tc_interico_widget_styling_section',
						'settings'    	=> 'tc_gallery_regular_text',
						'priority'    	=> 20,
					)
				)
			);

			$wp_customize->add_setting( 'tc_gallery_item_category_text',
				array(
					'default'     		=> '#cccccc',
			        'transport'			=> 'refresh',
			        'type'				=> 'theme_mod',
			        'capability'		=> 'edit_theme_options',
				    'sanitize_callback' => 'sanitize_hex_color',
				)
			);
			$wp_customize->add_control( new WP_Customize_Color_Control( 
				$wp_customize, 'tc_gallery_item_category_text', 
					array(
						'label'       	=> esc_html__( 'Gallery Hovered Item Category Color', 'interico' ),
						'description' 	=> esc_html__( 'Widget: Projects Gallery', 'interico' ),
						'section'     	=> 'tc_interico_widget_styling_section',
						'settings'    	=> 'tc_gallery_item_category_text',
						'priority'    	=> 25,
					)
				)
			);	

			$wp_customize->add_setting( 'tc_gallery_bg',
				array(
			        'transport'			=> 'refresh',
			        'type'				=> 'theme_mod',
			        'capability'		=> 'edit_theme_options',
				    'sanitize_callback' => 'sanitize_hex_color',
				)
			);
			$wp_customize->add_control( new WP_Customize_Color_Control( 
				$wp_customize, 'tc_gallery_bg', 
					array(
						'label'       	=> esc_html__( 'Gallery Background', 'interico' ),
						'description' 	=> esc_html__( 'Widget: Projects Gallery', 'interico' ),
						'section'     	=> 'tc_interico_widget_styling_section',
						'settings'    	=> 'tc_gallery_bg',
						'priority'    	=> 20,
					)
				)
			);

			$wp_customize->add_setting( 'tc_gallery_button_text',
				array(
			        'transport'			=> 'refresh',
			        'type'				=> 'theme_mod',
			        'capability'		=> 'edit_theme_options',
				    'sanitize_callback' => 'sanitize_hex_color',
				)
			);
			$wp_customize->add_control( new WP_Customize_Color_Control( 
				$wp_customize, 'tc_gallery_button_text', 
					array(
						'label'       	=> esc_html__( 'All Projects Button Text Color', 'interico' ),
						'description' 	=> esc_html__( 'Widget: Projects Gallery', 'interico' ),
						'section'     	=> 'tc_interico_widget_styling_section',
						'settings'    	=> 'tc_gallery_button_text',
						'priority'    	=> 25,
					)
				)
			);	

			$wp_customize->add_setting( 'tc_gallery_button_bg',
				array(
			        'transport'			=> 'refresh',
			        'type'				=> 'theme_mod',
			        'capability'		=> 'edit_theme_options',
				    'sanitize_callback' => 'sanitize_hex_color',
				)
			);
			$wp_customize->add_control( new WP_Customize_Color_Control( 
				$wp_customize, 'tc_gallery_button_bg', 
					array(
						'label'       	=> esc_html__( 'All Projects Button Background Color', 'interico' ),
						'description' 	=> esc_html__( 'Widget: Projects Gallery', 'interico' ),
						'section'     	=> 'tc_interico_widget_styling_section',
						'settings'    	=> 'tc_gallery_button_bg',
						'priority'    	=> 25,
					)
				)
			);	

			$wp_customize->add_setting( 'tc_testimonial_box_bg',
				array(
			        'transport'			=> 'refresh',
			        'type'				=> 'theme_mod',
			        'capability'		=> 'edit_theme_options',
				    'sanitize_callback' => 'sanitize_hex_color',
				)
			);
			$wp_customize->add_control( new WP_Customize_Color_Control( 
				$wp_customize, 'tc_testimonial_box_bg', 
					array(
						'label'       	=> esc_html__( 'Testimonial Background Color (Style Dark)', 'interico' ),
						'description' 	=> esc_html__( 'Widget: Testimonials', 'interico' ),
						'section'     	=> 'tc_interico_widget_styling_section',
						'settings'    	=> 'tc_testimonial_box_bg',
						'priority'    	=> 25,
					)
				)
			);

			// Widget: Blog
			$wp_customize->add_setting( 'tc_blog_headline_hover_color',
				array(
					'default'     		=> '#7d6741',
			        'transport'			=> 'refresh',
			        'type'				=> 'theme_mod',
			        'capability'		=> 'edit_theme_options',
				    'sanitize_callback' => 'sanitize_hex_color',
				)
			);
			$wp_customize->add_control( new WP_Customize_Color_Control( 
				$wp_customize, 'tc_blog_headline_hover_color', 
					array(
						'label'       	=> esc_html__( 'Blog Headline Hover Color', 'interico' ),
						'description' 	=> esc_html__( 'Widget: Blog Posts', 'interico' ),
						'section'     	=> 'tc_interico_widget_styling_section',
						'settings'    	=> 'tc_blog_headline_hover_color',
						'priority'    	=> 25,
					)
				)
			);



		/*-----------------------------------------------------------*
		 * 8. Footer CTA
		 *-----------------------------------------------------------*/

		$wp_customize->add_section( 'tc_interico_footer_cta_section',
			array(
				'title'       			=> esc_html__( 'Footer CTA', 'interico' ),
				'description' 			=> esc_html__( 'Customize footer CTA', 'interico' ),
				'priority'    			=> 10,
				'panel'       			=> 'tc_interico_options',
			)
		);

			$wp_customize->add_setting( 'tc_footer_cta', 
				array(
		        	'default'  			=> 'no',
		        	'transport'			=> 'refresh',
		        	'type'				=> 'theme_mod',
		        	'capability'		=> 'edit_theme_options',
		        	'sanitize_callback' => 'interico_sanitize_select',
		    	)
			);
			$wp_customize->add_control( 'tc_footer_cta', 
				array(
					'label'    			=> esc_html__( 'Show Footer CTA', 'interico' ),
					'section'  			=> 'tc_interico_footer_cta_section',
					'settings' 			=> 'tc_footer_cta',
					'type'    			=> 'select',
					'choices'  			=> array(
						'yes'  			=> esc_html__( 'Yes', 'interico' ),
						'no' 			=> esc_html__( 'No', 'interico' ),
					),
					'priority' 			=> 10,
				)
			);	

			$wp_customize->add_setting( 'tc_footer_cta_text',
				array(
					'default'            => 'Get a Free Quote for Your Project. Click Here.',
					'sanitize_callback'  => 'interico_sanitize_input',
					'capability'		 => 'edit_theme_options',
					'type'				 => 'theme_mod',
					'transport'          => 'refresh',
				)
			);
			$wp_customize->add_control( 'tc_footer_cta_text',
				array(
					'section' 			 => 'tc_interico_footer_cta_section',
					'label'   			 => esc_html__( 'Footer CTA Text', 'interico' ),
					'type'    			 => 'text',
					'settings'			 => 'tc_footer_cta_text',
					'priority'			 => 15,
				)
			);

			$wp_customize->add_setting( 'tc_footer_cta_link',
				array(
					'default'            => '#',
					'sanitize_callback'  => 'interico_sanitize_input',
					'capability'		 => 'edit_theme_options',
					'type'				 => 'theme_mod',
					'transport'          => 'refresh',
				)
			);
			$wp_customize->add_control( 'tc_footer_cta_link',
				array(
					'section' 			 => 'tc_interico_footer_cta_section',
					'label'   			 => esc_html__( 'Footer CTA Link Destination', 'interico' ),
					'type'    			 => 'text',
					'settings'			 => 'tc_footer_cta_link',
					'priority'			 => 15,
				)
			);

			$wp_customize->add_setting( 'tc_footer_cta_text_color_static',
				array(
				    'default'     		=> '#555555',
			        'transport'			=> 'refresh',
			        'type'				=> 'theme_mod',
			        'capability'		=> 'edit_theme_options',
				    'sanitize_callback' => 'sanitize_hex_color',
				)
			);
			$wp_customize->add_control( new WP_Customize_Color_Control( 
				$wp_customize, 'tc_footer_cta_text_color_static', 
					array(
						'label'       	=> esc_html__( 'CTA Text Color', 'interico' ),
						'section'     	=> 'tc_interico_footer_cta_section',
						'settings'    	=> 'tc_footer_cta_text_color_static',
						'priority'    	=> 20,
					)
				)
			);

			$wp_customize->add_setting( 'tc_footer_cta_text_color',
				array(
				    'default'     		=> '#ffffff',
			        'transport'			=> 'refresh',
			        'type'				=> 'theme_mod',
			        'capability'		=> 'edit_theme_options',
				    'sanitize_callback' => 'sanitize_hex_color',
				)
			);
			$wp_customize->add_control( new WP_Customize_Color_Control( 
				$wp_customize, 'tc_footer_cta_text_color', 
					array(
						'label'       	=> esc_html__( 'CTA Text Hover Color', 'interico' ),
						'section'     	=> 'tc_interico_footer_cta_section',
						'settings'    	=> 'tc_footer_cta_text_color',
						'priority'    	=> 25,
					)
				)
			);

			$wp_customize->add_setting( 'tc_footer_cta_bg_static',
				array(
				    'default'     		=> '#f9f9f9',
			        'transport'			=> 'refresh',
			        'type'				=> 'theme_mod',
			        'capability'		=> 'edit_theme_options',
				    'sanitize_callback' => 'sanitize_hex_color',
				)
			);
			$wp_customize->add_control( new WP_Customize_Color_Control( 
				$wp_customize, 'tc_footer_cta_bg_static', 
					array(
						'label'       	=> esc_html__( 'CTA Background Color', 'interico' ),
						'section'     	=> 'tc_interico_footer_cta_section',
						'settings'    	=> 'tc_footer_cta_bg_static',
						'priority'    	=> 30,
					)
				)
			);

			$wp_customize->add_setting( 'tc_footer_cta_bg',
				array(
				    'default'     		=> '#7d6741',
			        'transport'			=> 'refresh',
			        'type'				=> 'theme_mod',
			        'capability'		=> 'edit_theme_options',
				    'sanitize_callback' => 'sanitize_hex_color',
				)
			);
			$wp_customize->add_control( new WP_Customize_Color_Control( 
				$wp_customize, 'tc_footer_cta_bg', 
					array(
						'label'       	=> esc_html__( 'CTA Background Hover Color', 'interico' ),
						'section'     	=> 'tc_interico_footer_cta_section',
						'settings'    	=> 'tc_footer_cta_bg',
						'priority'    	=> 40,
					)
				)
			);

		/*-----------------------------------------------------------*
		 * 9. Footer
		 *-----------------------------------------------------------*/

		$wp_customize->add_section( 'tc_interico_footer_section',
			array(
				'title'       			=> esc_html__( 'Footer', 'interico' ),
				'description' 			=> esc_html__( 'Customize footer. Select the width of each column. 25% = 3/12, 33% = 4/12, 50% = 6/12. Total column width must not exceed 12 or 100%.', 'interico' ),
				'priority'    			=> 10,
				'panel'       			=> 'tc_interico_options',
			)
		);

			$wp_customize->add_setting( 'tc_footer_col_width_1', 
				array( 
					'default' 			=> 3,
					'transport'			=> 'refresh',
					'type'				=> 'theme_mod',
					'capability'		=> 'edit_theme_options',
					'sanitize_callback' => 'interico_sanitize_select',
				)
			);
			$wp_customize->add_control( 'tc_footer_col_width_1', 
				array(
					'type'        		=> 'select',
					'priority'    		=> 10,
					'label'       		=> esc_html__( '#1 Footer Column Width', 'interico' ),
					'description' 		=> esc_html__( 'Select the width of the column.', 'interico' ),
					'section'     		=> 'tc_interico_footer_section',
					'settings'    		=> 'tc_footer_col_width_1',
					'choices'  			=> array(
						'1'  			=> esc_html__( '8% (1/16)', 'interico' ),
						'2'  			=> esc_html__( '16% (2/16)', 'interico' ),
						'3' 			=> esc_html__( '25% (3/12)', 'interico' ),
						'4' 			=> esc_html__( '33% (4/12)', 'interico' ),
						'5' 			=> esc_html__( '42% (5/12)', 'interico' ),
						'6' 			=> esc_html__( '50% (6/12)', 'interico' ),
						'7' 			=> esc_html__( '58% (7/12)', 'interico' ),
						'8' 			=> esc_html__( '66% (8/12)', 'interico' ),
						'9' 			=> esc_html__( '75% (9/12)', 'interico' ),
						'10' 			=> esc_html__( '83% (10/12)', 'interico' ),
						'11' 			=> esc_html__( '92% (11/12)', 'interico' ),
						'12' 			=> esc_html__( '100% (12/12)', 'interico' ),
						'0'  			=> esc_html__( 'Disabled', 'interico' ),
					),
				)
			);

			$wp_customize->add_setting( 'tc_footer_col_1_mobile', 
				array( 
					'default' 			=> 'show',
					'type'				=> 'theme_mod',
					'capability'		=> 'edit_theme_options',
					'sanitize_callback' => 'interico_sanitize_select',
				)
			);
			$wp_customize->add_control( 'tc_footer_col_1_mobile', 
				array(
					'type'        		=> 'select',
					'priority'    		=> 10,
					'label'       		=> esc_html__( '#1 Footer Column Mobile Visibility', 'interico' ),
					'description' 		=> esc_html__( 'Select the width of the column.', 'interico' ),
					'section'     		=> 'tc_interico_footer_section',
					'settings'    		=> 'tc_footer_col_1_mobile',
					'choices'  			=> array(
						'show'			=> esc_html__( 'Show on  Mobile', 'interico' ),
						'hide'			=> esc_html__( 'Hide on Mobile', 'interico' ),
					),
				)
			);

			$wp_customize->add_setting( 'tc_footer_col_width_2', 
				array( 
					'default' 			=> 3,
					'transport'			=> 'refresh',
					'type'				=> 'theme_mod',
					'capability'		=> 'edit_theme_options',
					'sanitize_callback' => 'interico_sanitize_select',
				)
			);
			$wp_customize->add_control( 'tc_footer_col_width_2', 
				array(
					'type'        		=> 'select',
					'priority'    		=> 10,
					'label'       		=> esc_html__( '#2 Footer Column Width', 'interico' ),
					'description' 		=> esc_html__( 'Select the width of the column.', 'interico' ),
					'section'     		=> 'tc_interico_footer_section',
					'settings'    		=> 'tc_footer_col_width_2',
					'choices'  			=> array(
						'1'  			=> esc_html__( '8% (1/16)', 'interico' ),
						'2'  			=> esc_html__( '16% (2/16)', 'interico' ),
						'3' 			=> esc_html__( '25% (3/12)', 'interico' ),
						'4' 			=> esc_html__( '33% (4/12)', 'interico' ),
						'5' 			=> esc_html__( '42% (5/12)', 'interico' ),
						'6' 			=> esc_html__( '50% (6/12)', 'interico' ),
						'7' 			=> esc_html__( '58% (7/12)', 'interico' ),
						'8' 			=> esc_html__( '66% (8/12)', 'interico' ),
						'9' 			=> esc_html__( '75% (9/12)', 'interico' ),
						'10' 			=> esc_html__( '83% (10/12)', 'interico' ),
						'11' 			=> esc_html__( '92% (11/12)', 'interico' ),
						'12' 			=> esc_html__( '100% (12/12)', 'interico' ),
						'0'  			=> esc_html__( 'Disabled', 'interico' ),
					),
				)
			);

			$wp_customize->add_setting( 'tc_footer_col_2_mobile', 
				array( 
					'default' 			=> 'show',
					'type'				=> 'theme_mod',
					'capability'		=> 'edit_theme_options',
					'sanitize_callback' => 'interico_sanitize_select',
				)
			);
			$wp_customize->add_control( 'tc_footer_col_2_mobile', 
				array(
					'type'        		=> 'select',
					'priority'    		=> 10,
					'label'       		=> esc_html__( '#2 Footer Column Mobile Visibility', 'interico' ),
					'description' 		=> esc_html__( 'Select the width of the column.', 'interico' ),
					'section'     		=> 'tc_interico_footer_section',
					'settings'    		=> 'tc_footer_col_2_mobile',
					'choices'  			=> array(
						'show'			=> esc_html__( 'Show on  Mobile', 'interico' ),
						'hide'			=> esc_html__( 'Hide on Mobile', 'interico' ),
					),
				)
			);

			$wp_customize->add_setting( 'tc_footer_col_width_3', 
				array( 
					'default' 			=> 3,
					'transport'			=> 'refresh',
					'type'				=> 'theme_mod',
					'capability'		=> 'edit_theme_options',
					'sanitize_callback' => 'interico_sanitize_select',
				)
			);
			$wp_customize->add_control( 'tc_footer_col_width_3', 
				array(
					'type'        		=> 'select',
					'priority'    		=> 10,
					'label'       		=> esc_html__( '#3 Footer Column Width', 'interico' ),
					'description' 		=> esc_html__( 'Select the width of the column.', 'interico' ),
					'section'     		=> 'tc_interico_footer_section',
					'settings'    		=> 'tc_footer_col_width_3',
					'choices'  			=> array(
						'1'  			=> esc_html__( '8% (1/16)', 'interico' ),
						'2'  			=> esc_html__( '16% (2/16)', 'interico' ),
						'3' 			=> esc_html__( '25% (3/12)', 'interico' ),
						'4' 			=> esc_html__( '33% (4/12)', 'interico' ),
						'5' 			=> esc_html__( '42% (5/12)', 'interico' ),
						'6' 			=> esc_html__( '50% (6/12)', 'interico' ),
						'7' 			=> esc_html__( '58% (7/12)', 'interico' ),
						'8' 			=> esc_html__( '66% (8/12)', 'interico' ),
						'9' 			=> esc_html__( '75% (9/12)', 'interico' ),
						'10' 			=> esc_html__( '83% (10/12)', 'interico' ),
						'11' 			=> esc_html__( '92% (11/12)', 'interico' ),
						'12' 			=> esc_html__( '100% (12/12)', 'interico' ),
						'0'  			=> esc_html__( 'Disabled', 'interico' ),
					),
				)
			);

			$wp_customize->add_setting( 'tc_footer_col_3_mobile', 
				array( 
					'default' 			=> 'show',
					'type'				=> 'theme_mod',
					'capability'		=> 'edit_theme_options',
					'sanitize_callback' => 'interico_sanitize_select',
				)
			);
			$wp_customize->add_control( 'tc_footer_col_3_mobile', 
				array(
					'type'        		=> 'select',
					'priority'    		=> 10,
					'label'       		=> esc_html__( '#3 Footer Column Mobile Visibility', 'interico' ),
					'description' 		=> esc_html__( 'Select the width of the column.', 'interico' ),
					'section'     		=> 'tc_interico_footer_section',
					'settings'    		=> 'tc_footer_col_3_mobile',
					'choices'  			=> array(
						'show'			=> esc_html__( 'Show on  Mobile', 'interico' ),
						'hide'			=> esc_html__( 'Hide on Mobile', 'interico' ),
					),
				)
			);

			$wp_customize->add_setting( 'tc_footer_col_width_4', 
				array( 
					'default' 			=> 3,
					'transport'			=> 'refresh',
					'type'				=> 'theme_mod',
					'capability'		=> 'edit_theme_options',
					'sanitize_callback' => 'interico_sanitize_select',
				)
			);
			$wp_customize->add_control( 'tc_footer_col_width_4', 
				array(
					'type'        		=> 'select',
					'priority'    		=> 10,
					'label'       		=> esc_html__( '#4 Footer Column Width', 'interico' ),
					'description' 		=> esc_html__( 'Select the width of the column.', 'interico' ),
					'section'     		=> 'tc_interico_footer_section',
					'settings'    		=> 'tc_footer_col_width_4',
					'choices'  			=> array(
						'1'  			=> esc_html__( '8% (1/16)', 'interico' ),
						'2'  			=> esc_html__( '16% (2/16)', 'interico' ),
						'3' 			=> esc_html__( '25% (3/12)', 'interico' ),
						'4' 			=> esc_html__( '33% (4/12)', 'interico' ),
						'5' 			=> esc_html__( '42% (5/12)', 'interico' ),
						'6' 			=> esc_html__( '50% (6/12)', 'interico' ),
						'7' 			=> esc_html__( '58% (7/12)', 'interico' ),
						'8' 			=> esc_html__( '66% (8/12)', 'interico' ),
						'9' 			=> esc_html__( '75% (9/12)', 'interico' ),
						'10' 			=> esc_html__( '83% (10/12)', 'interico' ),
						'11' 			=> esc_html__( '92% (11/12)', 'interico' ),
						'12' 			=> esc_html__( '100% (12/12)', 'interico' ),
						'0'  			=> esc_html__( 'Disabled', 'interico' ),
					),
				)
			);

			$wp_customize->add_setting( 'tc_footer_col_4_mobile', 
				array( 
					'default' 			=> 'show',
					'type'				=> 'theme_mod',
					'capability'		=> 'edit_theme_options',
					'sanitize_callback' => 'interico_sanitize_select',
				)
			);
			$wp_customize->add_control( 'tc_footer_col_4_mobile', 
				array(
					'type'        		=> 'select',
					'priority'    		=> 10,
					'label'       		=> esc_html__( '#4 Footer Column Mobile Visibility', 'interico' ),
					'description' 		=> esc_html__( 'Select the width of the column.', 'interico' ),
					'section'     		=> 'tc_interico_footer_section',
					'settings'    		=> 'tc_footer_col_4_mobile',
					'choices'  			=> array(
						'show'			=> esc_html__( 'Show on  Mobile', 'interico' ),
						'hide'			=> esc_html__( 'Hide on Mobile', 'interico' ),
					),
				)
			);

			$wp_customize->add_setting( 'tc_footer_color_scheme',
				array(
		        	'default'  			=> 'dark',
		        	'transport'			=> 'refresh',
		        	'type'				=> 'theme_mod',
		        	'capability'		=> 'edit_theme_options',
		        	'sanitize_callback' => 'interico_sanitize_select',
		    	)
			);
			$wp_customize->add_control( 'tc_footer_color_scheme', 
				array(
					'label'				=> esc_html__( 'Dark or Light Footer Color Scheme', 'interico' ),
					'section'			=> 'tc_interico_footer_section',
					'settings'			=> 'tc_footer_color_scheme',
					'type'				=> 'select',
					'choices'			=> array(
						'light'	=> esc_html__( 'Light', 'interico' ),
						'dark'	=> esc_html__( 'Dark', 'interico' ),
					),
					'priority'			=> 15,
				)
			);

			$wp_customize->add_setting( 'tc_footer_title_color',
				array(
				    'default'     		=> '#888888',
			        'transport'			=> 'refresh',
			        'type'				=> 'theme_mod',
			        'capability'		=> 'edit_theme_options',
				    'sanitize_callback' => 'sanitize_hex_color',
				)
			);
			$wp_customize->add_control( new WP_Customize_Color_Control( 
				$wp_customize, 'tc_footer_title_color', 
					array(
						'label'       	=> esc_html__( 'Footer Widget Title Color', 'interico' ),
						'section'     	=> 'tc_interico_footer_section',
						'settings'    	=> 'tc_footer_title_color',
						'priority'    	=> 15,
					)
				)
			);

			$wp_customize->add_setting( 'tc_footer_text_color',
				array(
				    'default'     		=> '#888888',
			        'transport'			=> 'refresh',
			        'type'				=> 'theme_mod',
			        'capability'		=> 'edit_theme_options',
				    'sanitize_callback' => 'sanitize_hex_color',
				)
			);
			$wp_customize->add_control( new WP_Customize_Color_Control( 
				$wp_customize, 'tc_footer_text_color', 
					array(
						'label'       	=> esc_html__( 'Footer Text Color', 'interico' ),
						'section'     	=> 'tc_interico_footer_section',
						'settings'    	=> 'tc_footer_text_color',
						'priority'    	=> 20,
					)
				)
			);

			$wp_customize->add_setting( 'tc_footer_link_color',
				array(
				    'default'     		=> '#aaaaaa',
			        'transport'			=> 'refresh',
			        'type'				=> 'theme_mod',
			        'capability'		=> 'edit_theme_options',
				    'sanitize_callback' => 'sanitize_hex_color',
				)
			);
			$wp_customize->add_control( new WP_Customize_Color_Control( 
				$wp_customize, 'tc_footer_link_color', 
					array(
						'label'       	=> esc_html__( 'Footer Link Color', 'interico' ),
						'section'     	=> 'tc_interico_footer_section',
						'settings'    	=> 'tc_footer_link_color',
						'priority'    	=> 20,
					)
				)
			);

			$wp_customize->add_setting( 'tc_footer_text_hover_color',
				array(
			        'transport'			=> 'refresh',
			        'type'				=> 'theme_mod',
			        'capability'		=> 'edit_theme_options',
				    'sanitize_callback' => 'sanitize_hex_color',
				)
			);
			$wp_customize->add_control( new WP_Customize_Color_Control( 
				$wp_customize, 'tc_footer_text_hover_color', 
					array(
						'label'       	=> esc_html__( 'Footer Text Link Hover Color', 'interico' ),
						'section'     	=> 'tc_interico_footer_section',
						'settings'    	=> 'tc_footer_text_hover_color',
						'priority'    	=> 25,
					)
				)
			);

			$wp_customize->add_setting( 'tc_footer_bg',
				array(
			        'transport'			=> 'refresh',
			        'type'				=> 'theme_mod',
			        'capability'		=> 'edit_theme_options',
				    'sanitize_callback' => 'sanitize_hex_color',
				)
			);
			$wp_customize->add_control( new WP_Customize_Color_Control( 
				$wp_customize, 'tc_footer_bg', 
					array(
						'label'       	=> esc_html__( 'Footer Background Color', 'interico' ),
						'section'     	=> 'tc_interico_footer_section',
						'settings'    	=> 'tc_footer_bg',
						'priority'    	=> 30,
					)
				)
			);

			$wp_customize->add_setting( 'tc_logo_footer_img' ,
				array( 
					'default' 			=> get_template_directory_uri() . '/img/logo-footer.png',
					'transport'			=> 'refresh',
					'type'				=> 'theme_mod',
					'capability'		=> 'edit_theme_options',
					'sanitize_callback' => 'esc_url_raw',
				)
			);
			$wp_customize->add_control( new WP_Customize_Image_Control( 
				$wp_customize, 'tc_logo_footer_img',
					array(
						'label' 	 	=> esc_html__( 'Footer Logo Image', 'interico' ),
						'description' 	=> esc_html__( 'Recommended: grayscale color scheme and 90 pixels height', 'interico' ),
						'section' 	 	=> 'tc_interico_footer_section',
						'settings' 	 	=> 'tc_logo_footer_img',
						'priority'   	=> 35,
					)
				)
			);

			$wp_customize->add_setting( 'tc_logo_footer_img_2x' ,
				array( 
					'default' 			=> get_template_directory_uri() . '/img/logo-footer2x.png',
					'transport'			=> 'refresh',
					'type'				=> 'theme_mod',
					'capability'		=> 'edit_theme_options',
					'sanitize_callback' => 'esc_url_raw',
				)
			);
			$wp_customize->add_control( new WP_Customize_Image_Control( 
				$wp_customize, 'tc_logo_footer_img_2x',
					array(
						'label' 	 	=> esc_html__( 'Footer Logo Image 2x', 'interico' ),
						'description' 	=> esc_html__( '2x Size of the original logo', 'interico' ),
						'section' 	 	=> 'tc_interico_footer_section',
						'settings' 	 	=> 'tc_logo_footer_img_2x',
						'priority'   	=> 40,
					)
				)
			);

			$wp_customize->add_setting(	'interico_footer_copyright_text',
				array(
					'default'            => esc_html__( '2018. All Rights Reserved', 'interico'),
					'sanitize_callback'  => 'interico_sanitize_text',
					'transport'          => 'refresh'
				)
			);
			$wp_customize->add_control(	'interico_footer_copyright_text',
				array(
					'section'  			=> 'tc_interico_footer_section',
					'label'    			=> esc_html__( 'Copyright Message', 'interico' ),
					'type'     			=> 'text',
					'priority' 			=> 45,
				)
			);

			$wp_customize->add_setting( 'tc_footer_hide', 
				array( 
					'default' 			=> 'show',
					'transport'			=> 'refresh',
					'type'				=> 'theme_mod',
					'capability'		=> 'edit_theme_options',
					'sanitize_callback' => 'interico_sanitize_select',
				)
			);
			$wp_customize->add_control( 'tc_footer_hide', 
				array(
					'type'        		=> 'select',
					'priority'    		=> 50,
					'label'       		=> esc_html__( 'Hide Footer', 'interico' ),
					'section'     		=> 'tc_interico_footer_section',
					'settings'    		=> 'tc_footer_hide',
					'choices'  			=> array(
						'hide'  		=> esc_html__( 'Hide', 'interico' ),
						'show'  		=> esc_html__( 'Show', 'interico' ),
					),
				)
			);

			$wp_customize->add_setting( 'tc_footer_bot_hide', 
				array( 
					'default' 			=> 'show',
					'transport'			=> 'refresh',
					'type'				=> 'theme_mod',
					'capability'		=> 'edit_theme_options',
					'sanitize_callback' => 'interico_sanitize_select',
				)
			);
			$wp_customize->add_control( 'tc_footer_bot_hide', 
				array(
					'type'        		=> 'select',
					'priority'    		=> 50,
					'label'       		=> esc_html__( 'Hide Copyright Bot Footer', 'interico' ),
					'section'     		=> 'tc_interico_footer_section',
					'settings'    		=> 'tc_footer_bot_hide',
					'choices'  			=> array(
						'hide'  		=> esc_html__( 'Hide', 'interico' ),
						'show'  		=> esc_html__( 'Show', 'interico' ),
					),
				)
			);

			$wp_customize->add_setting( 'tc_footer_bot_bg',
				array(
				    'default'     		=> '#111111',
			        'transport'			=> 'refresh',
			        'type'				=> 'theme_mod',
			        'capability'		=> 'edit_theme_options',
				    'sanitize_callback' => 'sanitize_hex_color',
				)
			);
			$wp_customize->add_control( new WP_Customize_Color_Control( 
				$wp_customize, 'tc_footer_bot_bg', 
					array(
						'label'       	=> esc_html__( 'Footer Bot Background Color', 'interico' ),
						'section'     	=> 'tc_interico_footer_section',
						'settings'    	=> 'tc_footer_bot_bg',
						'priority'    	=> 55,
					)
				)
			);

			$wp_customize->add_setting( 'tc_footer_bot_text',
				array(
				    'default'     		=> '#666666',
			        'transport'			=> 'refresh',
			        'type'				=> 'theme_mod',
			        'capability'		=> 'edit_theme_options',
				    'sanitize_callback' => 'sanitize_hex_color',
				)
			);
			$wp_customize->add_control( new WP_Customize_Color_Control( 
				$wp_customize, 'tc_footer_bot_text', 
					array(
						'label'       	=> esc_html__( 'Footer Bot Text Color', 'interico' ),
						'section'     	=> 'tc_interico_footer_section',
						'settings'    	=> 'tc_footer_bot_text',
						'priority'    	=> 60,
					)
				)
			);

		/*-----------------------------------------------------------*
		 * 10. Shop
		 *-----------------------------------------------------------*/

		// Only display the Shop section if WooCommerce is active
		if ( class_exists( 'WooCommerce' ) ) {

			$wp_customize->add_section( 'tc_interico_shop_section',
				array(
					'title'       			=> esc_html__( 'Shop', 'interico' ),
					'description' 			=> esc_html__( 'Settings for the shop pages', 'interico' ),
					'priority'    			=> 10,
					'panel'       			=> 'tc_interico_options',
				)
			);

				$wp_customize->add_setting( 'tc_shop_items_per_page', 
					array(
						'default'			=> 5,
						'transport'			=> 'refresh',
						'type'				=> 'theme_mod',
						'capability'		=> 'edit_theme_options',
						'sanitize_callback' => 'interico_sanitize_text',
					)
				);
				$wp_customize->add_control( 'tc_shop_items_per_page', 
					array(
					    'label' 			=> esc_html__( 'Shop items per page', 'interico'),
					    'description' 		=> esc_html__( 'Set the number of items to show per page.', 'interico' ),
				    	'type'		        => 'number',
					    'section' 			=> 'tc_interico_shop_section',
					    'settings' 			=> 'tc_shop_items_per_page',
					    'priority' 			=> 15,
					    'input_attrs' 		=> array(
							'min' 		=> 0,
							'max'  		=> 100,
							'step' 		=> 1,
						),
					)
				);

				$wp_customize->add_setting( 'tc_shop_products_columns', 
					array( 
						'default' 			=> 4,
						'transport'			=> 'refresh',
						'type'				=> 'theme_mod',
						'capability'		=> 'edit_theme_options',
						'sanitize_callback' => 'interico_sanitize_select',
					)
				);
				$wp_customize->add_control( 'tc_shop_products_columns', 
					array(
						'type'        		=> 'select',
						'priority'    		=> 10,
						'label'       		=> esc_html__( 'Number of shop columns', 'interico' ),
						'description' 		=> esc_html__( 'Set the number of columns for the shop page.', 'interico' ),
						'section'     		=> 'tc_interico_shop_section',
						'settings'    		=> 'tc_shop_products_columns',
						'choices' 			=> array(
							'2' 			=> 2,
							'3'  			=> 3,
							'4' 			=> 4,
							'5' 			=> 5,
							'6' 			=> 6,
						),
					)
				);

				$wp_customize->add_setting( 'tc_shop_add_to_cart', 
					array(
						'default' 			=> esc_html__( 'Add to Cart', 'interico' ),
						'transport'			=> 'refresh',
						'type'				=> 'theme_mod',
						'capability'		=> 'edit_theme_options',
						'sanitize_callback' => 'interico_sanitize_input',
					)
				);
				$wp_customize->add_control( 'tc_shop_add_to_cart', 
					array(
						'label' 			=> esc_html__( 'Add to Cart button text', 'interico' ),
						'section' 			=> 'tc_interico_shop_section',
						'settings' 			=> 'tc_shop_add_to_cart',
						'priority' 			=> 5,
					)
				);

		}



		/*-----------------------------------------------------------*
		 * 11. Settings
		 *-----------------------------------------------------------*/

		$wp_customize->add_section( 'tc_interico_settings_section',
			array(
				'title'       			=> esc_html__( 'Settings', 'interico' ),
				'description' 			=> esc_html__( 'Change parent page slugs.', 'interico' ),
				'priority'    			=> 10,
				'panel'       			=> 'tc_interico_options',
			)
		);

			$wp_customize->add_setting(	'tc_read_more_string_blog',
				array(
					'default'            => esc_html__( 'Read More', 'interico' ),
					'sanitize_callback'  => 'interico_sanitize_input',
					'transport'          => 'refresh'
				)
			);
			$wp_customize->add_control(	'tc_read_more_string_blog',
				array(
					'section'  			=> 'tc_interico_settings_section',
					'label'    			=> esc_html__( 'Read More text for Blog items', 'interico' ),
					'type'     			=> 'text',
					'priority' 			=> 5,
				)
			);

			$wp_customize->add_setting(	'tc_read_more_string_service',
				array(
					'default'            => esc_html__( 'Read More', 'interico' ),
					'sanitize_callback'  => 'interico_sanitize_input',
					'transport'          => 'refresh'
				)
			);
			$wp_customize->add_control(	'tc_read_more_string_service',
				array(
					'section'  			=> 'tc_interico_settings_section',
					'label'    			=> esc_html__( 'Read More text for Service items', 'interico' ),
					'description' 		=> esc_html__( 'Widget: Image Box', 'interico' ),
					'type'     			=> 'text',
					'priority' 			=> 5,
				)
			);

			$wp_customize->add_setting( 'tc_projects_slug', 
				array(
					'default' 			=> 'projects',
					'transport'			=> 'refresh',
					'type'				=> 'theme_mod',
					'capability'		=> 'edit_theme_options',
					'sanitize_callback' => 'interico_sanitize_projects_slug',
				)
			);
			$wp_customize->add_control( 'tc_projects_slug', 
				array(
					'label' 			=> esc_html__( 'Projects Slug', 'interico' ),
					'description'		=> esc_html__( 'Update permalinks after this change: Settings -> Permalinks -> Save Changes', 'interico' ),
					'section' 			=> 'tc_interico_settings_section',
					'settings' 			=> 'tc_projects_slug',
					'priority' 			=> 5,
				)
			);

			$wp_customize->add_setting( 'tc_gallery_filter_button_text', 
				array(
					'default' 			=> 'All Projects',
					'transport'			=> 'refresh',
					'type'				=> 'theme_mod',
					'capability'		=> 'edit_theme_options',
					'sanitize_callback' => 'interico_sanitize_input',
				)
			);
			$wp_customize->add_control( 'tc_gallery_filter_button_text', 
				array(
					'label' 			=> esc_html__( 'Gallery All Projects filter button text', 'interico' ),
					'description'		=> esc_html__( 'Set text for the All Projects filter', 'interico' ),
					'section' 			=> 'tc_interico_settings_section',
					'settings' 			=> 'tc_gallery_filter_button_text',
					'priority' 			=> 5,
				)
			);

			$wp_customize->add_setting( 'tc_gallery_page_link', 
				array(
					'default' 			=> '#',
					'transport'			=> 'refresh',
					'type'				=> 'theme_mod',
					'capability'		=> 'edit_theme_options',
					'sanitize_callback' => 'interico_sanitize_input',
				)
			);
			$wp_customize->add_control( 'tc_gallery_page_link', 
				array(
					'label' 			=> esc_html__( 'Gallery Link for Project Items', 'interico' ),
					'description'		=> esc_html__( 'Set link for the Icon in a single project page', 'interico' ),
					'section' 			=> 'tc_interico_settings_section',
					'settings' 			=> 'tc_gallery_page_link',
					'priority' 			=> 5,
				)
			);

			$wp_customize->add_setting( 'tc_projects_nav', 
				array( 
					'default' 			=> 'show',
					'transport'			=> 'refresh',
					'type'				=> 'theme_mod',
					'capability'		=> 'edit_theme_options',
					'sanitize_callback' => 'interico_sanitize_select',
				)
			);
			$wp_customize->add_control( 'tc_projects_nav', 
				array(
					'type'        		=> 'select',
					'priority'    		=> 50,
					'label'       		=> esc_html__( 'Next/Prev Projects Navigation', 'interico' ),
					'section'     		=> 'tc_interico_settings_section',
					'settings'    		=> 'tc_projects_nav',
					'choices'  			=> array(
						'hide'  		=> esc_html__( 'Hide', 'interico' ),
						'show'  		=> esc_html__( 'Show', 'interico' ),
					),
				)
			);

			$wp_customize->add_setting( 'tc_posts_nav', 
				array( 
					'default' 			=> 'show',
					'transport'			=> 'refresh',
					'type'				=> 'theme_mod',
					'capability'		=> 'edit_theme_options',
					'sanitize_callback' => 'interico_sanitize_select',
				)
			);
			$wp_customize->add_control( 'tc_posts_nav', 
				array(
					'type'        		=> 'select',
					'priority'    		=> 50,
					'label'       		=> esc_html__( 'Next/Prev Posts Navigation', 'interico' ),
					'section'     		=> 'tc_interico_settings_section',
					'settings'    		=> 'tc_posts_nav',
					'choices'  			=> array(
						'hide'  		=> esc_html__( 'Hide', 'interico' ),
						'show'  		=> esc_html__( 'Show', 'interico' ),
					),
				)
			);			
			
			$wp_customize->get_setting( 'blogname' )->transport = 'postMessage';
			$wp_customize->get_setting( 'blogdescription' )->transport = 'postMessage';

	}


	public function interico_customizer_live_preview() {
		wp_enqueue_script(
			'interico-theme-customizer',
			get_template_directory_uri() . '/inc/js/theme-customizer.js',
			array( 'jquery', 'customize-preview' ),
			'',
			true
		);
	} // end interico_customizer_live_preview

	/**
	 * Deletes the cached style CSS that's output into the header.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return void
	 */
	public function interico_cache_delete() {
		wp_cache_delete( get_stylesheet() . '_custom_colors' );
	}

	/**
	 * Returns the instance.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return object
	 */
	public static function get_instance() {
		if ( ! self::$instance )
			self::$instance = new self;
		return self::$instance;
	}
}

function interico_adjust_brightness($hex, $steps) {
    // Negative = darker, positive = lighter
    $steps = max(-255, min(255, $steps));

    // Normalize into a six character long hex string
    $hex = str_replace('#', '', $hex);
    if (strlen($hex) == 3) {
        $hex = str_repeat(substr($hex,0,1), 2).str_repeat(substr($hex,1,1), 2).str_repeat(substr($hex,2,1), 2);
    }

    // Split into three parts: R, G and B
    $color_parts = str_split($hex, 2);
    $return = '#';

    foreach ($color_parts as $color) {
        $color   = hexdec($color); // Convert to decimal
        $color   = max(0,min(255,$color + $steps)); // Adjust color
        $return .= str_pad(dechex($color), 2, '0', STR_PAD_LEFT); // Make two char hex code
    }

    return $return;
}

/**
 * Sanitizes the incoming input and returns it prior to serialization.
 *
 * @param      string    $input    The string to sanitize
 * @return     string              The sanitized string
 * @package    interico
 * @since      0.5.0
 * @version    1.0.2
 */
function interico_sanitize_input( $input ) {
	return strip_tags( stripslashes( $input ) );
} // end interico_sanitize_input

/**
 * Sanitize select callback function.
 */
if ( ! function_exists( 'interico_sanitize_select' ) ) {
	function interico_sanitize_select( $input, $setting ) {

		// Ensure input is a slug.
		$input = sanitize_key( $input );

		// Get list of choices from the control associated with the setting.
		$choices = $setting->manager->get_control( $setting->id )->choices;

		// If the input is a valid key, return it; otherwise, return the default.
		return ( array_key_exists( $input, $choices ) ? $input : $setting->default );
	}
}

/**
 * Sanitize text callback function
 */
if( ! function_exists( 'interico_sanitize_text' ) ) {
	function interico_sanitize_text( $input ) {
	    return force_balance_tags( wp_kses_post( $input ) );
	}
}

/**
 * Sanitize textarea callback function
 */
if( ! function_exists( 'interico_sanitize_textarea' ) ) {
	function interico_sanitize_textarea( $input ) {
	    return esc_textarea( $input );
	}
}

/**
 * Sanitize slug for Custom Post Type: Portfolio 
 */
if( ! function_exists( 'interico_sanitize_projects_slug' ) ) {
	function interico_sanitize_projects_slug( $slug ) {
		$slug = trim( $slug );
		return sanitize_title( $slug, 'projects' );
	}
}

/**
 * Sanitize slug for Custom Post Type: Services 
 */
if( ! function_exists( 'interico_sanitize_services_slug' ) ) {
	function interico_sanitize_services_slug( $slug ) {
		$slug = trim( $slug );
		return sanitize_title( $slug, 'services' );
	}
}


interico_Customizer::get_instance();
