<?php

// Prevent direct file access
if ( ! defined ( 'ABSPATH' ) ) {
	exit;
}

class Interico_Blog_Posts extends WP_Widget {
	
	/*--------------------------------------------------*/
	/* Constructor
	/* Specifies the name and description
	/*--------------------------------------------------*/

	function __construct() {
		parent::__construct(
			false,
			esc_html__( 'Interico: Blog Posts', 'interico' ), // Name
			array(
				'description' => __( 'Display Blog Posts', 'interico') // Description
			)
		);
	}

	/*--------------------------------------------------*
	 * Widget form in the Back End
	 * @see WP_Widget::form()
	 /*--------------------------------------------------*/

	function form( $instance ) {
		$title   		 	   = empty( $instance['title'] ) ? '' : $instance['title'];
		$page_id 		  	   = empty( $instance['page_id'] ) ? 0 : (int) $instance['page_id'];
		$blog_button_text      = empty( $instance['blog_button_text'] ) ? '' : $instance['blog_button_text'];
		$blog_read_more_string = empty( $instance['blog_read_more_string'] ) ? '' : $instance['blog_read_more_string'];
		$categories   		   = empty( $instance['categories'] ) ? '' : $instance['categories'];
		$blog_heading_style    = empty( $instance['blog_heading_style'] ) ? '' : $instance['blog_heading_style'];
		$blog_post_style   	   = empty( $instance['blog_post_style'] ) ? '' : $instance['blog_post_style'];

		?>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Set Title:', 'interico'  ); ?></label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'blog_button_text' ) ); ?>"><?php esc_html_e( 'All Articles link Text', 'interico'  ); ?></label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'blog_button_text' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'blog_button_text' ) ); ?>" type="text" value="<?php echo esc_attr( $blog_button_text ); ?>" />
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'page_id' ) ); ?>"><?php esc_html_e( 'All Articles link:', 'interico' ); ?></label><br>
			<?php
				wp_dropdown_pages(
					array(
						'selected' => $page_id,
						'id'       => $this->get_field_id( 'page_id' ),
						'name'     => $this->get_field_name( 'page_id' ),
					)
				);
			?>
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'blog_read_more_string' ) ); ?>"><?php esc_html_e( 'Read More string for Blog Items', 'interico'  ); ?></label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'blog_read_more_string' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'blog_read_more_string' ) ); ?>" type="text" value="<?php echo esc_attr( $blog_read_more_string ); ?>" />
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'categories' ) ); ?>"><?php esc_html_e( 'Filter by Category', 'interico'  ); ?>:</label> 
			<?php
				wp_dropdown_categories( array(
					'orderby' => 'name',
					'name' => $this->get_field_name( 'categories' ),
					'selected' => $categories,
					'hierarchical' => true,
					'show_option_all' => esc_html__( 'All categories', 'interico'  ),
				) );
			?>
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'blog_heading_style' ) ); ?>"><?php esc_html_e( 'Heading & Link Style', 'interico' ); ?></label> <br>
			<select id="<?php echo esc_attr( $this->get_field_id( 'blog_heading_style' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'blog_heading_style' ) ); ?>">
				<option value="light" <?php selected( $blog_heading_style, 'light' ); ?>><?php esc_html_e( 'Style 1: Light', 'interico' ); ?></option>
				<option value="dark" <?php selected( $blog_heading_style, 'dark' ); ?>><?php esc_html_e( 'Style 2: Dark', 'interico' ); ?></option>
			</select>
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'blog_post_style' ) ); ?>"><?php esc_html_e( 'Blog Post Box Style', 'interico' ); ?></label> <br>
			<select id="<?php echo esc_attr( $this->get_field_id( 'blog_post_style' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'blog_post_style' ) ); ?>">
				<option value="light" <?php selected( $blog_post_style, 'light' ); ?>><?php esc_html_e( 'Style 1: Light', 'interico' ); ?></option>
				<option value="dark" <?php selected( $blog_post_style, 'dark' ); ?>><?php esc_html_e( 'Style 2: Dark', 'interico' ); ?></option>
			</select>
		</p>


		<?php
	}

	/*--------------------------------------------------*
	 * Sanitize widget data.
	 * @see WP_Widget::update()
	 /*--------------------------------------------------*/

	function update( $new_instance, $old_instance ) {
		$instance = array();
		$instance['title']   		  	   = wp_kses_post( $new_instance['title'] );
		$instance['page_id']		 	   = absint( $new_instance['page_id'] );
		$instance['blog_button_text'] 	   = wp_kses_post( $new_instance['blog_button_text'] );
		$instance['blog_read_more_string'] = wp_kses_post( $new_instance['blog_read_more_string'] );
		$instance['categories'] 		   = sanitize_key( $new_instance['categories'] );
		$instance['blog_heading_style']    = wp_kses_post( $new_instance['blog_heading_style'] );
		$instance['blog_post_style'] 	   = wp_kses_post( $new_instance['blog_post_style'] );

		return $instance;
	}

	/*--------------------------------------------------*
	 * Front-end display of widget.
	 * @see WP_Widget::widget()
	 /*--------------------------------------------------*/
	 
	function widget( $args, $instance ) {

		echo $args['before_widget'];

		$title = apply_filters( 'widget_title', $instance['title'] );

		// Set blog item link text
		if ( isset( $instance['blog_read_more_string'] ) ) {
			$read_more_string = $instance['blog_read_more_string'];
		}
		// If custom value is empty, use default value
		if ( empty( $read_more_string ) ) {
			$read_more_string = get_theme_mod( 'tc_read_more_string_blog', 'Read More' );
		}

		// Set all articles link text
		if ( isset( $instance['blog_button_text'] ) && !empty( $instance['blog_button_text'] ) ) {
			$blog_button_text = $instance['blog_button_text'];
		} else {
			$blog_button_text = 'All Articles';
		}

		$page_id = $instance['page_id'];
		if ( $page_id ) :
			$page = (array) get_post( $page_id );
		endif;

		// Get permalink from page ID
		$page['url'] = get_permalink( $page_id );

		if ( isset( $instance['categories'] ) ) {
			$categories = $instance['categories'];
		} else {
			$categories = false;
		}

		// Set Blog heading style
		if ( isset( $instance['blog_heading_style'] ) ) {
			$blog_heading_style = $instance['blog_heading_style'];
		} else {
			$blog_heading_style = 'light';
		}

		// Set Blog post box style
		if ( isset( $instance['blog_post_style'] ) ) {
			$blog_post_style = $instance['blog_post_style'];
		} else {
			$blog_post_style = 'light';
		}


		$blog_posts_query = new WP_Query(
			array(
				'posts_per_page' 	  => 3,
				'post_type' 		  => 'post',
				'cat' 			 	  => $categories,
				'ignore_sticky_posts' => true
			)
		);
		
		?>
		<div class="container">
			<!-- Begin Latest News -->
			<div class="row">
				<div class="col-md-12 title-link-box clearfix <?php echo esc_attr( $blog_heading_style ); ?>">
					<h2 class="section-title"><?php echo esc_attr( $title ); ?></h2>
					<a class="btn-read-more" href="<?php echo esc_url( $page['url'] ); ?>"><?php printf( esc_html__( '%s', 'interico' ), $blog_button_text ); ?></a>
				</div>
			</div>
			<div class="divider-light"></div>


			<!-- Begin News carousel -->
			<div class="row">
				<div id="news">

					<?php
						
						if ( $blog_posts_query->have_posts() ) :
							while ( $blog_posts_query->have_posts() ) : $blog_posts_query->the_post();

							// Get post by its ID
							$blog_post_id = get_the_ID();
							$blog_post    = (array)get_post( $blog_post_id );

							// Prepare Featured Image srcset
							$blog_post_image_id     = get_post_thumbnail_id();
							$blog_post_image_data   = wp_get_attachment_image_src( $blog_post_image_id, 'interico-blog-s' );
							$sizes 					= array( 'interico-blog-l' );
							$blog_post['srcset']    = interico_img_sizes( $blog_post_image_id, $sizes );
							$blog_post['image_url'] = $blog_post_image_data[0];			
					?>

							<!-- Begin News item -->
							<div class="col-sm-4">
								<a href="<?php esc_url( the_permalink() ); ?>">
									<article class="blog-post-box <?php echo esc_attr( $blog_post_style); ?>">
										<?php if ( has_post_thumbnail() ) : ?>
											<div class="image-container">
												<img src="<?php echo esc_url( $blog_post['image_url'] ); ?>" srcset="<?php echo esc_html( $blog_post['srcset'] ); ?>" sizes="(min-width: 781px) 380px, calc(100vw - 30px)" alt="<?php echo esc_attr( $blog_post['post_title'] ); ?>">
											</div>
										<?php endif; ?>
										<p class="blog-date"><span><?php the_time( get_option( 'date_format' ) ); ?></span></p>
										<div class="content-box-info">
											<h3 class="box-heading"><?php echo esc_attr( $blog_post['post_title'] ); ?></h3>
											<p>
												<?php 
													// Control the length of the excerpt
													$maxLength = 140;

													// If excerpt is not filled, then let's create an excerpt from the post content
													if ( empty( $blog_post['post_excerpt']) ) {
														$excerpt = $blog_post['post_content'];
													} else {
														$excerpt = $blog_post['post_excerpt'];
													}

													if ( strlen( $excerpt ) > $maxLength ) {
													    $modTrimTo = strpos( $excerpt, ' ', $maxLength );
													    $trimmedExcerpt = substr( $excerpt, 0, $modTrimTo ) . '...';
													} else {
													    $trimmedExcerpt = $excerpt;
													}

													// Output trimmed excerpt
													echo esc_html( $trimmedExcerpt );
												?>
											</p>
											<?php if ( esc_attr( $read_more_string) ) : ?>
												<div class="btn-read-more"><?php printf( esc_html__( '%s', 'interico' ), $read_more_string ); ?></div>
											<?php endif; ?>								
										</div>
									</article>
								</a>
							</div> <!-- End News item -->

							<?php endwhile;
							wp_reset_postdata();
						endif; ?>


				</div> <!-- End News carousel -->
			</div> <!-- End row -->
		</div>

		<?php

		echo $args['after_widget'];
	}
}
add_action( 'widgets_init', create_function( '', 'register_widget( "Interico_Blog_Posts" );' ) );
