<?php

// Prevent direct file access
if ( ! defined ( 'ABSPATH' ) ) {
	exit;
}

class Interico_Testimonials extends WP_Widget {
	
	/*--------------------------------------------------*/
	/* Constructor
	/* Specifies the classname and description,
	/*--------------------------------------------------*/

	function __construct() {
		parent::__construct(
			false,
			esc_html__( 'Interico: Testimonials', 'interico' ), // Name
			array(
				'description' => esc_html__( 'Display Testimonials Slider', 'interico' ),
			)
		);
	}

	/*--------------------------------------------------*
	 * Sanitize widget data.
	 * @see WP_Widget::update()
	 /*--------------------------------------------------*/

	function update( $new_instance, $old_instance ) {
		$instance = array();
		$instance['title']  				  = wp_kses_post( $new_instance['title'] );
		$instance['page_id']				  = absint( $new_instance['page_id'] );
		$instance['testimonials_button_text'] = wp_kses_post( $new_instance['testimonials_button_text'] );
		$instance['testimonials_style']	      = wp_kses_post( $new_instance['testimonials_style'] );
		$instance['testimonial_layout']		  = wp_kses_post( $new_instance['testimonial_layout'] );
		$instance['testimonial_heading_style'] = wp_kses_post( $new_instance['testimonial_heading_style'] );

		return $instance;
	}

	/*--------------------------------------------------*
	 * Widget form in the Back End
	 * @see WP_Widget::form()
	 /*--------------------------------------------------*/

	function form( $instance ) {
		$title   				  = empty( $instance['title'] ) ? '' : $instance['title'];
		$page_id				  = empty( $instance['page_id'] ) ? 0 : (int) $instance['page_id'];
		$testimonials_button_text = empty( $instance['testimonials_button_text'] ) ? '' : $instance['testimonials_button_text'];
		$testimonials_style		  = empty( $instance['testimonials_style'] ) ? '' : $instance['testimonials_style'];
		$testimonial_layout	      = empty( $instance['testimonial_layout'] ) ? '' : $instance['testimonial_layout'];
		$testimonial_heading_style = empty( $instance['testimonial_heading_style'] ) ? '' : $instance['testimonial_heading_style'];


		?>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Set Title:', 'interico'  ); ?></label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'testimonials_button_text' ) ); ?>"><?php esc_html_e( 'Button Text:', 'interico' ); ?></label> <br />
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'testimonials_button_text' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'testimonials_button_text' ) ); ?>" type="text" value="<?php echo esc_attr( $testimonials_button_text ); ?>" />
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'page_id' ) ); ?>"><?php esc_html_e( 'Button link:', 'interico' ); ?></label><br>
			<?php
				wp_dropdown_pages(
					array(
						'selected' => $page_id,
						'id'       => $this->get_field_id( 'page_id' ),
						'name'     => $this->get_field_name( 'page_id' ),
					)
				);
			?>
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'testimonial_layout' ) ); ?>"><?php esc_html_e( 'Select Icon Box Layout:', 'interico' ); ?></label> <br>
			<select id="<?php echo esc_attr( $this->get_field_id( 'testimonial_layout' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'testimonial_layout' ) ); ?>">
				<option value="left" <?php selected( $testimonial_layout, 'left' ); ?>><?php esc_html_e( 'Profile Inside', 'interico' ); ?></option>
				<option value="bottom" <?php selected( $testimonial_layout, 'bottom' ); ?>><?php esc_html_e( 'Profile Bottom Center', 'interico' ); ?></option>
				<option value="bottom-overlapped" <?php selected( $testimonial_layout, 'bottom-overlapped' ); ?>><?php esc_html_e( 'Profile Bottom Center Overlapped', 'interico' ); ?></option>
				<option value="bottom-left" <?php selected( $testimonial_layout, 'bottom-left' ); ?>><?php esc_html_e( 'Profile Bottom Left', 'interico' ); ?></option>
			</select>
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'testimonials_style' ) ); ?>"><?php esc_html_e( 'Color Scheme', 'interico' ); ?>:</label> <br />
			<select id="<?php echo esc_attr( $this->get_field_id('testimonials_style') ); ?>" name="<?php echo  esc_attr( $this->get_field_name('testimonials_style') ); ?>" class="widefat" style="width:100%;">
			    <option value="light" <?php selected( $testimonials_style, 'light' ); ?>><?php esc_html_e( 'Style 1: Light boxes', 'interico' ); ?></option>
			    <option value="dark" <?php selected( $testimonials_style, 'dark' ); ?>><?php esc_html_e( 'Style 2: Dark boxes', 'interico' ); ?></option>
			</select>
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'testimonial_heading_style' ) ); ?>"><?php esc_html_e( 'Heading & Arrows Style', 'interico' ); ?>:</label> <br />
			<select id="<?php echo esc_attr( $this->get_field_id('testimonial_heading_style') ); ?>" name="<?php echo  esc_attr( $this->get_field_name('testimonial_heading_style') ); ?>" class="widefat" style="width:100%;">
			    <option value="dark" <?php selected( $testimonial_heading_style, 'dark' ); ?>><?php esc_html_e( 'Style 1: Dark', 'interico' ); ?></option>
			    <option value="light" <?php selected( $testimonial_heading_style, 'light' ); ?>><?php esc_html_e( 'Style 2: Light', 'interico' ); ?></option>
			</select>
		</p>

		<?php
	}

	/*--------------------------------------------------*
	 * Front-end display of widget.
	 * @see WP_Widget::widget()
	 /*--------------------------------------------------*/
	 
	function widget( $args, $instance ) {

		echo $args['before_widget'];

		$title = apply_filters( 'widget_title', $instance['title'] );

		$page_id = $instance['page_id'];
		if ( $page_id ) :
			$page = (array) get_post( $page_id );
		endif;

		if ( isset( $instance['testimonials_button_text'] ) ) {
			$view_all_string = $instance['testimonials_button_text'];
		} else {
			$view_all_string = 'All Testimonials';
		}

		// Set testimonial style
		if ( isset( $instance['testimonials_style'] ) ) {
			$testimonials_style = $instance['testimonials_style'];
		} else {
			$testimonials_style = 'light';
		}

		// Set testimonial heading style
		if ( isset( $instance['testimonial_heading_style'] ) ) {
			$testimonial_heading_style = $instance['testimonial_heading_style'];
		} else {
			$testimonial_heading_style = 'dark';
		}			

		// Set testimonial layout
		if ( isset( $instance['testimonial_layout'] ) ) {
			$testimonial_layout = $instance['testimonial_layout'];
		} else {
			$testimonial_layout = 'left';
		}

		// Get permalink from page ID
		$page['url'] = get_permalink( $page_id );		

		$testimonials_query = new WP_Query(
			array(
				'post_type' => 'testimonial',
				'posts_per_page' => 8
				)
			);
		?>

		<!-- Begin Testimonials -->
		<section id="testimonials" class="<?php echo esc_attr( $testimonial_heading_style ); ?>">
			<div class="container carousel-light">
				<div class="row">
					<div class="col-md-12">
						<h2 class="section-title"><?php echo esc_attr( $title ); ?></h2>
						<div class="divider-light"></div>
					</div>
				</div>
				<div class="row">

					<!-- Begin Testimonials carousel -->
					<div id="testimonial-carousel" class="carousel">

						<?php
							if ( $testimonials_query->have_posts() ) :
								while ( $testimonials_query->have_posts() ) : $testimonials_query->the_post();
								
								$testimonial_id = get_the_ID();
								$testimonial = (array)get_post( $testimonial_id );

								// Testimonial title
								if ( isset( $testimonial['post_title'] ) ) {
									$testimonial_title = $testimonial['post_title'];
								} else {
									$testimonial_title = false;
								}

								// Testimonial content
								if ( isset( $page['post_content'] ) ) {
									$testimonial_content = $testimonial['post_content'];
								} else {
									$testimonial_content = false;
								}

								// Prepare Featured Image srcset
								$testimonial_image_id         = get_post_thumbnail_id( $testimonial_id );
								$testimonial_image_data       = wp_get_attachment_image_src( $testimonial_image_id );
								$testimonial['image_url']     = $testimonial_image_data[0];

								if ( class_exists('acf') ) { 
									$testimonial_subtitle = get_field( 'testimonial_subtitle', $testimonial_id );
									$testimonial_headline = get_field( 'testimonial_headline', $testimonial_id );
								}
						?>
								<!-- Begin Testimonial -->
								<div class="col-md-6">
									<div class="testimonial image-<?php echo esc_attr( $testimonial_layout); ?> testimonial-<?php echo esc_attr( $testimonials_style ); ?>">
										<div class="content-box">
											<div class="content-box-info">
												<?php if ( 'left' === $testimonial_layout ) : ?>
													<div class="profile">
														<?php if ( esc_attr( $testimonial_title ) ) : ?>
															<img src="<?php echo esc_url( $testimonial['image_url'] ); ?>" alt="<?php echo esc_attr( $testimonial_title ); ?>">
															<p class="name"><?php echo esc_attr( $testimonial_title ); ?></p>
														<?php endif; ?>
														<?php if ( class_exists('acf') && ! empty( $testimonial_subtitle ) ) : ?>
															<p class="company"><?php echo esc_attr( $testimonial_subtitle ); ?></p>
														<?php endif; ?>
													</div>
												<?php endif; ?>
												
													<div class="testimonial-content">
														<?php if ( class_exists('acf') && ! empty( $testimonial_headline ) ) : ?>
															<p class="testimonial-headline"><?php echo esc_attr( $testimonial_headline ); ?></p>
														<?php endif; ?>
														<p><?php echo esc_html( $testimonial_content ); ?></p>
													</div>
											</div>
										</div>
										<?php if ( 'left' !== $testimonial_layout ) : ?>
											<div class="profile">
												<?php if ( esc_attr( $testimonial_title ) ) : ?>
													<img src="<?php echo esc_url( $testimonial['image_url'] ); ?>" alt="<?php echo esc_attr( $testimonial_title ); ?>">
													<p class="name"><?php echo esc_attr( $testimonial_title ); ?></p>
												<?php endif; ?>
												<?php if ( class_exists('acf') && ! empty( $testimonial_subtitle ) ) : ?>
													<p class="company"><?php echo esc_attr( $testimonial_subtitle ); ?></p>
												<?php endif; ?>
											</div>
										<?php endif; ?>
									</div> 
								</div>
								<!-- End Testimonial -->

							<?php endwhile;
							wp_reset_postdata();

						endif; ?>

					</div> <!-- End Testimonials carousel -->
				</div> <!-- End row -->

				<div class="clear"></div>
				<?php if( esc_attr( $instance['testimonials_button_text'] ) ) : ?>
					<a class="read-more" href="<?php echo esc_url( $page['url'] ); ?>"><?php printf( esc_html__( '%s', 'interico' ), $view_all_string ); ?></a>
				<?php endif; ?>
				<div class="clear"></div>


			</div>
		</section> <!-- End Testimonials -->

		<?php

		echo $args['after_widget'];
	}
}
add_action( 'widgets_init', create_function( '', 'register_widget( "Interico_Testimonials" );' ) );
