<?php
/**
 * The main template file.
 *
 * This is the most generic template file in a WordPress theme
 * and one of the two required files for a theme (the other being style.css).
 * It is used to display a page when nothing more specific matches a query.
 * E.g., it puts together the home page when no home.php file exists.
 *
 * @link https://codex.wordpress.org/Template_Hierarchy
 *
 * @package Interico
 */

get_header(); 
get_template_part( 'template-parts/top-content-area' );

$page_id = absint( get_option( 'page_for_posts' ) );

if ( class_exists( 'acf' ) && is_active_sidebar( 'blog-sidebar' ) ) {
	if ( 'default' === get_field( 'sidebar_position', $page_id ) ) {
		$sidebar_position = get_theme_mod( 'tc_blog_sidebar_position' );
	} else {
		$sidebar_position = get_field( 'sidebar_position', $page_id );
	}
} elseif ( is_active_sidebar( 'blog-sidebar' ) ) {
	$sidebar_position = get_theme_mod( 'tc_blog_sidebar_position' );
} else {
	$sidebar_position = 'disabled';
}

if ( !isset( $sidebar_position ) ) {
	$sidebar_position = get_theme_mod( 'tc_blog_sidebar_position', 'left' );
}

$sidebar_position = strtolower( $sidebar_position);


?>

	<!-- Begin Content -->
	<div class="content animated fadeIn">
		<div class="container">
			<div class="row">

				<!-- Begin page content -->
				<main class="col-xs-12 <?php echo esc_attr( $sidebar_position === 'left' ? 'col-md-9 col-md-push-3' : '' ); echo esc_attr( $sidebar_position === 'right' ? 'col-md-9' : '' ); ?>">

					<?php
					if ( have_posts() ) :

						/* Start the Loop */
						while ( have_posts() ) : the_post();

							/*
							 * Include the Post-Format-specific template for the content.
							 * If you want to override this in a child theme, then include a file
							 * called content-___.php (where ___ is the Post Format name) and that will be used instead.
							 */
							get_template_part( 'template-parts/content', get_post_format() );

						endwhile;

					else :

						get_template_part( 'template-parts/content', 'none' );

					endif; ?>

					<nav class="pagination">
						<?php
							$big = 999999999; // need an unlikely integer
							echo paginate_links( array(
								'base' => str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
								'format' => '?paged=%#%',
								'current' => max( 1, get_query_var('paged') ),
								'total' => $wp_query->max_num_pages,
								'prev_text' => '<i class="fa fa-angle-left"></i>',
								'next_text' => '<i class="fa fa-angle-right"></i>'
							) );
						?>
					</nav>

				</main> <!-- End page content -->

				<!-- Begin Sidebar -->
				<?php if ( 'disabled' !== $sidebar_position && is_active_sidebar( 'blog-sidebar' ) ) : ?>
					<div class="col-xs-12 col-md-3 <?php echo esc_attr( $sidebar_position === 'left' ? ' col-md-pull-9' : '' ); ?>">
						<aside class="sidebar-nav">
							<?php dynamic_sidebar( 'blog-sidebar' ); ?>
						</aside>
					</div>
				<?php endif; ?>
				<!-- End Sidebar -->

			</div> <!-- End row -->
		</div> <!-- End container -->
	</div> <!-- End Content -->

<?php get_footer(); ?>
