<?php
/**
 * The template for displaying all pages.
 *
 * This is the template that displays all pages by default.
 * Please note that this is the WordPress construct of pages
 * and that other 'pages' on your WordPress site may use a
 * different template.
 *
 * @link https://codex.wordpress.org/Template_Hierarchy
 *
 * @package Interico
 */

get_header(); 
get_template_part( 'template-parts/top-content-area' );

if ( class_exists( 'acf' ) && is_active_sidebar( 'sidebar' ) ) {
	if ( 'default' === get_field( 'sidebar_position', $page_id ) ) {
		$sidebar_position = get_theme_mod( 'tc_page_sidebar_position' );
	} else {
		$sidebar_position = get_field( 'sidebar_position', $page_id );
	}
} elseif ( is_active_sidebar( 'sidebar' ) ) {
	$sidebar_position = get_theme_mod( 'tc_page_sidebar_position' );
} else {
	$sidebar_position = 'disabled';
}

if ( !isset( $sidebar_position ) ) {
	$sidebar_position = 'disabled';
}

$sidebar_position = strtolower( $sidebar_position);

if ( class_exists( 'acf' ) ) {
	if ( 'default' === get_field( 'content_padding_top', $page_id ) ) {
		$content_padding_top = get_theme_mod( 'tc_default_page_padding_top', '80' );
	} else {
		$content_padding_top = get_field( 'content_padding_top', $page_id );
	}
	if ( 'default' === get_field( 'content_padding_bottom', $page_id ) ) {
		$content_padding_bottom = get_theme_mod( 'tc_default_page_padding_bottom', '80' );
	} else {
		$content_padding_bottom = get_field( 'content_padding_bottom', $page_id );
	}
} else {
	$content_padding_top = get_theme_mod( 'tc_default_page_padding_top', '80' );
	$content_padding_bottom = get_theme_mod( 'tc_default_page_padding_bottom', '80' );
}


?>

	<!-- Begin Content -->
	<div class="content animated padding-top-<?php echo esc_attr($content_padding_top); ?> padding-bottom-<?php echo esc_attr($content_padding_bottom); ?>">
		<div class="container">
			<div class="row">

				<!-- Begin page content -->
				<main class="col-xs-12 <?php echo esc_attr( $sidebar_position === 'left' ? 'col-md-9 col-md-push-3' : '' ); echo esc_attr( $sidebar_position === 'right' ? 'col-md-9' : '' ); ?>">

					<?php
						while ( have_posts() ) : the_post();

							get_template_part( 'template-parts/content', 'page' );

							// If comments are open or we have at least one comment, load up the comment template.
							if ( comments_open() || get_comments_number() ) :
								comments_template();
							endif;

						endwhile; // End of the loop.
					?>

				</main> <!-- End page content -->

				<!-- Begin Sidebar -->
				<?php if ( 'disabled' !== $sidebar_position && is_active_sidebar( 'sidebar' ) ) : ?>
					<div class="col-xs-12 col-md-3 <?php echo esc_attr( $sidebar_position === 'left' ? ' col-md-pull-9' : '' ); ?>">
						<aside class="sidebar">
							<?php dynamic_sidebar( 'sidebar' ); ?>
						</aside>
					</div>
				<?php endif; ?>
				<!-- End Sidebar -->

			</div> <!-- End row -->
		</div> <!-- End container -->
	</div> <!-- End Content -->

<?php get_footer(); ?>
