<?php
/**
 * The template for displaying all single posts.
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/#single-post
 *
 * @package Interico
 */

get_header(); 
get_template_part( 'template-parts/top-content-area' );

$page_id = get_the_ID();

if ( class_exists( 'acf' ) && is_active_sidebar( 'blog-sidebar' ) ) {
	if ( 'default' === get_field( 'sidebar_position', $page_id ) ) {
		$sidebar_position = get_theme_mod( 'tc_blog_sidebar_position', 'left' );
	} else {
		$sidebar_position = get_field( 'sidebar_position', $page_id );
	}
} elseif ( is_active_sidebar( 'blog-sidebar' ) ) {
	$sidebar_position = get_theme_mod( 'tc_blog_sidebar_position', 'left' );
} else {
	$sidebar_position = 'disabled';
}

if ( !isset( $sidebar_position ) || 'default' === $sidebar_position ) {
	$sidebar_position = get_theme_mod( 'tc_blog_sidebar_position', 'left' );
}

$sidebar_position = strtolower( $sidebar_position);

if ( class_exists( 'acf' ) ) {
	if ( 'default' === get_field( 'post_layout', $page_id ) ) {
		$layout = get_theme_mod( 'tc_default_post_layout', 'standard' );
	} else {
		$layout = get_field( 'post_layout', $page_id );
	}
	$content_padding_top = 80;
	$content_padding_bottom = 80;
} else {
	$content_padding_top = 80;
	$content_padding_bottom = 80;
	$layout = get_theme_mod( 'tc_default_post_layout', 'standard' );
}


?>

	<!-- Begin Content -->
	<div class="content padding-top-<?php echo esc_attr($content_padding_top); ?> padding-bottom-<?php echo esc_attr($content_padding_bottom); ?> post-<?php echo esc_attr( $layout ); ?>">
		<div class="container">
			<div class="row">

				<!-- Begin page content -->
				<main class="col-xs-12 <?php echo esc_attr( $sidebar_position === 'left' ? 'col-md-9 col-md-push-3' : '' ); echo esc_attr( $sidebar_position === 'right' ? 'col-md-9' : '' ); ?>">

				<?php
				while ( have_posts() ) : the_post();

					get_template_part( 'template-parts/content-single', get_post_format() );

					wp_link_pages( array(
						'before' => '<div class="page-links">' . esc_html__( 'Pages:', 'interico' ),
						'after'  => '</div>',
					) );

				endwhile; // End of the loop.
				?>
	
				<?php if ( 'hide' !== get_theme_mod( 'tc_posts_nav', 'show' ) && ( get_next_post() || ( get_previous_post() ) ) ) : ?>
					<div class="projects-navigation posts">
						<div class="container">
							<div class="row">
								<nav class="projects-nav">
									<div class="col-xs-6 text-left">
										<?php
											// Next Post 
											next_post_link( '<span class="link-prev">%link</span>' );
										?>
									</div>

									<div class="col-xs-6 text-right">
										
										<?php
											// Previous Post 
											previous_post_link( '<span class="link-next">%link</span>' );
										?>
									</div>
									
								</nav>
							</div>
						</div>
					</div>
				<?php endif; ?>

				<?php // If comments are open or we have at least one comment, load up the comment template.
				if ( comments_open() || get_comments_number() ) :
					comments_template();
				endif;
				?>

				</main> <!-- End page content -->

				<!-- Begin Sidebar -->
				<?php if ( 'disabled' !== $sidebar_position && is_active_sidebar( 'blog-sidebar' ) ) : ?>
					<div class="col-xs-12 col-md-3 <?php echo esc_attr( $sidebar_position === 'left' ? ' col-md-pull-9' : '' ); ?>">
						<aside class="sidebar">
							<?php dynamic_sidebar( 'blog-sidebar' ); ?>
						</aside>
					</div>
				<?php endif; ?>
				<!-- End Sidebar -->

			</div> <!-- End row -->
		</div> <!-- End container -->
	</div> <!-- End Content -->

<?php
get_footer();
