<?php

function wmfx_paginate( $pagination = null ) {
	global $wp_query, $wp_rewrite;
	$wp_query->query_vars['paged'] > 1 ? $current = $wp_query->query_vars['paged'] : $current = 1;
	
	if( $pagination == null ) $pagination = array(
		'base' => @add_query_arg('page','%#%'),
		'format' => '',
		'total' => $wp_query->max_num_pages,
		'current' => $current,
		'show_all' => true,
		'type' => 'list',
		'next_text' => '&raquo;',
		'prev_text' => '&laquo;'
	);
	
	if( $wp_rewrite->using_permalinks() )
		$pagination['base'] = user_trailingslashit( trailingslashit( remove_query_arg( 's', get_pagenum_link( 1 ) ) ) . 'page/%#%/', 'paged' );
	
	if( !empty($wp_query->query_vars['s']) )
		$pagination['add_args'] = array( 's' => get_query_var( 's' ) );
	
	echo paginate_links( $pagination );
}

// Limit Post Word Count
add_filter('excerpt_length', 'wmfx_new_excerpt_length');
function wmfx_new_excerpt_length($length) {
	return 40;
}

//Replace Excerpt Link
add_filter('excerpt_more', 'wmfx_new_excerpt_more');
function wmfx_new_excerpt_more($more) {
       global $post;
	return '...';
}

//custom excerpts
function wmfx_excerpt($limit) {
	$excerpt = explode(' ', get_the_excerpt(), $limit);
	if (count($excerpt)>=$limit) {
		array_pop($excerpt);
		$excerpt = implode(" ",$excerpt).'...';
	} else {
		$excerpt = implode(" ",$excerpt);
	}
	$excerpt = preg_replace('`[[^]]*]`','',$excerpt);
	return $excerpt;
}


function wmfx_language_selector(){
    $languages = icl_get_languages('skip_missing=0&orderby=code');
    if(!empty($languages)){
    	echo '<ul>';
        foreach($languages as $l){
        	echo '<li>';
            if(!$l['active']) echo '<a href="'.$l['url'].'">' . $l['native_name'] . '</a>' ;
        	echo '</li>';
        }
    	echo '</ul>';
    }
}

function wp_barebones_cutoff_content($post_id){
	$the_post = get_post($post_id); //Gets post ID
	$the_excerpt = $the_post->post_content; //Gets post_content to be used as a basis for the excerpt
	$excerpt_length = 35; //Sets excerpt length by word count
	$the_excerpt = strip_tags(strip_shortcodes($the_excerpt)); //Strips tags and images
	$words = explode(' ', $the_excerpt, $excerpt_length + 1);
	if(count($words) > $excerpt_length) :
		array_pop($words);
		array_push($words, '...');
		$the_excerpt = implode(' ', $words);
	endif;
	return $the_excerpt;
}

function wp_barebones_get_excerpt_by_id($post_id) {
  global $post;  
  $save_post = $post;
  $post = get_post($post_id);
  $output = get_the_excerpt();
  if(!$output){
  	$output = wp_barebones_cutoff_content($post_id);
  }
  $post = $save_post;
  return $output;
}


function wp_barebones_title(){
	/*
	 * Print the <title> tag based on what is being viewed.
	 */
	global $page, $paged;

	wp_title( '|', true, 'right' );

	// Add the blog name.
	bloginfo( 'name' );

	// Add the blog description for the home/front page.
	$site_description = get_bloginfo( 'description', 'display' );
	if ( $site_description && ( is_home() || is_front_page() ) )
		echo " | $site_description";

	// Add a page number if necessary:
	if ( $paged >= 2 || $page >= 2 )
		echo ' | ' . sprintf( __( 'Page %s', 'wp_barebones' ), max( $paged, $page ) );

}

function wp_barebones_permalink( $id ){
	echo wp_barebones_get_permalink( $id );
}

function wp_barebones_get_permalink( $id ){
	if(function_exists('icl_object_id')){
		$id = icl_object_id($id, 'page', true);
	}
	return get_permalink( $id );
}

function wp_barebones_get_image( $append ){
	return get_bloginfo( 'template_directory' ) .'/images/'. $append ;
}


function wp_barebones_image( $append ){
	echo wp_barebones_get_image($append);
}

function wp_barebones_theme_url( $append = ''){
	return get_bloginfo( 'template_directory' ) . $append ;
}


function wp_barebones_theme_location( $append ){
	return get_theme_root() . "/" . get_template() . $append ;
}


function _return_empty_string(){
	return '' ;
}

function wp_barebones_get_home_url( $eng_url = '' ){
	if( empty($eng_url)){
		return home_url();
	}
	$url = home_url($eng_url);
	$postid = url_to_postid( $url );
	return azuri_get_permalink( $postid );
}

function wp_barebones_home_url( $eng_url = '' ){
	echo get_azuri_home_url($eng_url) ;
}

function wp_barebones_slug($string){
    return strtolower(trim(preg_replace('~[^0-9a-z]+~i', '-', html_entity_decode(preg_replace('~&([a-z]{1,2})(?:acute|cedil|circ|grave|lig|orn|ring|slash|th|tilde|uml);~i', '$1', htmlentities($string, ENT_QUOTES, 'UTF-8')), ENT_QUOTES, 'UTF-8')), '-'));
}

function wp_barebones_cuttext($value, $length){    
    if(is_array($value)) list($string, $match_to) = $value;
    else { $string = $value; $match_to = $value{0}; }

    $match_start = stristr($string, $match_to);
    $match_compute = strlen($string) - strlen($match_start);

    if (strlen($string) > $length)
    {
        if ($match_compute < ($length - strlen($match_to)))
        {
            $pre_string = substr($string, 0, $length);
            $pos_end = strrpos($pre_string, " ");
            if($pos_end === false) $string = $pre_string."...";
            else $string = substr($pre_string, 0, $pos_end)."...";
        }
        else if ($match_compute > (strlen($string) - ($length - strlen($match_to))))
        {
            $pre_string = substr($string, (strlen($string) - ($length - strlen($match_to))));
            $pos_start = strpos($pre_string, " ");
            $string = "...".substr($pre_string, $pos_start);
            if($pos_start === false) $string = "...".$pre_string;
            else $string = "...".substr($pre_string, $pos_start);
        }
        else
        {        
            $pre_string = substr($string, ($match_compute - round(($length / 3))), $length);
            $pos_start = strpos($pre_string, " "); $pos_end = strrpos($pre_string, " ");
            $string = "...".substr($pre_string, $pos_start, $pos_end)."...";
            if($pos_start === false && $pos_end === false) $string = "...".$pre_string."...";
            else $string = "...".substr($pre_string, $pos_start, $pos_end)."...";
        }

        $match_start = stristr($string, $match_to);
        $match_compute = strlen($string) - strlen($match_start);
    }
    
    return $string;
}
